Class: Aws::Imagebuilder::Types::AutoDisablePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines the rules by which an image pipeline is automatically disabled when it fails. By default, if the schedule doesn't include an auto-disable policy, Image Builder disables the pipeline after 5 consecutive failed scheduled builds.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_count ⇒ Integer

The number of consecutive scheduled image pipeline executions that must fail before Image Builder automatically disables the pipeline.

Returns:

  • (Integer)


213
214
215
216
217
# File 'lib/aws-sdk-imagebuilder/types.rb', line 213

class AutoDisablePolicy < Struct.new(
  :failure_count)
  SENSITIVE = []
  include Aws::Structure
end