Class: Aws::Imagebuilder::Types::CallRateLimitExceededException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

You have exceeded the permitted request rate for the Amazon EC2 APIs that Image Builder calls on your behalf. Retry with an increasing or variable delay between requests.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


228
229
230
231
232
# File 'lib/aws-sdk-imagebuilder/types.rb', line 228

class CallRateLimitExceededException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end