Class: Aws::Imagebuilder::Types::CancelImageCreationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


256
257
258
259
260
261
# File 'lib/aws-sdk-imagebuilder/types.rb', line 256

class CancelImageCreationRequest < Struct.new(
  :image_build_version_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image that you want to cancel creation for.

Returns:

  • (String)


256
257
258
259
260
261
# File 'lib/aws-sdk-imagebuilder/types.rb', line 256

class CancelImageCreationRequest < Struct.new(
  :image_build_version_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end