Class: Aws::Imagebuilder::Types::CancelLifecycleExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CancelLifecycleExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lifecycle_execution_id ⇒ String
The unique identifier of the lifecycle execution that the cancellation request applies to.
Instance Attribute Details
#lifecycle_execution_id ⇒ String
The unique identifier of the lifecycle execution that the cancellation request applies to. The cancellation completes asynchronously.
323 324 325 326 327 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 323 class CancelLifecycleExecutionResponse < Struct.new( :lifecycle_execution_id) SENSITIVE = [] include Aws::Structure end |