Class: Aws::Imagebuilder::Types::ClientException
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ClientException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
A generic client error. This error usually indicates that the request failed a validation check, such as when a downstream service rejects a configured value.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
338 339 340 341 342 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 338 class ClientException < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |