Class: Aws::Imagebuilder::Types::ComponentConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Configuration details of the component. You can specify each component only once in a recipe, regardless of version. Components with a status of DEPRECATED or DISABLED can't be added to new recipes.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_arn ⇒ String

The Amazon Resource Name (ARN) of the component. You can specify a build version ARN, or a component version ARN whose version segments can use x wildcards, for example 1.x.x.

Returns:

  • (String)


488
489
490
491
492
493
# File 'lib/aws-sdk-imagebuilder/types.rb', line 488

class ComponentConfiguration < Struct.new(
  :component_arn,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parameters ⇒ Array<Types::ComponentParameter>

A group of parameter settings that Image Builder uses to configure the component for a specific recipe. You must supply a value for every component parameter that has no default value, and you can only supply parameters that the component defines.

Returns:



488
489
490
491
492
493
# File 'lib/aws-sdk-imagebuilder/types.rb', line 488

class ComponentConfiguration < Struct.new(
  :component_arn,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end