Class: Aws::Imagebuilder::Types::ComponentSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

A high-level summary of a component.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the component.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#change_description ⇒ String

The change description for this version of the component.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date that Image Builder created this version of the component.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the component.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the component.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#obfuscate ⇒ Boolean

Indicates whether component source is hidden from view in the console, and from component detail results for API, CLI, or SDK operations.

Returns:

  • (Boolean)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the component. The value is your account ID for components that you own, the sharing account's ID for shared components, or Amazon, ThirdParty, or AWSMarketplace.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The operating system platform of the component.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#publisher ⇒ String

Contains the name of the publisher if this is a third-party component. Otherwise, this property is empty.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::ComponentState

Describes the current status of the component.



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#supported_os_versions ⇒ Array<String>

The operating system (OS) version that the component supports. If the OS information is available, Image Builder performs a prefix match against the base image OS version during image recipe creation.

Returns:

  • (Array<String>)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags that apply to the component.

Returns:

  • (Hash<String,String>)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The component type specifies whether Image Builder uses the component to build the image or only to test it.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the component.

Returns:

  • (String)


674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
# File 'lib/aws-sdk-imagebuilder/types.rb', line 674

class ComponentSummary < Struct.new(
  :arn,
  :name,
  :version,
  :platform,
  :supported_os_versions,
  :state,
  :type,
  :owner,
  :description,
  :change_description,
  :date_created,
  :tags,
  :publisher,
  :obfuscate)
  SENSITIVE = []
  include Aws::Structure
end