Class: Aws::Imagebuilder::Types::ComponentVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The defining characteristics of a specific version of a component.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the component.

Semantic versioning is included in each object's Amazon Resource Name (ARN), at the level that applies to that object as follows:

  1. Versionless ARNs and Name ARNs do not include specific values in any of the nodes. The nodes are either left off entirely, or they are specified as wildcards, for example: x.x.x.

  2. Version ARNs have only the first three nodes: <major>.<minor>.<patch>

  3. Build version ARNs have all four nodes, and point to a specific build for a specific version of an object.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date that the component was created.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the component.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the component.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the component. The value is your account ID for components that you own, the sharing account's ID for shared components, or Amazon, ThirdParty, or AWSMarketplace.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The platform of the component.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#product_codes ⇒ Array<Types::ProductCodeListItem>

Contains product codes that are used for billing purposes for Amazon Web Services Marketplace components.

Returns:



783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Describes the current status of the component version.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#supported_os_versions ⇒ Array<String>

The operating system (OS) version supported by the component. If OS information is available, Image Builder performs a prefix match against the base image OS version during image recipe creation.

Returns:

  • (Array<String>)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of the component denotes whether the component is used to build the image or only to test it.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The semantic version of the component.

The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.

Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.

Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.

Filtering: You can use wildcards (x) to specify the most recent versions or nodes when selecting the base image or components for your recipe. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards.

Returns:

  • (String)


783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
# File 'lib/aws-sdk-imagebuilder/types.rb', line 783

class ComponentVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :platform,
  :supported_os_versions,
  :type,
  :owner,
  :date_created,
  :status,
  :product_codes)
  SENSITIVE = []
  include Aws::Structure
end