Class: Aws::Imagebuilder::Types::Container
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::Container
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Details of the container images that are output resources of an image build in a given Amazon Web Services Region: the Region, and the URIs of the container images.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_uris ⇒ Array<String>
A list of URIs for containers created in the context Region.
-
#region ⇒ String
Containers and container images are Region-specific.