Class: Aws::Imagebuilder::Types::ContainerRecipeSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

A summary of a container recipe.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the container recipe.

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#container_type ⇒ String

Specifies the type of container, such as "Docker".

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date when this container recipe was created.

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#instance_image ⇒ String

The base image for a container build and test instance. This can contain an AMI ID or it can specify an Amazon Web Services Systems Manager (SSM) Parameter Store Parameter, prefixed by ssm:, followed by the parameter name or ARN.

If not specified, Image Builder uses the appropriate ECS-optimized AMI as a base image.

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the container recipe.

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the container recipe.

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#parent_image ⇒ String

The base image for the container recipe.

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The system platform for the container. Container recipes support only the Linux and Windows platforms.

Returns:

  • (String)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Tags that are attached to the container recipe.

Returns:

  • (Hash<String,String>)


1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1065

class ContainerRecipeSummary < Struct.new(
  :arn,
  :container_type,
  :name,
  :platform,
  :owner,
  :parent_image,
  :date_created,
  :instance_image,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end