Class: Aws::Imagebuilder::Types::CreateContainerRecipeRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#components ⇒ Array<Types::ComponentConfiguration>

The components included in the container recipe. You can specify each component only one time in a recipe.

Returns:



1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#container_type ⇒ String

The type of container to create.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the container recipe.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dockerfile_template_data ⇒ String

The Dockerfile template used to build your image, as an inline data blob. You must specify exactly one of the dockerfileTemplateData or dockerfileTemplateUri properties. For the contextual variables that the template can include, see Create a new version of a container recipe in the EC2 Image Builder User Guide.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dockerfile_template_uri ⇒ String

The Amazon S3 URI for the Dockerfile template that is used to build your container image. You must have permission to read the object. Image Builder reads the object once, when it creates the recipe, and stores its content in the recipe. Later changes to the S3 object don't affect the recipe. You must specify exactly one of the dockerfileTemplateData or dockerfileTemplateUri properties.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_run ⇒ Boolean

Validates the required permissions and request parameters without performing the operation. If validation succeeds, the operation returns a DryRunOperationException error response.

Returns:

  • (Boolean)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_os_version_override ⇒ String

Specifies the operating system version for the base image. Use this property only when the base image is a container image from a registry. When the base image is an Image Builder image, the operating system version comes from the parent image.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_configuration ⇒ Types::InstanceConfiguration

A group of options that can be used to configure an instance for building and testing container images.



1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The Amazon Resource Name (ARN) that uniquely identifies which KMS key is used to encrypt the Dockerfile template. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the container recipe. The recipe name, combined with the semantic version, must be unique to your account in each Amazon Web Services Region. Image Builder generates the container recipe ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#parent_image ⇒ String

The base image for the container recipe. This can be an Image Builder image resource ARN or a container image URI from a registry, for example amazonlinux:latest.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#platform_override ⇒ String

Specifies the operating system platform when you use a custom base image. Container recipes support only the Linux and Windows platforms.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#semantic_version ⇒ String

The semantic version of the container recipe. This version follows the semantic version syntax.

The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.

Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.

Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Tags that are attached to the container recipe.

Returns:

  • (Hash<String,String>)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#target_repository ⇒ Types::TargetContainerRepository

The destination repository for the container image. The Amazon ECR repository must already exist in the Amazon Web Services Region where the build runs.



1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#working_directory ⇒ String

The working directory for use during build and test workflows.

Returns:

  • (String)


1373
1374
1375
1376
1377
1378
1379
1380
1381
1382
1383
1384
1385
1386
1387
1388
1389
1390
1391
1392
1393
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1373

class CreateContainerRecipeRequest < Struct.new(
  :container_type,
  :name,
  :description,
  :semantic_version,
  :components,
  :instance_configuration,
  :dockerfile_template_data,
  :dockerfile_template_uri,
  :platform_override,
  :image_os_version_override,
  :parent_image,
  :tags,
  :working_directory,
  :target_repository,
  :kms_key_id,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end