Class: Aws::Imagebuilder::Types::CreateImagePipelineRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#container_recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the container recipe that is used to configure images created by this container pipeline. You must specify either this property or imageRecipeArn, but not both.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the image pipeline.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the distribution configuration that configures and distributes images created by this image pipeline.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_run ⇒ Boolean

Validates the required permissions and request parameters without performing the operation. If validation succeeds, the operation returns a DryRunOperationException error response.

Returns:

  • (Boolean)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_image_metadata_enabled ⇒ Boolean

Specifies whether to collect additional information about the image being created, including the operating system (OS) version and package list. Defaults to true.

Returns:

  • (Boolean)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the image recipe that configures images created by this image pipeline. You must specify either this property or containerRecipeArn, but not both.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_scanning_configuration ⇒ Types::ImageScanningConfiguration

Contains settings for vulnerability scans that Amazon Inspector runs against the test instance during image creation.



1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_tags ⇒ Hash<String,String>

The tags that Image Builder applies to the Image Builder image resource that this pipeline's scheduled executions create. These tags don't apply to the output AMI. To tag output AMIs, use amiTags in the pipeline's distribution configuration.

Returns:

  • (Hash<String,String>)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#image_tests_configuration ⇒ Types::ImageTestsConfiguration

Specifies the test settings that Image Builder applies to images that this pipeline creates. If you don't provide test settings, Image Builder stores a default configuration with image tests enabled.



1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the infrastructure configuration that builds images created by this image pipeline.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configuration ⇒ Types::PipelineLoggingConfiguration

Specifies the logging configuration for the image pipeline. Use this to define custom CloudWatch Logs log groups for your pipeline execution logs and image build logs. The service manages log groups with names starting with /aws/imagebuilder/ using the service-linked role. For custom log group names outside of this prefix, you must also provide an executionRole.



1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the image pipeline. Pipeline names must be unique to your account in each Amazon Web Services Region. Image Builder generates the pipeline ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#schedule ⇒ Types::Schedule

The schedule of the image pipeline. If you don't provide a schedule, the pipeline runs only when you call StartImagePipelineExecution.

Returns:



1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the image pipeline. If you don't specify a status, it defaults to ENABLED. A disabled pipeline doesn't run on its schedule, but you can still start builds manually.

Returns:

  • (String)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags of the image pipeline.

Returns:

  • (Hash<String,String>)


1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#workflows ⇒ Array<Types::WorkflowConfiguration>

The array of workflow configuration objects for builds that this pipeline starts. You must also specify executionRole when you provide workflows.

Returns:



1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1624

class CreateImagePipelineRequest < Struct.new(
  :name,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :tags,
  :image_tags,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :execution_role,
  :logging_configuration,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end