Class: Aws::Imagebuilder::Types::CreateImageRecipeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

The client token that uniquely identifies the request.

Returns:

  • (String)


1831
1832
1833
1834
1835
1836
1837
1838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1831

class CreateImageRecipeResponse < Struct.new(
  :request_id,
  :client_token,
  :image_recipe_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#image_recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the image recipe that was created by this request.

Returns:

  • (String)


1831
1832
1833
1834
1835
1836
1837
1838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1831

class CreateImageRecipeResponse < Struct.new(
  :request_id,
  :client_token,
  :image_recipe_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#latest_version_references ⇒ Types::LatestVersionReferences

A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.



1831
1832
1833
1834
1835
1836
1837
1838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1831

class CreateImageRecipeResponse < Struct.new(
  :request_id,
  :client_token,
  :image_recipe_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


1831
1832
1833
1834
1835
1836
1837
1838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1831

class CreateImageRecipeResponse < Struct.new(
  :request_id,
  :client_token,
  :image_recipe_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end