Class: Aws::Imagebuilder::Types::CreateImageResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

The client token that uniquely identifies the request.

Returns:

  • (String)


1967
1968
1969
1970
1971
1972
1973
1974
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1967

class CreateImageResponse < Struct.new(
  :request_id,
  :client_token,
  :image_build_version_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image that the request created.

Returns:

  • (String)


1967
1968
1969
1970
1971
1972
1973
1974
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1967

class CreateImageResponse < Struct.new(
  :request_id,
  :client_token,
  :image_build_version_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#latest_version_references ⇒ Types::LatestVersionReferences

A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.



1967
1968
1969
1970
1971
1972
1973
1974
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1967

class CreateImageResponse < Struct.new(
  :request_id,
  :client_token,
  :image_build_version_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


1967
1968
1969
1970
1971
1972
1973
1974
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1967

class CreateImageResponse < Struct.new(
  :request_id,
  :client_token,
  :image_build_version_arn,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end