Class: Aws::Imagebuilder::Types::CreateInfrastructureConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the infrastructure configuration.

Returns:

  • (String)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_run ⇒ Boolean

Validates the required permissions and request parameters without performing the operation. If validation succeeds, the operation returns a DryRunOperationException error response.

Returns:

  • (Boolean)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_metadata_options ⇒ Types::InstanceMetadataOptions

The instance metadata service (IMDS) settings that Image Builder applies to the EC2 build and test instances it launches during image creation. If you don't set these options, the EC2 launch defaults for the instance apply. For more information about instance metadata options, see one of the following links:



2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_name ⇒ String

The instance profile to associate with the instance used to customize your Amazon EC2 AMI. The instance profile must exist in your account.

Returns:

  • (String)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#instance_types ⇒ Array<String>

The instance types of the infrastructure configuration. You can specify one or more instance types to use for this build. Image Builder picks one of these instance types based on availability. If you don't specify instance types, Image Builder selects compatible instance types automatically. If you specify a Dedicated Host, Image Builder uses only instance types that the host supports.

Returns:

  • (Array<String>)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#key_pair ⇒ String

The key pair of the infrastructure configuration. You can use this to log on to and debug the instance used to create your image.

Returns:

  • (String)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#logging ⇒ Types::Logging

The logging configuration of the infrastructure configuration. When you configure S3 logs, Image Builder writes logs from the build and test process to the specified bucket under the key prefix.

Returns:



2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the infrastructure configuration. Infrastructure configuration names must be unique to your account in each Amazon Web Services Region. Image Builder generates the infrastructure configuration ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name.

Returns:

  • (String)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#placement ⇒ Types::Placement

The instance placement settings that define where the build and test instances that Image Builder launches during image creation run. These settings don't affect instances that you launch from the output image.

Returns:



2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tags ⇒ Hash<String,String>

The metadata tags to assign to the Amazon EC2 instance that Image Builder launches during the build process. Tags are formatted as key value pairs. Tag keys can't begin with aws: or match one of the following reserved keys: CreatedBy, Ec2ImageBuilderArn, Name, or Tags.

Returns:

  • (Hash<String,String>)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

The security group IDs to associate with the instance used to customize your Amazon EC2 AMI.

Returns:

  • (Array<String>)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arn ⇒ String

The Amazon Resource Name (ARN) of the SNS topic to which Image Builder sends image build event notifications. Specify a standard topic. Image Builder doesn't support FIFO topics. Image Builder validates the topic when you create or update the configuration. You must have permission to publish to the topic.

EC2 Image Builder can't send notifications to SNS topics that are encrypted using keys from other accounts. If your SNS topic is encrypted, the key must be owned by the same account that owns your Image Builder resources.

Returns:

  • (String)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_id ⇒ String

The subnet ID in which to place the instance used to customize your Amazon EC2 AMI. If you specify subnetId, you must also specify one or more security group IDs in securityGroupIds. Otherwise, the request fails.

Returns:

  • (String)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The metadata tags to assign to the infrastructure configuration resource that Image Builder creates as output. Tags are formatted as key value pairs.

Returns:

  • (Hash<String,String>)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#terminate_instance_on_failure ⇒ Boolean

Specifies whether to terminate the instance on failure. Set to false if you want Image Builder to retain the instance used to configure your AMI if the build or test phase of your workflow fails. Defaults to true.

Returns:

  • (Boolean)


2111
2112
2113
2114
2115
2116
2117
2118
2119
2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2111

class CreateInfrastructureConfigurationRequest < Struct.new(
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement,
  :client_token,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end