Class: Aws::Imagebuilder::Types::CreateWorkflowRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_description ⇒ String

Describes what change has been made in this version of the workflow, or what makes this version different from other versions of the workflow.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#data ⇒ String

The UTF-8 encoded YAML document content for the workflow, up to 16,000 characters. For larger documents, store the document in Amazon S3 and specify the uri property instead. You must specify exactly one of the data or uri properties.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Describes the workflow.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#dry_run ⇒ Boolean

Validates the required permissions and request parameters without performing the operation. If validation succeeds, the operation returns a DryRunOperationException error response.

Returns:

  • (Boolean)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The Amazon Resource Name (ARN) that uniquely identifies the KMS key used to encrypt this workflow resource. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide. If you don't specify a key, Image Builder encrypts the workflow document with a KMS key that Image Builder owns.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the workflow to create. Image Builder generates the workflow ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name. If a workflow with the same name and semantic version already exists in your account in the same Amazon Web Services Region, the request creates a new build version for it. If the content is also identical to the latest build version, the request fails because the workflow already exists.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#semantic_version ⇒ String

The semantic version of this workflow resource. The semantic version syntax adheres to the following rules.

The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.

Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.

Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Tags that apply to the workflow resource.

Returns:

  • (Hash<String,String>)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The image creation stage that this workflow applies to. Image Builder validates the workflow document steps against the stage you specify.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end

#uri ⇒ String

The uri of a YAML workflow document file stored in Amazon S3. This must be an S3 URL (s3://bucket/key), and you must have permission to access the S3 bucket it points to. A workflow document that you provide from Amazon S3 can be up to your service quota for workflow size.

Alternatively, you can specify the YAML document inline, using the workflow data property. You must specify exactly one of the data or uri properties.

Returns:

  • (String)


2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2368

class CreateWorkflowRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token,
  :type,
  :dry_run)
  SENSITIVE = []
  include Aws::Structure
end