Class: Aws::Imagebuilder::Types::DistributeImageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::DistributeImageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token that uniquely identifies the request.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the new Image Builder image resource that this operation creates to track the distribution.
Instance Attribute Details
#client_token ⇒ String
The client token that uniquely identifies the request.
2847 2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2847 class DistributeImageResponse < Struct.new( :client_token, :image_build_version_arn) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the new Image Builder image resource that this operation creates to track the distribution. Use this ARN with GetImage to monitor distribution progress.
2847 2848 2849 2850 2851 2852 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2847 class DistributeImageResponse < Struct.new( :client_token, :image_build_version_arn) SENSITIVE = [] include Aws::Structure end |