Class: Aws::Imagebuilder::Types::DistributionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines how Image Builder distributes the output of an image build. You can configure:

  • The Regions to distribute the image to.

  • The Region-specific settings to apply, such as output AMI names, launch permissions for other Amazon Web Services accounts, and target container repositories.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the distribution configuration.

Returns:

  • (String)


2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date on which this distribution configuration was created.

Returns:

  • (String)


2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#date_updated ⇒ String

The date on which this distribution configuration was last updated.

Returns:

  • (String)


2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the distribution configuration.

Returns:

  • (String)


2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#distributions ⇒ Array<Types::Distribution>

The distribution objects that apply Region-specific settings for the deployment of the image to targeted Regions.

Returns:



2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the distribution configuration.

Returns:

  • (String)


2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags of the distribution configuration.

Returns:

  • (Hash<String,String>)


2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_minutes ⇒ Integer

A property that Image Builder doesn't use. You can't set this property when you create or update a distribution configuration, and it has no effect on distribution behavior.

Returns:

  • (Integer)


2958
2959
2960
2961
2962
2963
2964
2965
2966
2967
2968
2969
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2958

class DistributionConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :distributions,
  :timeout_minutes,
  :date_created,
  :date_updated,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end