Class: Aws::Imagebuilder::Types::DryRunOperationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The dry run operation of the resource was successful, and no resources or mutations were actually performed due to the dry run flag in the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


3047
3048
3049
3050
3051
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3047

class DryRunOperationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end