Class: Aws::Imagebuilder::Types::EbsInstanceBlockDeviceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::EbsInstanceBlockDeviceSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Amazon EBS-specific block device mapping specifications.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Specifies whether to delete the associated device on termination.
-
#encrypted ⇒ Boolean
Specifies whether to encrypt the device.
-
#iops ⇒ Integer
The IOPS value for the device.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key to use when encrypting the device.
-
#snapshot_id ⇒ String
The snapshot that defines the device contents.
-
#throughput ⇒ Integer
For GP3 volumes only – The throughput in MiB/s that the volume supports.
-
#volume_size ⇒ Integer
Overrides the volume size for the device.
-
#volume_type ⇒ String
Overrides the volume type for the device.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Specifies whether to delete the associated device on termination.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Specifies whether to encrypt the device.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The IOPS value for the device. Required only when volumeType is io1 or io2.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key to use when encrypting the device. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot that defines the device contents.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
For GP3 volumes only – The throughput in MiB/s that the volume supports.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
Overrides the volume size for the device.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
Overrides the volume type for the device.
3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 3109 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3098 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |