Class: Aws::Imagebuilder::Types::FastLaunchLaunchTemplateSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Identifies the launch template that the associated Windows AMI uses for launching an instance when Windows fast launch is enabled.

You can specify either the launchTemplateName or the launchTemplateId, but not both.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#launch_template_id ⇒ String

The ID of the launch template to use for Windows fast launch for a Windows AMI.

Returns:



3205
3206
3207
3208
3209
3210
3211
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3205

class FastLaunchLaunchTemplateSpecification < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :launch_template_version)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_name ⇒ String

The name of the launch template to use for Windows fast launch for a Windows AMI.

Returns:



3205
3206
3207
3208
3209
3210
3211
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3205

class FastLaunchLaunchTemplateSpecification < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :launch_template_version)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_version ⇒ String

The version of the launch template to use for Windows fast launch for a Windows AMI.

Returns:



3205
3206
3207
3208
3209
3210
3211
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3205

class FastLaunchLaunchTemplateSpecification < Struct.new(
  :launch_template_id,
  :launch_template_name,
  :launch_template_version)
  SENSITIVE = []
  include Aws::Structure
end