Class: Aws::Imagebuilder::Types::GetComponentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the component that you want to get. You can specify a build version ARN, or a component version ARN. The version can use the x wildcard in trailing positions, for example 1.0.x or 1.x.x. Version ARNs resolve to the latest available matching component build version.

Returns:

  • (String)


3304
3305
3306
3307
3308
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3304

class GetComponentRequest < Struct.new(
  :component_build_version_arn)
  SENSITIVE = []
  include Aws::Structure
end