Class: Aws::Imagebuilder::Types::GetComponentResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component ⇒ Types::Component

The component object specified in the request.

Returns:



3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3327

class GetComponentResponse < Struct.new(
  :request_id,
  :component,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#latest_version_references ⇒ Types::LatestVersionReferences

A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.



3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3327

class GetComponentResponse < Struct.new(
  :request_id,
  :component,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


3327
3328
3329
3330
3331
3332
3333
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3327

class GetComponentResponse < Struct.new(
  :request_id,
  :component,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end