Class: Aws::Imagebuilder::Types::GetContainerRecipePolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy ⇒ String

The resource policy for the container recipe, as a JSON policy document. If no policy has been applied, the response contains an empty JSON object ({}).

Returns:

  • (String)


3360
3361
3362
3363
3364
3365
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3360

class GetContainerRecipePolicyResponse < Struct.new(
  :request_id,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


3360
3361
3362
3363
3364
3365
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3360

class GetContainerRecipePolicyResponse < Struct.new(
  :request_id,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end