Class: Aws::Imagebuilder::Types::GetContainerRecipeResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_recipe ⇒ Types::ContainerRecipe

The container recipe object that is returned.



3396
3397
3398
3399
3400
3401
3402
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3396

class GetContainerRecipeResponse < Struct.new(
  :request_id,
  :container_recipe,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#latest_version_references ⇒ Types::LatestVersionReferences

A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.



3396
3397
3398
3399
3400
3401
3402
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3396

class GetContainerRecipeResponse < Struct.new(
  :request_id,
  :container_recipe,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


3396
3397
3398
3399
3400
3401
3402
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3396

class GetContainerRecipeResponse < Struct.new(
  :request_id,
  :container_recipe,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end