Class: Aws::Imagebuilder::Types::GetImageRecipePolicyResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#policy ⇒ String

The resource policy for the image recipe, as a JSON policy document. If no policy has been applied, the response contains an empty JSON object ({}).

Returns:

  • (String)


3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3521

class GetImageRecipePolicyResponse < Struct.new(
  :request_id,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


3521
3522
3523
3524
3525
3526
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3521

class GetImageRecipePolicyResponse < Struct.new(
  :request_id,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end