Class: Aws::Imagebuilder::Types::GetImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image that you want to get. You can specify a full build version ARN, or a version ARN with or without wildcards (x.x.x, 1.x.x, or 1.0.x). A version or wildcard ARN resolves to the latest matching build version that has reached AVAILABLE status. Builds that were later deprecated, disabled, or deleted don't resolve. To get an image in any other state, such as a failed or in-progress build, specify the full build version ARN.

Returns:

  • (String)


3581
3582
3583
3584
3585
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3581

class GetImageRequest < Struct.new(
  :image_build_version_arn)
  SENSITIVE = []
  include Aws::Structure
end