Class: Aws::Imagebuilder::Types::GetImageResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image ⇒ Types::Image

The image object.

Returns:



3604
3605
3606
3607
3608
3609
3610
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3604

class GetImageResponse < Struct.new(
  :request_id,
  :image,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#latest_version_references ⇒ Types::LatestVersionReferences

A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.



3604
3605
3606
3607
3608
3609
3610
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3604

class GetImageResponse < Struct.new(
  :request_id,
  :image,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


3604
3605
3606
3607
3608
3609
3610
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3604

class GetImageResponse < Struct.new(
  :request_id,
  :image,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end