Class: Aws::Imagebuilder::Types::GetMarketplaceResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_arn ⇒ String

The Amazon Resource Name (ARN) that uniquely identifies an Amazon Web Services Marketplace resource.

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3714

class GetMarketplaceResourceRequest < Struct.new(
  :resource_type,
  :resource_arn,
  :resource_location)
  SENSITIVE = []
  include Aws::Structure
end

#resource_location ⇒ String

The Amazon S3 location of the component artifact to retrieve, in s3://bucket/key form.

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3714

class GetMarketplaceResourceRequest < Struct.new(
  :resource_type,
  :resource_arn,
  :resource_location)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

Specifies which type of Amazon Web Services Marketplace resource Image Builder retrieves.

Returns:

  • (String)


3714
3715
3716
3717
3718
3719
3720
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3714

class GetMarketplaceResourceRequest < Struct.new(
  :resource_type,
  :resource_arn,
  :resource_location)
  SENSITIVE = []
  include Aws::Structure
end