Class: Aws::Imagebuilder::Types::GetWorkflowExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time ⇒ String

The timestamp when the specified runtime instance of the workflow finished.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image build version that owns the specified runtime instance of the workflow.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

The output message from the specified runtime instance of the workflow, if applicable.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#parallel_group ⇒ String

The name of the parallel group that this runtime instance of the workflow ran in, if configured. Parallel groups apply only to test workflows.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ String

The timestamp when the specified runtime instance of the workflow started.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current runtime status for the specified runtime instance of the workflow. COMPLETED, FAILED, ROLLBACK_COMPLETED, CANCELLED, and SKIPPED are terminal states.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_step_count ⇒ Integer

The total number of steps that the workflow document defines for this runtime instance of the workflow. Image Builder sets this count before any steps run. The sum of succeeded, skipped, and failed steps only reaches this total if every step finishes in one of those states.

Returns:

  • (Integer)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_failed ⇒ Integer

A runtime count for the number of steps that failed in the specified runtime instance of the workflow.

Returns:

  • (Integer)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_skipped ⇒ Integer

A runtime count for the number of steps that were skipped in the specified runtime instance of the workflow.

Returns:

  • (Integer)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_succeeded ⇒ Integer

A runtime count for the number of steps that ran successfully in the specified runtime instance of the workflow.

Returns:

  • (Integer)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of workflow that Image Builder ran for the specified runtime instance of the workflow.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the build version for the Image Builder workflow resource that defines the specified runtime instance of the workflow.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_execution_id ⇒ String

The unique identifier that Image Builder assigned to keep track of runtime details when it ran the workflow.

Returns:

  • (String)


3837
3838
3839
3840
3841
3842
3843
3844
3845
3846
3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3837

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end