Class: Aws::Imagebuilder::Types::GetWorkflowResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#latest_version_references ⇒ Types::LatestVersionReferences

A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.



3885
3886
3887
3888
3889
3890
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3885

class GetWorkflowResponse < Struct.new(
  :workflow,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end

#workflow ⇒ Types::Workflow

The workflow resource specified in the request.

Returns:



3885
3886
3887
3888
3889
3890
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3885

class GetWorkflowResponse < Struct.new(
  :workflow,
  :latest_version_references)
  SENSITIVE = []
  include Aws::Structure
end