Class: Aws::Imagebuilder::Types::GetWorkflowStepExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#step_execution_id ⇒ String

The unique identifier for the runtime instance of the workflow step that you want to get runtime details for. To get the identifiers for the steps that ran in a workflow, call ListWorkflowStepExecutions.

Returns:

  • (String)


3900
3901
3902
3903
3904
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3900

class GetWorkflowStepExecutionRequest < Struct.new(
  :step_execution_id)
  SENSITIVE = []
  include Aws::Structure
end