Class: Aws::Imagebuilder::Types::GetWorkflowStepExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action ⇒ String

The name of the action that the specified step performs.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#attempt_number ⇒ Integer

The current attempt number for the specified runtime instance of the workflow step. The first run is attempt one. The number increases by one for each retry.

Returns:

  • (Integer)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Describes the specified workflow step.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#end_time ⇒ String

The timestamp when the specified runtime instance of the workflow step finished.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image build version that owns the specified runtime instance of the workflow step.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#inputs ⇒ String

Input parameters that Image Builder provided for the specified runtime instance of the workflow step, as a JSON-encoded string.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#max_attempts ⇒ Integer

The maximum number of attempts allowed for the specified runtime instance of the workflow step, based on the retry configuration in the workflow document. If the step doesn't configure retries, the maximum is one attempt.

Returns:

  • (Integer)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

The output message from the specified runtime instance of the workflow step, if applicable.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the specified runtime instance of the workflow step.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#on_failure ⇒ String

The action that the workflow takes if this step fails, as configured in the workflow document. Abort fails the workflow and rolls back completed steps. Continue proceeds to the next step. If the step doesn't set a value, it defaults to Abort.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#outputs ⇒ String

The output values that the specified runtime instance of the workflow step produced, as a JSON-encoded string. For example, a step that launches an instance outputs the instance ID. If the step failed, this field contains the error message.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_status ⇒ String

Reports on the rollback status of the specified runtime instance of the workflow step, if applicable. Rollback runs when the workflow execution fails, and undoes the work that completed steps performed.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ String

The timestamp when the specified runtime instance of the workflow step started.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status for the specified runtime instance of the workflow step.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#step_execution_id ⇒ String

The unique identifier for the runtime instance of the workflow step that you specified in the request.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_seconds ⇒ Integer

The maximum duration in seconds for this step to complete its action. If the workflow document doesn't set a timeout for the step, Image Builder applies the default timeout for the step's action. This field returns that value.

Returns:

  • (Integer)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the build version for the Image Builder workflow resource that defines this workflow step.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_execution_id ⇒ String

The unique identifier that Image Builder assigned to keep track of runtime details when it ran the workflow.

Returns:

  • (String)


4009
4010
4011
4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4009

class GetWorkflowStepExecutionResponse < Struct.new(
  :request_id,
  :step_execution_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :on_failure,
  :timeout_seconds,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end