Class: Aws::Imagebuilder::Types::Image

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

An Image Builder image resource that keeps track of all of the settings used to create, configure, and distribute output for that image. An image that Image Builder built from a recipe contains exactly one recipe – either a container recipe (containerRecipe), which creates a container image, or an image recipe (imageRecipe), which creates an AMI. Imported images don't contain a recipe.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the image.

Semantic versioning is included in each object's Amazon Resource Name (ARN), at the level that applies to that object as follows:

  1. Versionless ARNs and Name ARNs do not include specific values in any of the nodes. The nodes are either left off entirely, or they are specified as wildcards, for example: x.x.x.

  2. Version ARNs have only the first three nodes: <major>.<minor>.<patch>

  3. Build version ARNs have all four nodes, and point to a specific build for a specific version of an object.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#build_type ⇒ String

Indicates the type of build that created this image. The build can be initiated in the following ways:

  • USER_INITIATED – A manual pipeline build request.

  • SCHEDULED – A pipeline build initiated by a cron expression in the Image Builder pipeline, or from EventBridge.

  • IMPORT – A VM import created the image to use as the base image for the recipe.

  • IMPORT_ISO – An ISO disk import created the image.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#container_recipe ⇒ Types::ContainerRecipe

For container images, this is the container recipe that Image Builder used to create the image. For images that distribute an AMI, this is empty.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date on which Image Builder created this image.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#deprecation_time ⇒ Time

The time when deprecation occurs for an image resource. This can be a past or future date.

Returns:

  • (Time)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_configuration ⇒ Types::DistributionConfiguration

The distribution configuration that Image Builder used to create this image.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_image_metadata_enabled ⇒ Boolean

Indicates whether Image Builder collects additional information about the image, such as the operating system (OS) version and package list.

Returns:

  • (Boolean)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_recipe ⇒ Types::ImageRecipe

For images that distribute an AMI, this is the image recipe that Image Builder used to create the image. For container images, this is empty.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_scanning_configuration ⇒ Types::ImageScanningConfiguration

Settings for the vulnerability scans that Amazon Inspector runs for this image. For AMI output, Amazon Inspector scans the test instance during image creation. For container output, Amazon Inspector scans the container image in its Amazon ECR repository.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_source ⇒ String

The origin of the base image that Image Builder used to build this image.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_tests_configuration ⇒ Types::ImageTestsConfiguration

The image test settings that Image Builder used when it created this image.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_configuration ⇒ Types::InfrastructureConfiguration

The infrastructure that Image Builder used to create this image.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_execution_id ⇒ String

Identifies the last runtime instance of the lifecycle policy to take action on the image.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configuration ⇒ Types::ImageLoggingConfiguration

The logging configuration that's defined for the image. Image Builder uses the defined settings to direct execution log output during image creation.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the image.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#os_version ⇒ String

The operating system version for instances that launch from this image. For example, Amazon Linux 2, Ubuntu 18, or Microsoft Windows Server 2019.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#output_resources ⇒ Types::OutputResources

The output resources that Image Builder produces for this image.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The image operating system platform, such as Linux or Windows.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#scan_state ⇒ Types::ImageScanState

Contains information about the current state of scans for this image.



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_pipeline_arn ⇒ String

The Amazon Resource Name (ARN) of the image pipeline that created this image. This field is only present for images that a pipeline execution created.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_pipeline_name ⇒ String

The name of the image pipeline that created this image. Image Builder doesn't return this field for new images. Use sourcePipelineArn instead.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::ImageState

The state of the image.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags that apply to this image.

Returns:

  • (Hash<String,String>)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Specifies whether this image produces an AMI or a container image.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The semantic version of the image.

The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.

Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.

Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.

Filtering: You can use wildcards (x) to specify the most recent versions or nodes when selecting the base image or components for your recipe. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards.

Returns:

  • (String)


4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#workflows ⇒ Array<Types::WorkflowConfiguration>

The build, test, and distribution workflow configurations that are associated with the image.

Returns:



4237
4238
4239
4240
4241
4242
4243
4244
4245
4246
4247
4248
4249
4250
4251
4252
4253
4254
4255
4256
4257
4258
4259
4260
4261
4262
4263
4264
4265
4266
4267
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4237

class Image < Struct.new(
  :arn,
  :type,
  :name,
  :version,
  :platform,
  :enhanced_image_metadata_enabled,
  :os_version,
  :state,
  :image_recipe,
  :container_recipe,
  :source_pipeline_name,
  :source_pipeline_arn,
  :infrastructure_configuration,
  :distribution_configuration,
  :image_tests_configuration,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :scan_state,
  :image_scanning_configuration,
  :deprecation_time,
  :lifecycle_execution_id,
  :execution_role,
  :workflows,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end