Class: Aws::Imagebuilder::Types::ImageFailureContext

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains details about the failure when the image creation process fails. Properties appear in the failure context when the related information is available for the failure.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_failure ⇒ Types::ComponentFailureContext

The details about the component that failed, if the failure occurred while a component was running.



4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4332

class ImageFailureContext < Struct.new(
  :image_status,
  :workflow_execution_id,
  :workflow_arn,
  :step_execution_id,
  :failed_step,
  :component_failure,
  :distribution_failure)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_failure ⇒ Types::DistributionFailureContext

The details about the distribution failure, if the failure occurred while Image Builder distributed or configured the image.



4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4332

class ImageFailureContext < Struct.new(
  :image_status,
  :workflow_execution_id,
  :workflow_arn,
  :step_execution_id,
  :failed_step,
  :component_failure,
  :distribution_failure)
  SENSITIVE = []
  include Aws::Structure
end

#failed_step ⇒ String

The name of the workflow step that failed, as it appears in the workflow document.

Returns:

  • (String)


4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4332

class ImageFailureContext < Struct.new(
  :image_status,
  :workflow_execution_id,
  :workflow_arn,
  :step_execution_id,
  :failed_step,
  :component_failure,
  :distribution_failure)
  SENSITIVE = []
  include Aws::Structure
end

#image_status ⇒ String

The status that the image had when the failure occurred. This indicates the stage of the image creation process where the image failed, for example BUILDING or DISTRIBUTING.

Returns:

  • (String)


4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4332

class ImageFailureContext < Struct.new(
  :image_status,
  :workflow_execution_id,
  :workflow_arn,
  :step_execution_id,
  :failed_step,
  :component_failure,
  :distribution_failure)
  SENSITIVE = []
  include Aws::Structure
end

#step_execution_id ⇒ String

The unique identifier of the workflow step execution that failed.

Returns:

  • (String)


4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4332

class ImageFailureContext < Struct.new(
  :image_status,
  :workflow_execution_id,
  :workflow_arn,
  :step_execution_id,
  :failed_step,
  :component_failure,
  :distribution_failure)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_arn ⇒ String

The Amazon Resource Name (ARN) of the workflow build version that was running when the image failed.

Returns:

  • (String)


4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4332

class ImageFailureContext < Struct.new(
  :image_status,
  :workflow_execution_id,
  :workflow_arn,
  :step_execution_id,
  :failed_step,
  :component_failure,
  :distribution_failure)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_execution_id ⇒ String

The unique identifier of the workflow execution that was running when the image failed.

Returns:

  • (String)


4332
4333
4334
4335
4336
4337
4338
4339
4340
4341
4342
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4332

class ImageFailureContext < Struct.new(
  :image_status,
  :workflow_execution_id,
  :workflow_arn,
  :step_execution_id,
  :failed_step,
  :component_failure,
  :distribution_failure)
  SENSITIVE = []
  include Aws::Structure
end