Class: Aws::Imagebuilder::Types::ImageLoggingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The logging configuration that's defined for the image. Image Builder uses the defined settings to direct execution log output during image creation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#log_group_nameString

The log group name that Image Builder uses for image creation. If not specified, the log group name defaults to /aws/imagebuilder/image-name.

Returns:

  • (String)


3854
3855
3856
3857
3858
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3854

class ImageLoggingConfiguration < Struct.new(
  :log_group_name)
  SENSITIVE = []
  include Aws::Structure
end