Class: Aws::Imagebuilder::Types::ImagePackage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

A software package that's installed on an image, as detected by Amazon Web Services Systems Manager Inventory at build time. The list includes packages that shipped with the base image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#package_name ⇒ String

The name of the package that's reported to the operating system package manager.

Returns:

  • (String)


4378
4379
4380
4381
4382
4383
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4378

class ImagePackage < Struct.new(
  :package_name,
  :package_version)
  SENSITIVE = []
  include Aws::Structure
end

#package_version ⇒ String

The version of the package that's reported to the operating system package manager.

Returns:

  • (String)


4378
4379
4380
4381
4382
4383
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4378

class ImagePackage < Struct.new(
  :package_name,
  :package_version)
  SENSITIVE = []
  include Aws::Structure
end