Class: Aws::Imagebuilder::Types::ImagePipeline

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines the automation configuration for building, testing, and distributing images. A pipeline references the resources that its builds use, such as the recipe and infrastructure configuration. It also holds the settings that control its builds, such as the schedule and custom workflows.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the image pipeline.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#consecutive_failures ⇒ Integer

Image Builder tracks the number of consecutive failures for scheduled pipeline executions and takes one of the following actions each time it runs on a schedule:

  • If the pipeline execution is successful, the number of consecutive failures resets to zero.

  • If the pipeline execution fails, Image Builder increments the number of consecutive failures. If the failure count reaches the limit defined in the AutoDisablePolicy, Image Builder disables the pipeline.

The consecutive failure count is also reset to zero under the following conditions:

  • The pipeline runs manually and succeeds.

  • The pipeline configuration is updated.

If the pipeline runs manually and fails, the count remains the same. The next scheduled run continues to increment where it left off before.

Returns:

  • (Integer)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#container_recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the container recipe that is used for this pipeline.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date on which this image pipeline was created.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_last_run ⇒ String

The date on which this image pipeline was last run.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_next_run ⇒ String

The next date when the pipeline is scheduled to run.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_updated ⇒ String

The date on which this image pipeline was last updated.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the image pipeline.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the distribution configuration associated with this image pipeline.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_image_metadata_enabled ⇒ Boolean

Specifies whether to collect additional information about the image being created, including the operating system (OS) version and package list. Defaults to true.

Returns:

  • (Boolean)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the image recipe associated with this image pipeline.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_scanning_configuration ⇒ Types::ImageScanningConfiguration

Contains settings for vulnerability scans that Amazon Inspector runs against the test instance during image creation.



4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_tags ⇒ Hash<String,String>

The tags that Image Builder applies to the Image Builder image resource that this pipeline's scheduled executions create. These tags don't apply to the output AMI. Builds that you start manually use the tags from the StartImagePipelineExecution request instead.

Returns:

  • (Hash<String,String>)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_tests_configuration ⇒ Types::ImageTestsConfiguration

The image tests configuration of the image pipeline.



4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the infrastructure configuration associated with this image pipeline.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#last_run_status ⇒ String

The status of the last image that this pipeline built, such as BUILDING, TESTING, FAILED, or AVAILABLE.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configuration ⇒ Types::PipelineLoggingConfiguration

The CloudWatch Logs configuration for the pipeline: the log group for image build logs and the log group for pipeline execution logs.



4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the image pipeline.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The platform of the image pipeline, inherited from the recipe that the pipeline uses.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#schedule ⇒ Types::Schedule

The schedule of the image pipeline.

Returns:



4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the image pipeline. A disabled pipeline doesn't run on its schedule, but you can still start builds manually. Image Builder can also disable a pipeline automatically when consecutive scheduled builds fail.

Returns:

  • (String)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags of this image pipeline.

Returns:

  • (Hash<String,String>)


4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#workflows ⇒ Array<Types::WorkflowConfiguration>

Contains the workflows that run for the image pipeline.

Returns:



4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
4550
4551
4552
4553
4554
4555
4556
4557
4558
4559
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4532

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end