Class: Aws::Imagebuilder::Types::ImagePipelineAggregation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains vulnerability counts for a specific image pipeline.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_pipeline_arnString

The Amazon Resource Name (ARN) that identifies the image pipeline for this aggregation.

Returns:

  • (String)


4080
4081
4082
4083
4084
4085
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4080

class ImagePipelineAggregation < Struct.new(
  :image_pipeline_arn,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end

#severity_countsTypes::SeverityCounts

Counts by severity level for medium severity and higher level findings, plus a total for all of the findings for the specified image pipeline.



4080
4081
4082
4083
4084
4085
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4080

class ImagePipelineAggregation < Struct.new(
  :image_pipeline_arn,
  :severity_counts)
  SENSITIVE = []
  include Aws::Structure
end