Class: Aws::Imagebuilder::Types::ImageRecipe

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

An image recipe.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_instance_configuration ⇒ Types::AdditionalInstanceConfiguration

Before you create a new AMI, Image Builder launches temporary Amazon EC2 instances to build and test your image configuration. Instance configuration adds a layer of control over those instances. You can define settings and add scripts to run when Image Builder launches your build instance.



4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#ami_tags ⇒ Hash<String,String>

Tags that are applied to the AMI that Image Builder creates during the Build phase prior to image distribution.

Returns:

  • (Hash<String,String>)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#ami_watermarks ⇒ Array<String>

The AMI watermark names attached to the output AMI from this recipe. AMI watermarks are lineage markers that automatically propagate to derivative AMIs when the source AMI is copied or distributed.

Returns:

  • (Array<String>)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#arn ⇒ String

The Amazon Resource Name (ARN) of the image recipe.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#block_device_mappings ⇒ Array<Types::InstanceBlockDeviceMapping>

The block device mappings to apply when creating images from this recipe.



4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#components ⇒ Array<Types::ComponentConfiguration>

The components that are included in the image recipe. A recipe can contain a maximum of 20 build and test components in any combination, by default. This maximum is an adjustable quota. For more information, see EC2 Image Builder endpoints and quotas in the Amazon Web Services General Reference.

Returns:



4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date on which this image recipe was created.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the image recipe.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the image recipe.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the image recipe.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#parent_image ⇒ String

The base image for customizations specified in the image recipe. You can specify the parent image using one of the following options:

  • AMI ID

  • Image Builder image Amazon Resource Name (ARN)

  • Amazon Web Services Systems Manager (SSM) Parameter Store Parameter, prefixed by ssm:, followed by the parameter name or ARN.

  • Amazon Web Services Marketplace product ID

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The platform of the image recipe.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags of the image recipe.

Returns:

  • (Hash<String,String>)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The output image type. For an image recipe, this is always AMI. Container images are built from container recipes, a separate resource. This field isn't currently returned in responses.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the image recipe.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#working_directory ⇒ String

The working directory used during build and test workflows. If you don't specify a working directory, Image Builder uses /tmp for Linux and macOS build instances, and C:/ for Windows build instances.

Returns:

  • (String)


4683
4684
4685
4686
4687
4688
4689
4690
4691
4692
4693
4694
4695
4696
4697
4698
4699
4700
4701
4702
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4683

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end