Class: Aws::Imagebuilder::Types::ImageScanFinding
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImageScanFinding
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Contains details about a vulnerability scan finding.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_account_id ⇒ String
The Amazon Web Services account ID that's associated with the finding.
-
#description ⇒ String
The description of the finding.
-
#first_observed_at ⇒ Time
The date and time when the finding was first observed.
-
#fix_available ⇒ String
Details about whether a fix is available for any of the packages that are identified in the finding through a version update.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version that's associated with the finding.
-
#image_pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the image pipeline that's associated with the finding.
-
#inspector_score ⇒ Float
The score that Amazon Inspector assigned for the finding.
-
#inspector_score_details ⇒ Types::InspectorScoreDetails
An object that contains details of the Amazon Inspector score.
-
#package_vulnerability_details ⇒ Types::PackageVulnerabilityDetails
An object that contains the details of a package vulnerability finding.
-
#remediation ⇒ Types::Remediation
An object that contains the details about how to remediate the finding.
-
#severity ⇒ String
The severity of the finding.
-
#title ⇒ String
The title of the finding.
-
#type ⇒ String
The type of the finding.
-
#updated_at ⇒ Time
The timestamp when the finding was last updated.
Instance Attribute Details
#aws_account_id ⇒ String
The Amazon Web Services account ID that's associated with the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#first_observed_at ⇒ Time
The date and time when the finding was first observed.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#fix_available ⇒ String
Details about whether a fix is available for any of the packages that are identified in the finding through a version update.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version that's associated with the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#image_pipeline_arn ⇒ String
The Amazon Resource Name (ARN) of the image pipeline that's associated with the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#inspector_score ⇒ Float
The score that Amazon Inspector assigned for the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#inspector_score_details ⇒ Types::InspectorScoreDetails
An object that contains details of the Amazon Inspector score.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#package_vulnerability_details ⇒ Types::PackageVulnerabilityDetails
An object that contains the details of a package vulnerability finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#remediation ⇒ Types::Remediation
An object that contains the details about how to remediate the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity of the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of the finding.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the finding. Image Builder looks for findings of the
type PACKAGE_VULNERABILITY that apply to output images, and
excludes other types.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the finding was last updated.
4279 4280 4281 4282 4283 4284 4285 4286 4287 4288 4289 4290 4291 4292 4293 4294 4295 4296 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4279 class ImageScanFinding < Struct.new( :aws_account_id, :image_build_version_arn, :image_pipeline_arn, :type, :description, :title, :remediation, :severity, :first_observed_at, :updated_at, :inspector_score, :inspector_score_details, :package_vulnerability_details, :fix_available) SENSITIVE = [] include Aws::Structure end |