Class: Aws::Imagebuilder::Types::ImageState

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Image status and the reason for that status.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#failure_context ⇒ Types::ImageFailureContext

The details about the failure, for images that failed to complete. Image Builder only sets this property when the image status is FAILED.



4988
4989
4990
4991
4992
4993
4994
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4988

class ImageState < Struct.new(
  :status,
  :reason,
  :failure_context)
  SENSITIVE = []
  include Aws::Structure
end

#reason ⇒ String

The reason for the status of the image.

Returns:

  • (String)


4988
4989
4990
4991
4992
4993
4994
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4988

class ImageState < Struct.new(
  :status,
  :reason,
  :failure_context)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the image. A new image moves through build, test, and distribution statuses during creation, and ends in the AVAILABLE, FAILED, or CANCELLED state. The DEPRECATED, DISABLED, and DELETED statuses come from later resource management actions.

Returns:

  • (String)


4988
4989
4990
4991
4992
4993
4994
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4988

class ImageState < Struct.new(
  :status,
  :reason,
  :failure_context)
  SENSITIVE = []
  include Aws::Structure
end