Class: Aws::Imagebuilder::Types::ImageTestsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Configure image tests for your pipeline build. Tests run after building the image, to verify that the AMI or container image is valid before distributing it.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_tests_enabled ⇒ Boolean

Specifies whether tests run after building the image. When enabled, tests run after the image build and before image distribution. Defaults to true.

Returns:

  • (Boolean)


5123
5124
5125
5126
5127
5128
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5123

class ImageTestsConfiguration < Struct.new(
  :image_tests_enabled,
  :timeout_minutes)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_minutes ⇒ Integer

The maximum time in minutes that tests are permitted to run. If you don't specify a value, Image Builder stores and returns 720.

The timeout property is not currently active. This value is ignored.

Returns:

  • (Integer)


5123
5124
5125
5126
5127
5128
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5123

class ImageTestsConfiguration < Struct.new(
  :image_tests_enabled,
  :timeout_minutes)
  SENSITIVE = []
  include Aws::Structure
end