Class: Aws::Imagebuilder::Types::ImageVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The defining characteristics of a specific version of an Image Builder image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of a specific version of an Image Builder image.

Semantic versioning is included in each object's Amazon Resource Name (ARN), at the level that applies to that object as follows:

  1. Versionless ARNs and Name ARNs do not include specific values in any of the nodes. The nodes are either left off entirely, or they are specified as wildcards, for example: x.x.x.

  2. Version ARNs have only the first three nodes: <major>.<minor>.<patch>

  3. Build version ARNs have all four nodes, and point to a specific build for a specific version of an object.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#build_type ⇒ String

Indicates the type of build that created this image. The build can be initiated in the following ways:

  • USER_INITIATED – A manual pipeline build request.

  • SCHEDULED – A pipeline build initiated by a cron expression in the Image Builder pipeline, or from EventBridge.

  • IMPORT – A VM import created the image to use as the base image for the recipe.

  • IMPORT_ISO – An ISO disk import created the image.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date on which this specific version of the Image Builder image was created.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#image_source ⇒ String

The origin of the base image that Image Builder used to build this image.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of this specific version of an Image Builder image.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#os_version ⇒ String

The operating system version of the image. For example, Amazon Linux 2023 or Microsoft Windows Server 2022.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the image version.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The operating system platform of the image version, for example "Windows" or "Linux".

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Specifies whether this image produces an AMI or a container image.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The semantic version of the image. This version follows the semantic version syntax.

The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.

Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.

Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.

Filtering: You can use wildcards (x) to specify the most recent versions or nodes when selecting the base image or components for your recipe. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards.

Returns:

  • (String)


5228
5229
5230
5231
5232
5233
5234
5235
5236
5237
5238
5239
5240
5241
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5228

class ImageVersion < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :owner,
  :date_created,
  :build_type,
  :image_source)
  SENSITIVE = []
  include Aws::Structure
end