Class: Aws::Imagebuilder::Types::ImportComponentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#change_description ⇒ String

The change description of the component. This description indicates the change that has been made in this version, or what makes this version different from other versions of the component.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#data ⇒ String

The data of the component. For the SHELL format, this is the plain script content. You must specify exactly one of the data or uri properties. For scripts that exceed the inline length constraint, use the uri property.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the component. Describes the contents of the component.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#format ⇒ String

The format of the resource that you want to import as a component.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The Amazon Resource Name (ARN) of the KMS key that is used to encrypt this component. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide. If you don't specify a key, Image Builder encrypts the component data with a KMS key that Image Builder owns.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the component. Image Builder generates the component ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name. If a component with the same name and semantic version already exists in your account in the same Amazon Web Services Region, the request creates a new build version for it. If the content is also identical to the latest build version, the request fails because the component already exists.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#platform ⇒ String

The platform of the component.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#semantic_version ⇒ String

The semantic version of the component. This version follows the semantic version syntax.

The semantic version has four nodes: <major>.<minor>.<patch>/<build>. You can assign values for the first three, and can filter on all of them.

Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.

Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags of the component.

Returns:

  • (Hash<String,String>)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of the component denotes whether the component is used to build the image, or only to test it.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#uri ⇒ String

The uri of the component. Must be an Amazon S3 URL and you must have permission to access the Amazon S3 bucket. If you use Amazon S3, you can specify component content up to your service quota. Either data or uri can be used to specify the data within the component.

Returns:

  • (String)


5348
5349
5350
5351
5352
5353
5354
5355
5356
5357
5358
5359
5360
5361
5362
5363
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5348

class ImportComponentRequest < Struct.new(
  :name,
  :semantic_version,
  :description,
  :change_description,
  :type,
  :format,
  :platform,
  :data,
  :uri,
  :kms_key_id,
  :tags,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end