Class: Aws::Imagebuilder::Types::ImportDiskImageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImportDiskImageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token that uniquely identifies the request.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the Image Builder image resource that this request created.
Instance Attribute Details
#client_token ⇒ String
The client token that uniquely identifies the request.
5504 5505 5506 5507 5508 5509 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5504 class ImportDiskImageResponse < Struct.new( :client_token, :image_build_version_arn) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the Image Builder image resource that this request created. The AMI doesn't exist yet when the response returns. The import runs asynchronously, and the output AMI appears in the image's output resources when the import completes.
5504 5505 5506 5507 5508 5509 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5504 class ImportDiskImageResponse < Struct.new( :client_token, :image_build_version_arn) SENSITIVE = [] include Aws::Structure end |