Class: Aws::Imagebuilder::Types::ImportVmImageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImportVmImageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token that uniquely identifies the request.
-
#image_arn ⇒ String
The Amazon Resource Name (ARN) of the Image Builder image resource that this request created.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#client_token ⇒ String
The client token that uniquely identifies the request.
5620 5621 5622 5623 5624 5625 5626 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5620 class ImportVmImageResponse < Struct.new( :request_id, :image_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#image_arn ⇒ String
The Amazon Resource Name (ARN) of the Image Builder image resource that this request created. Image Builder records the AMI from the VM import task in the image's output resources after the task completes.
5620 5621 5622 5623 5624 5625 5626 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5620 class ImportVmImageResponse < Struct.new( :request_id, :image_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
5620 5621 5622 5623 5624 5625 5626 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5620 class ImportVmImageResponse < Struct.new( :request_id, :image_arn, :client_token) SENSITIVE = [] include Aws::Structure end |