Class: Aws::Imagebuilder::Types::InfrastructureConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Details of the infrastructure configuration.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the infrastructure configuration.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The date on which the infrastructure configuration was created.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#date_updated ⇒ String

The date on which the infrastructure configuration was last updated.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the infrastructure configuration.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#instance_metadata_options ⇒ Types::InstanceMetadataOptions

The instance metadata option settings for the infrastructure configuration.



5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#instance_profile_name ⇒ String

The instance profile of the infrastructure configuration.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#instance_types ⇒ Array<String>

The instance types of the infrastructure configuration.

Returns:

  • (Array<String>)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#key_pair ⇒ String

The Amazon EC2 key pair of the infrastructure configuration.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#logging ⇒ Types::Logging

The logging configuration of the infrastructure configuration. When you configure S3 logs, Image Builder writes logs from the build and test process to the specified bucket under the key prefix.

Returns:



5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the infrastructure configuration.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#placement ⇒ Types::Placement

The instance placement settings that define where the build and test instances that Image Builder launches during image creation run. These settings don't affect instances that you launch from the output image.

Returns:



5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tags ⇒ Hash<String,String>

The metadata tags assigned to the Amazon EC2 build and test instances that Image Builder launches during image creation.

Returns:

  • (Hash<String,String>)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_ids ⇒ Array<String>

The security group IDs of the infrastructure configuration.

Returns:

  • (Array<String>)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arn ⇒ String

The Amazon Resource Name (ARN) of the SNS topic to which Image Builder sends image build event notifications. Specify a standard topic. Image Builder doesn't support FIFO topics.

EC2 Image Builder can't send notifications to SNS topics that are encrypted using keys from other accounts. If your SNS topic is encrypted, the key must be owned by the same account that owns your Image Builder resources.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_id ⇒ String

The subnet ID of the infrastructure configuration.

Returns:

  • (String)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags of the infrastructure configuration.

Returns:

  • (Hash<String,String>)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end

#terminate_instance_on_failure ⇒ Boolean

Indicates whether Image Builder terminates the build and test instances when the image build fails. When false, Image Builder retains the instance so that you can debug it.

Returns:

  • (Boolean)


5718
5719
5720
5721
5722
5723
5724
5725
5726
5727
5728
5729
5730
5731
5732
5733
5734
5735
5736
5737
5738
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5718

class InfrastructureConfiguration < Struct.new(
  :arn,
  :name,
  :description,
  :instance_types,
  :instance_profile_name,
  :security_group_ids,
  :subnet_id,
  :logging,
  :key_pair,
  :terminate_instance_on_failure,
  :sns_topic_arn,
  :date_created,
  :date_updated,
  :resource_tags,
  :instance_metadata_options,
  :tags,
  :placement)
  SENSITIVE = []
  include Aws::Structure
end