Class: Aws::Imagebuilder::Types::InfrastructureConfigurationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::InfrastructureConfigurationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Contains a high-level summary of an infrastructure configuration, including the environment settings that Image Builder uses to build and test images.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration.
-
#date_created ⇒ String
The date on which the infrastructure configuration was created.
-
#date_updated ⇒ String
The date on which the infrastructure configuration was last updated.
-
#description ⇒ String
The description of the infrastructure configuration.
-
#instance_profile_name ⇒ String
The instance profile of the infrastructure configuration.
-
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration.
-
#name ⇒ String
The name of the infrastructure configuration.
-
#placement ⇒ Types::Placement
The instance placement settings that define where the build and test instances that Image Builder launches during image creation run.
-
#resource_tags ⇒ Hash<String,String>
The metadata tags assigned to the Amazon EC2 build and test instances that Image Builder launches during image creation.
-
#tags ⇒ Hash<String,String>
The tags of the infrastructure configuration.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ String
The date on which the infrastructure configuration was created.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#date_updated ⇒ String
The date on which the infrastructure configuration was last updated.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the infrastructure configuration.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#instance_profile_name ⇒ String
The instance profile of the infrastructure configuration.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the infrastructure configuration.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#placement ⇒ Types::Placement
The instance placement settings that define where the build and test instances that Image Builder launches during image creation run. These settings don't affect instances that you launch from the output image.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Hash<String,String>
The metadata tags assigned to the Amazon EC2 build and test instances that Image Builder launches during image creation.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the infrastructure configuration.
5790 5791 5792 5793 5794 5795 5796 5797 5798 5799 5800 5801 5802 5803 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5790 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |