Class: Aws::Imagebuilder::Types::InstanceMetadataOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::InstanceMetadataOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
The instance metadata service (IMDS) settings that Image Builder applies to the EC2 build and test instances it launches. These settings control how software on those instances retrieves instance metadata and IAM role credentials.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#http_put_response_hop_limit ⇒ Integer
Limit the number of hops that an instance metadata request can traverse to reach its destination.
-
#http_tokens ⇒ String
Indicates whether a signed token header is required for instance metadata retrieval requests.
Instance Attribute Details
#http_put_response_hop_limit ⇒ Integer
Limit the number of hops that an instance metadata request can traverse to reach its destination. If you don't set a value, the EC2 launch default for the instance applies. If HTTP tokens are required, container image builds need a minimum of two hops.
5917 5918 5919 5920 5921 5922 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5917 class InstanceMetadataOptions < Struct.new( :http_tokens, :http_put_response_hop_limit) SENSITIVE = [] include Aws::Structure end |
#http_tokens ⇒ String
Indicates whether a signed token header is required for instance metadata retrieval requests. The values affect the response as follows:
-
required – When you retrieve the IAM role credentials, version 2.0 credentials are returned in all cases.
-
optional – You can include a signed token header in your request to retrieve instance metadata, or you can leave it out. If you include it, version 2.0 credentials are returned for the IAM role. Otherwise, version 1.0 credentials are returned.
If you don't set a value, the EC2 launch default applies to the build and test instances. That default depends on the base AMI and any account-level instance metadata defaults. For more information, see Configure the instance metadata options in the Amazon EC2 User Guide .
5917 5918 5919 5920 5921 5922 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5917 class InstanceMetadataOptions < Struct.new( :http_tokens, :http_put_response_hop_limit) SENSITIVE = [] include Aws::Structure end |