Class: Aws::Imagebuilder::Types::InvalidParameterCombinationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

You have specified a combination of parameters that isn't valid. For example, two mutually exclusive parameters, or a parameter without its required companion parameter. Review the error message for details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message ⇒ String

Returns:

  • (String)


5946
5947
5948
5949
5950
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5946

class InvalidParameterCombinationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end