Class: Aws::Imagebuilder::Types::LatestVersionReferences

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#latest_major_version_arn ⇒ String

The latest version Amazon Resource Name (ARN) with the same major version of the Image Builder resource.

Returns:

  • (String)


6034
6035
6036
6037
6038
6039
6040
6041
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6034

class LatestVersionReferences < Struct.new(
  :latest_version_arn,
  :latest_major_version_arn,
  :latest_minor_version_arn,
  :latest_patch_version_arn)
  SENSITIVE = []
  include Aws::Structure
end

#latest_minor_version_arn ⇒ String

The latest version Amazon Resource Name (ARN) with the same minor version of the Image Builder resource.

Returns:

  • (String)


6034
6035
6036
6037
6038
6039
6040
6041
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6034

class LatestVersionReferences < Struct.new(
  :latest_version_arn,
  :latest_major_version_arn,
  :latest_minor_version_arn,
  :latest_patch_version_arn)
  SENSITIVE = []
  include Aws::Structure
end

#latest_patch_version_arn ⇒ String

The latest version Amazon Resource Name (ARN) with the same patch version of the Image Builder resource.

Returns:

  • (String)


6034
6035
6036
6037
6038
6039
6040
6041
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6034

class LatestVersionReferences < Struct.new(
  :latest_version_arn,
  :latest_major_version_arn,
  :latest_minor_version_arn,
  :latest_patch_version_arn)
  SENSITIVE = []
  include Aws::Structure
end

#latest_version_arn ⇒ String

The latest version Amazon Resource Name (ARN) of the Image Builder resource.

Returns:

  • (String)


6034
6035
6036
6037
6038
6039
6040
6041
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6034

class LatestVersionReferences < Struct.new(
  :latest_version_arn,
  :latest_major_version_arn,
  :latest_minor_version_arn,
  :latest_patch_version_arn)
  SENSITIVE = []
  include Aws::Structure
end