Class: Aws::Imagebuilder::Types::LaunchPermissionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Describes the configuration for a launch permission. The launch permission modification request is sent to the Amazon EC2 ModifyImageAttribute API on behalf of the user for each Region they have selected to distribute the AMI. To make an AMI public, set userGroups to the value all. See the examples for making an AMI public at Amazon EC2 ModifyImageAttribute.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#organization_arns ⇒ Array<String>

The ARN for an Amazon Web Services Organization that you want to share your AMI with. For more information, see What is Organizations?.

Returns:

  • (Array<String>)


6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6087

class LaunchPermissionConfiguration < Struct.new(
  :user_ids,
  :user_groups,
  :organization_arns,
  :organizational_unit_arns)
  SENSITIVE = []
  include Aws::Structure
end

#organizational_unit_arns ⇒ Array<String>

The ARN for an Organizations organizational unit (OU) that you want to share your AMI with. For more information about key concepts for Organizations, see Organizations terminology and concepts.

Returns:

  • (Array<String>)


6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6087

class LaunchPermissionConfiguration < Struct.new(
  :user_ids,
  :user_groups,
  :organization_arns,
  :organizational_unit_arns)
  SENSITIVE = []
  include Aws::Structure
end

#user_groups ⇒ Array<String>

The name of the group that you want to grant launch permission to. The only supported value is all, which makes the distributed AMI public.

Returns:

  • (Array<String>)


6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6087

class LaunchPermissionConfiguration < Struct.new(
  :user_ids,
  :user_groups,
  :organization_arns,
  :organizational_unit_arns)
  SENSITIVE = []
  include Aws::Structure
end

#user_ids ⇒ Array<String>

The Amazon Web Services account IDs to grant launch permission to. Each listed account can use the distributed AMI to launch instances.

Returns:

  • (Array<String>)


6087
6088
6089
6090
6091
6092
6093
6094
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6087

class LaunchPermissionConfiguration < Struct.new(
  :user_ids,
  :user_groups,
  :organization_arns,
  :organizational_unit_arns)
  SENSITIVE = []
  include Aws::Structure
end