Class: Aws::Imagebuilder::Types::LaunchTemplateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Identifies an Amazon EC2 launch template to use for a specific account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_id ⇒ String

The account ID that this configuration applies to.

Returns:

  • (String)


6115
6116
6117
6118
6119
6120
6121
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6115

class LaunchTemplateConfiguration < Struct.new(
  :launch_template_id,
  :account_id,
  :set_default_version)
  SENSITIVE = []
  include Aws::Structure
end

#launch_template_id ⇒ String

Identifies the Amazon EC2 launch template to use.

Returns:

  • (String)


6115
6116
6117
6118
6119
6120
6121
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6115

class LaunchTemplateConfiguration < Struct.new(
  :launch_template_id,
  :account_id,
  :set_default_version)
  SENSITIVE = []
  include Aws::Structure
end

#set_default_version ⇒ Boolean

Specifies whether to make the new launch template version that Image Builder creates the default version of the launch template. If you don't set a value, Image Builder treats it as true.

Returns:

  • (Boolean)


6115
6116
6117
6118
6119
6120
6121
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6115

class LaunchTemplateConfiguration < Struct.new(
  :launch_template_id,
  :account_id,
  :set_default_version)
  SENSITIVE = []
  include Aws::Structure
end