Class: Aws::Imagebuilder::Types::LifecycleExecution

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains metadata from a runtime instance of a lifecycle policy.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time ⇒ Time

The timestamp when the lifecycle runtime instance completed.

Returns:

  • (Time)


6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6153

class LifecycleExecution < Struct.new(
  :lifecycle_execution_id,
  :lifecycle_policy_arn,
  :resources_impacted_summary,
  :state,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_execution_id ⇒ String

Identifies the lifecycle policy runtime instance.

Returns:

  • (String)


6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6153

class LifecycleExecution < Struct.new(
  :lifecycle_execution_id,
  :lifecycle_policy_arn,
  :resources_impacted_summary,
  :state,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_policy_arn ⇒ String

The Amazon Resource Name (ARN) of the lifecycle policy that ran.

Returns:

  • (String)


6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6153

class LifecycleExecution < Struct.new(
  :lifecycle_execution_id,
  :lifecycle_policy_arn,
  :resources_impacted_summary,
  :state,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#resources_impacted_summary ⇒ Types::LifecycleExecutionResourcesImpactedSummary

A summary flag that indicates whether the lifecycle execution identified any resources to take lifecycle actions on.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6153

class LifecycleExecution < Struct.new(
  :lifecycle_execution_id,
  :lifecycle_policy_arn,
  :resources_impacted_summary,
  :state,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

The timestamp when the lifecycle runtime instance started.

Returns:

  • (Time)


6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6153

class LifecycleExecution < Struct.new(
  :lifecycle_execution_id,
  :lifecycle_policy_arn,
  :resources_impacted_summary,
  :state,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::LifecycleExecutionState

Runtime state that reports whether the lifecycle execution is in progress, succeeded, or failed.



6153
6154
6155
6156
6157
6158
6159
6160
6161
6162
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6153

class LifecycleExecution < Struct.new(
  :lifecycle_execution_id,
  :lifecycle_policy_arn,
  :resources_impacted_summary,
  :state,
  :start_time,
  :end_time)
  SENSITIVE = []
  include Aws::Structure
end