Class: Aws::Imagebuilder::Types::LifecycleExecutionResourcesImpactedSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains an indicator that shows whether the lifecycle execution identified any resources to take lifecycle actions on.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#has_impacted_resources ⇒ Boolean

Indicates whether the lifecycle execution identified any resources to take lifecycle actions on.

Returns:

  • (Boolean)


6284
6285
6286
6287
6288
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6284

class LifecycleExecutionResourcesImpactedSummary < Struct.new(
  :has_impacted_resources)
  SENSITIVE = []
  include Aws::Structure
end