Class: Aws::Imagebuilder::Types::LifecycleExecutionSnapshotResource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains the state of an impacted snapshot resource that the runtime instance of the lifecycle policy identified for action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#snapshot_id ⇒ String

Identifies the impacted snapshot resource.

Returns:

  • (String)


6303
6304
6305
6306
6307
6308
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6303

class LifecycleExecutionSnapshotResource < Struct.new(
  :snapshot_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::LifecycleExecutionResourceState

The runtime status of the lifecycle action taken for the snapshot.



6303
6304
6305
6306
6307
6308
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6303

class LifecycleExecutionSnapshotResource < Struct.new(
  :snapshot_id,
  :state)
  SENSITIVE = []
  include Aws::Structure
end