Class: Aws::Imagebuilder::Types::LifecyclePolicy

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines a lifecycle policy resource: its identity, status, execution role, resource type, rules, resource selection, timestamps, and tags.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the lifecycle policy resource.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ Time

The timestamp when Image Builder created the lifecycle policy resource.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#date_last_run ⇒ Time

The timestamp for the last time Image Builder ran the lifecycle policy.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#date_updated ⇒ Time

The timestamp when Image Builder updated the lifecycle policy resource.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Optional description for the lifecycle policy.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The name or Amazon Resource Name (ARN) of the IAM role that Image Builder uses to run the lifecycle policy. This is a custom role that you create.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the lifecycle policy.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#policy_details ⇒ Array<Types::LifecyclePolicyDetail>

The list of rules for the lifecycle policy. Each rule pairs an action with a filter and optional exclusion rules. A policy can contain at most one rule per action type.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_selection ⇒ Types::LifecyclePolicyResourceSelection

Resource selection criteria used to run the lifecycle policy.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#resource_type ⇒ String

The type of resources the lifecycle policy targets.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Indicates whether the lifecycle policy resource is enabled. Only enabled policies run on their schedule. Disabling or deleting a policy removes its schedule and cancels any in-flight lifecycle execution.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

To help manage your lifecycle policy resources, you can assign your own metadata to each resource in the form of tags. Each tag consists of a key and an optional value, both of which you define.

Returns:



6394
6395
6396
6397
6398
6399
6400
6401
6402
6403
6404
6405
6406
6407
6408
6409
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6394

class LifecyclePolicy < Struct.new(
  :arn,
  :name,
  :description,
  :status,
  :execution_role,
  :resource_type,
  :policy_details,
  :resource_selection,
  :date_created,
  :date_updated,
  :date_last_run,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end