Class: Aws::Imagebuilder::Types::LifecyclePolicyDetailAction

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains the action configuration for a lifecycle policy rule: the action to take, and which underlying resources the action extends to.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#include_resources ⇒ Types::LifecyclePolicyDetailActionIncludeResources

Specifies which underlying resources the action extends to beyond the Image Builder image resource itself: distributed AMIs, their snapshots, or distributed container images. DELETE rules can include all three, DEPRECATE and DISABLE rules can include AMIs only, and you can only include snapshots together with AMIs.



6459
6460
6461
6462
6463
6464
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6459

class LifecyclePolicyDetailAction < Struct.new(
  :type,
  :include_resources)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Specifies the lifecycle action to take. DELETE deletes the image resource and, with includeResources, also removes distributed AMIs, snapshots, or container images. DEPRECATE and DISABLE set the corresponding status on the image resource and, if includeResources.amis is set, on its distributed AMIs.

Returns:

  • (String)


6459
6460
6461
6462
6463
6464
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6459

class LifecyclePolicyDetailAction < Struct.new(
  :type,
  :include_resources)
  SENSITIVE = []
  include Aws::Structure
end