Class: Aws::Imagebuilder::Types::LifecyclePolicyDetailActionIncludeResources

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Specifies how the lifecycle policy should apply actions to selected resources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amis ⇒ Boolean

Specifies whether the lifecycle action should apply to distributed AMIs.

Returns:

  • (Boolean)


6486
6487
6488
6489
6490
6491
6492
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6486

class LifecyclePolicyDetailActionIncludeResources < Struct.new(
  :amis,
  :snapshots,
  :containers)
  SENSITIVE = []
  include Aws::Structure
end

#containers ⇒ Boolean

Specifies whether the lifecycle action should apply to distributed containers.

Returns:

  • (Boolean)


6486
6487
6488
6489
6490
6491
6492
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6486

class LifecyclePolicyDetailActionIncludeResources < Struct.new(
  :amis,
  :snapshots,
  :containers)
  SENSITIVE = []
  include Aws::Structure
end

#snapshots ⇒ Boolean

Specifies whether the lifecycle action should apply to snapshots associated with distributed AMIs.

Returns:

  • (Boolean)


6486
6487
6488
6489
6490
6491
6492
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6486

class LifecyclePolicyDetailActionIncludeResources < Struct.new(
  :amis,
  :snapshots,
  :containers)
  SENSITIVE = []
  include Aws::Structure
end