Class: Aws::Imagebuilder::Types::LifecyclePolicyDetailExclusionRulesAmisLastLaunched

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines criteria to exclude AMIs from lifecycle actions based on the last time they were used to launch an instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#unit ⇒ String

Defines the unit of time that the lifecycle policy uses to calculate elapsed time since the last launch.

Returns:

  • (String)


6570
6571
6572
6573
6574
6575
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6570

class LifecyclePolicyDetailExclusionRulesAmisLastLaunched < Struct.new(
  :value,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end

#value ⇒ Integer

The integer number of units for the time period. For example 6 (months).

Returns:

  • (Integer)


6570
6571
6572
6573
6574
6575
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6570

class LifecyclePolicyDetailExclusionRulesAmisLastLaunched < Struct.new(
  :value,
  :unit)
  SENSITIVE = []
  include Aws::Structure
end