Class: Aws::Imagebuilder::Types::LifecyclePolicyResourceSelection

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Resource selection criteria for the lifecycle policy. You must provide exactly one selection criteria: either recipes or a tag map, not both.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#recipes ⇒ Array<Types::LifecyclePolicyResourceSelectionRecipe>

A list of recipes that are used as selection criteria for the output images that the lifecycle policy applies to.



6635
6636
6637
6638
6639
6640
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6635

class LifecyclePolicyResourceSelection < Struct.new(
  :recipes,
  :tag_map)
  SENSITIVE = []
  include Aws::Structure
end

#tag_map ⇒ Hash<String,String>

A list of tags that are used as selection criteria for the Image Builder image resources that the lifecycle policy applies to.

Returns:

  • (Hash<String,String>)


6635
6636
6637
6638
6639
6640
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6635

class LifecyclePolicyResourceSelection < Struct.new(
  :recipes,
  :tag_map)
  SENSITIVE = []
  include Aws::Structure
end