Class: Aws::Imagebuilder::Types::ListComponentBuildVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#component_version_arn ⇒ String

The component version ARN whose build versions you want to list. The ARN must specify an exact version, without a build number suffix. If you don't specify an ARN, Image Builder returns build versions for the components that your account owns.

Returns:

  • (String)


6747
6748
6749
6750
6751
6752
6753
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6747

class ListComponentBuildVersionsRequest < Struct.new(
  :component_version_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return in a single request.

Returns:

  • (Integer)


6747
6748
6749
6750
6751
6752
6753
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6747

class ListComponentBuildVersionsRequest < Struct.new(
  :component_version_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to specify where to start paginating. Use the nextToken value from a previously truncated response.

Returns:

  • (String)


6747
6748
6749
6750
6751
6752
6753
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6747

class ListComponentBuildVersionsRequest < Struct.new(
  :component_version_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end