Class: Aws::Imagebuilder::Types::ListComponentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#by_name ⇒ Boolean

Specifies whether to return one entry per component name, with all versions of each component aggregated. Defaults to false, which returns one entry per component version. You can't combine this option with the version filter.

Returns:

  • (Boolean)


6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6830

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filters ⇒ Array<Types::Filter>

Use the following filters to streamline results:

  • description

  • name

  • platform

  • productCodes

  • status

  • supportedOsVersion

  • type

  • version

Returns:



6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6830

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return in a single request.

Returns:

  • (Integer)


6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6830

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to specify where to start paginating. Use the nextToken value from a previously truncated response.

Returns:

  • (String)


6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6830

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

Filters results based on the type of owner for the component. By default, this request returns a list of components that your account owns. To see results for other types of owners, you can specify components that Amazon manages, components from the Amazon Web Services Marketplace, third party components, or components that other accounts have shared with you.

Returns:

  • (String)


6830
6831
6832
6833
6834
6835
6836
6837
6838
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6830

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end