Method: Aws::Imagebuilder::Types::ListComponentsRequest#owner

Defined in:
lib/aws-sdk-imagebuilder/types.rb

#ownerString

Filters results based on the type of owner for the component. By default, this request returns a list of components that your account owns. To see results for other types of owners, you can specify components that Amazon manages, third party components, or components that other accounts have shared with you.

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6144

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end