Class: Aws::Imagebuilder::Types::ListContainerRecipesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#container_recipe_summary_list ⇒ Array<Types::ContainerRecipeSummary>

The list of container recipes returned for the request.

Returns:



6927
6928
6929
6930
6931
6932
6933
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6927

class ListContainerRecipesResponse < Struct.new(
  :request_id,
  :container_recipe_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.

Returns:

  • (String)


6927
6928
6929
6930
6931
6932
6933
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6927

class ListContainerRecipesResponse < Struct.new(
  :request_id,
  :container_recipe_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


6927
6928
6929
6930
6931
6932
6933
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6927

class ListContainerRecipesResponse < Struct.new(
  :request_id,
  :container_recipe_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end