Class: Aws::Imagebuilder::Types::ListDistributionConfigurationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListDistributionConfigurationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
You can filter on
nameto streamline results. -
#max_results ⇒ Integer
The maximum number of items to return in a single request.
-
#next_token ⇒ String
A token to specify where to start paginating.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
You can filter on name to streamline results.
6950 6951 6952 6953 6954 6955 6956 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6950 class ListDistributionConfigurationsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in a single request.
6950 6951 6952 6953 6954 6955 6956 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6950 class ListDistributionConfigurationsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. Use the nextToken
value from a previously truncated response.
6950 6951 6952 6953 6954 6955 6956 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6950 class ListDistributionConfigurationsRequest < Struct.new( :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |