Class: Aws::Imagebuilder::Types::ListImageBuildVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListImageBuildVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_summary_list ⇒ Array<Types::ImageSummary>
The list of image build versions.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#image_summary_list ⇒ Array<Types::ImageSummary>
The list of image build versions.
7042 7043 7044 7045 7046 7047 7048 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7042 class ListImageBuildVersionsResponse < Struct.new( :request_id, :image_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
7042 7043 7044 7045 7046 7047 7048 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7042 class ListImageBuildVersionsResponse < Struct.new( :request_id, :image_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
7042 7043 7044 7045 7046 7047 7048 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7042 class ListImageBuildVersionsResponse < Struct.new( :request_id, :image_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |