Class: Aws::Imagebuilder::Types::ListImagePackagesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image build version whose packages you want to list. The value must be a full build version ARN.

Returns:

  • (String)


7067
7068
7069
7070
7071
7072
7073
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7067

class ListImagePackagesRequest < Struct.new(
  :image_build_version_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return in a single request.

Returns:

  • (Integer)


7067
7068
7069
7070
7071
7072
7073
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7067

class ListImagePackagesRequest < Struct.new(
  :image_build_version_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to specify where to start paginating. Use the nextToken value from a previously truncated response.

Returns:

  • (String)


7067
7068
7069
7070
7071
7072
7073
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7067

class ListImagePackagesRequest < Struct.new(
  :image_build_version_arn,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end