Class: Aws::Imagebuilder::Types::ListImagePipelineImagesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filters ⇒ Array<Types::Filter>

Use the following filters to streamline results:

  • name

  • version

Returns:



7124
7125
7126
7127
7128
7129
7130
7131
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7124

class ListImagePipelineImagesRequest < Struct.new(
  :image_pipeline_arn,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#image_pipeline_arn ⇒ String

The Amazon Resource Name (ARN) of the image pipeline whose images you want to view.

Returns:

  • (String)


7124
7125
7126
7127
7128
7129
7130
7131
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7124

class ListImagePipelineImagesRequest < Struct.new(
  :image_pipeline_arn,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return in a single request.

Returns:

  • (Integer)


7124
7125
7126
7127
7128
7129
7130
7131
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7124

class ListImagePipelineImagesRequest < Struct.new(
  :image_pipeline_arn,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to specify where to start paginating. Use the nextToken value from a previously truncated response.

Returns:

  • (String)


7124
7125
7126
7127
7128
7129
7130
7131
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7124

class ListImagePipelineImagesRequest < Struct.new(
  :image_pipeline_arn,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end