Class: Aws::Imagebuilder::Types::ListImageRecipesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filters ⇒ Array<Types::Filter>

Use the following filters to streamline results:

  • name

  • parentImage

  • platform

Returns:



7246
7247
7248
7249
7250
7251
7252
7253
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7246

class ListImageRecipesRequest < Struct.new(
  :owner,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return in a single request.

Returns:

  • (Integer)


7246
7247
7248
7249
7250
7251
7252
7253
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7246

class ListImageRecipesRequest < Struct.new(
  :owner,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to specify where to start paginating. Use the nextToken value from a previously truncated response.

Returns:

  • (String)


7246
7247
7248
7249
7250
7251
7252
7253
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7246

class ListImageRecipesRequest < Struct.new(
  :owner,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

You can specify the recipe owner to filter results by that owner. By default, this request will only show image recipes owned by your account. To filter by a different owner, specify one of the Valid Values that are listed for this parameter.

Returns:

  • (String)


7246
7247
7248
7249
7250
7251
7252
7253
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7246

class ListImageRecipesRequest < Struct.new(
  :owner,
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end