Class: Aws::Imagebuilder::Types::ListImageRecipesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_recipe_summary_list ⇒ Array<Types::ImageRecipeSummary>

A list of ImageRecipeSummary objects that contain identifying characteristics for the image recipe, such as the name, the Amazon Resource Name (ARN), and the date created, along with other key details.

Returns:



7275
7276
7277
7278
7279
7280
7281
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7275

class ListImageRecipesResponse < Struct.new(
  :request_id,
  :image_recipe_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.

Returns:

  • (String)


7275
7276
7277
7278
7279
7280
7281
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7275

class ListImageRecipesResponse < Struct.new(
  :request_id,
  :image_recipe_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


7275
7276
7277
7278
7279
7280
7281
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7275

class ListImageRecipesResponse < Struct.new(
  :request_id,
  :image_recipe_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end