Class: Aws::Imagebuilder::Types::ListImageScanFindingAggregationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_type ⇒ String

The aggregation type specifies what type of key is used to group the image scan findings. Image Builder returns results based on the request filter. If you didn't specify a filter in the request, the type defaults to accountId.

Aggregation types

  • accountId

  • imageBuildVersionArn

  • imagePipelineArn

  • vulnerabilityId

Each aggregation includes counts by severity level for medium severity and higher level findings, plus a total for all of the findings for each key value.

Returns:

  • (String)


7350
7351
7352
7353
7354
7355
7356
7357
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7350

class ListImageScanFindingAggregationsResponse < Struct.new(
  :request_id,
  :aggregation_type,
  :responses,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.

Returns:

  • (String)


7350
7351
7352
7353
7354
7355
7356
7357
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7350

class ListImageScanFindingAggregationsResponse < Struct.new(
  :request_id,
  :aggregation_type,
  :responses,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


7350
7351
7352
7353
7354
7355
7356
7357
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7350

class ListImageScanFindingAggregationsResponse < Struct.new(
  :request_id,
  :aggregation_type,
  :responses,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#responses ⇒ Array<Types::ImageScanFindingAggregation>

An array of image scan finding aggregations that match the filter criteria.



7350
7351
7352
7353
7354
7355
7356
7357
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7350

class ListImageScanFindingAggregationsResponse < Struct.new(
  :request_id,
  :aggregation_type,
  :responses,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end