Class: Aws::Imagebuilder::Types::ListImageScanFindingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filters ⇒ Array<Types::ImageScanFindingsFilter>

An array of name value pairs that you can use to filter your results. You can use the following filters to streamline results:

  • imageBuildVersionArn – Filters findings by the image build version that was scanned.

  • imagePipelineArn – Filters findings by the pipeline that created the scanned image.

  • vulnerabilityId – Filters findings by vulnerability ID, for example a CVE ID.

  • severity – Filters findings by severity level.

If you don't request a filter, then all findings in your account are listed.

Returns:



7389
7390
7391
7392
7393
7394
7395
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7389

class ListImageScanFindingsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

The maximum number of items to return in a single request.

Returns:

  • (Integer)


7389
7390
7391
7392
7393
7394
7395
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7389

class ListImageScanFindingsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

A token to specify where to start paginating. Use the nextToken value from a previously truncated response.

Returns:

  • (String)


7389
7390
7391
7392
7393
7394
7395
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7389

class ListImageScanFindingsRequest < Struct.new(
  :filters,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end