Class: Aws::Imagebuilder::Types::ListImageScanFindingsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#findings ⇒ Array<Types::ImageScanFinding>

The image scan findings for your account that meet your request filter criteria.

Returns:



7415
7416
7417
7418
7419
7420
7421
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7415

class ListImageScanFindingsResponse < Struct.new(
  :request_id,
  :findings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.

Returns:

  • (String)


7415
7416
7417
7418
7419
7420
7421
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7415

class ListImageScanFindingsResponse < Struct.new(
  :request_id,
  :findings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#request_id ⇒ String

The request ID that uniquely identifies this request.

Returns:

  • (String)


7415
7416
7417
7418
7419
7420
7421
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7415

class ListImageScanFindingsResponse < Struct.new(
  :request_id,
  :findings,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end