Class: Aws::Imagebuilder::Types::ListImagesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListImagesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#by_name ⇒ Boolean
Specifies whether to return one entry per image name, with all versions of each image aggregated.
-
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results:.
-
#include_deprecated ⇒ Boolean
Specifies whether to include deprecated Amazon-managed images in the results.
-
#max_results ⇒ Integer
The maximum number of items to return in a single request.
-
#next_token ⇒ String
A token to specify where to start paginating.
-
#owner ⇒ String
Filters the list to images owned by you, by Amazon, or shared with you by other accounts.
Instance Attribute Details
#by_name ⇒ Boolean
Specifies whether to return one entry per image name, with all
versions of each image aggregated. Defaults to false, which
returns one entry per image version. You can't combine this option
with the version filter.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7467 class ListImagesRequest < Struct.new( :owner, :filters, :by_name, :max_results, :next_token, :include_deprecated) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results:
-
name -
osVersion -
platform -
type -
version
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7467 class ListImagesRequest < Struct.new( :owner, :filters, :by_name, :max_results, :next_token, :include_deprecated) SENSITIVE = [] include Aws::Structure end |
#include_deprecated ⇒ Boolean
Specifies whether to include deprecated Amazon-managed images in the
results. Deprecated images that you own are always returned.
Defaults to false.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7467 class ListImagesRequest < Struct.new( :owner, :filters, :by_name, :max_results, :next_token, :include_deprecated) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in a single request.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7467 class ListImagesRequest < Struct.new( :owner, :filters, :by_name, :max_results, :next_token, :include_deprecated) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. Use the nextToken
value from a previously truncated response.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7467 class ListImagesRequest < Struct.new( :owner, :filters, :by_name, :max_results, :next_token, :include_deprecated) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
Filters the list to images owned by you, by Amazon, or shared with you by other accounts. By default, only your account's images are returned.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7467 class ListImagesRequest < Struct.new( :owner, :filters, :by_name, :max_results, :next_token, :include_deprecated) SENSITIVE = [] include Aws::Structure end |