Class: Aws::Imagebuilder::Types::ListLifecyclePoliciesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lifecycle_policy_summary_list ⇒ Array<Types::LifecyclePolicySummary>

A list of lifecycle policies in your Amazon Web Services account that meet the criteria specified in the request.

Returns:



7715
7716
7717
7718
7719
7720
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7715

class ListLifecyclePoliciesResponse < Struct.new(
  :lifecycle_policy_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.

Returns:

  • (String)


7715
7716
7717
7718
7719
7720
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7715

class ListLifecyclePoliciesResponse < Struct.new(
  :lifecycle_policy_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end