Class: Aws::Imagebuilder::Types::OutputResources

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The resources produced by this image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amis ⇒ Array<Types::Ami>

The Amazon EC2 AMIs created by this image. The list contains one entry per AMI, including copies that distribution created in each target Amazon Web Services Region and account.

Returns:



8066
8067
8068
8069
8070
8071
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8066

class OutputResources < Struct.new(
  :amis,
  :containers)
  SENSITIVE = []
  include Aws::Structure
end

#containers ⇒ Array<Types::Container>

The container images that Image Builder created when it built this image, stored in the output Amazon ECR repository.

Returns:



8066
8067
8068
8069
8070
8071
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8066

class OutputResources < Struct.new(
  :amis,
  :containers)
  SENSITIVE = []
  include Aws::Structure
end