Class: Aws::Imagebuilder::Types::PackageVulnerabilityDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Information about package vulnerability findings.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cvssArray<Types::CvssScore>

CVSS scores for one or more vulnerabilities that Amazon Inspector identified for a package.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#reference_urlsArray<String>

Links to web pages that contain details about the vulnerabilities that Amazon Inspector identified for the package.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

Vulnerabilities that are often related to the findings for the package.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source of the vulnerability information.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#source_urlString

A link to the source of the vulnerability information.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_created_atTime

The date and time when this vulnerability was first added to the vendor’s database.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_severityString

The severity that the vendor assigned to this vulnerability type.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#vendor_updated_atTime

The date and time when the vendor last updated this vulnerability in their database.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#vulnerability_idString

A unique identifier for this vulnerability.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end

#vulnerable_packagesArray<Types::VulnerablePackage>

The packages that this vulnerability impacts.



7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7386

class PackageVulnerabilityDetails < Struct.new(
  :vulnerability_id,
  :vulnerable_packages,
  :source,
  :cvss,
  :related_vulnerabilities,
  :source_url,
  :vendor_severity,
  :vendor_created_at,
  :vendor_updated_at,
  :reference_urls)
  SENSITIVE = []
  include Aws::Structure
end