Class: Aws::Imagebuilder::Types::PipelineLoggingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The logging configuration that's defined for pipeline execution.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_log_group_name ⇒ String

Specifies the CloudWatch Logs log group name for image build logs. The log group name can contain alphanumeric characters, hyphens, underscores, forward slashes, and periods, up to 512 characters. Log group names not starting with /aws/imagebuilder/ require an executionRole with CloudWatch Logs write permissions. If not specified, defaults to /aws/imagebuilder/image-name.

Returns:

  • (String)


8161
8162
8163
8164
8165
8166
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8161

class PipelineLoggingConfiguration < Struct.new(
  :image_log_group_name,
  :pipeline_log_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_log_group_name ⇒ String

Specifies the CloudWatch Logs log group name for pipeline execution logs. The log group name can contain alphanumeric characters, hyphens, underscores, forward slashes, and periods, up to 512 characters. Log group names not starting with /aws/imagebuilder/ require an executionRole with CloudWatch Logs write permissions. If not specified, defaults to /aws/imagebuilder/pipeline/pipeline-name.

Returns:

  • (String)


8161
8162
8163
8164
8165
8166
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8161

class PipelineLoggingConfiguration < Struct.new(
  :image_log_group_name,
  :pipeline_log_group_name)
  SENSITIVE = []
  include Aws::Structure
end