Class: Aws::Imagebuilder::Types::Placement

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

By default, EC2 instances run on shared tenancy hardware. This means that multiple Amazon Web Services accounts might share the same physical hardware. When you use dedicated hardware, the physical server that hosts your instances is dedicated to your Amazon Web Services account. Instance placement settings contain the details for the physical hardware where instances that Image Builder launches during image creation will run.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#availability_zone ⇒ String

The Availability Zone where your build and test instances will launch.

Returns:

  • (String)


8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8206

class Placement < Struct.new(
  :availability_zone,
  :tenancy,
  :host_id,
  :host_resource_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#host_id ⇒ String

The ID of the Dedicated Host on which build and test instances run. This only applies if tenancy is host.

Returns:

  • (String)


8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8206

class Placement < Struct.new(
  :availability_zone,
  :tenancy,
  :host_id,
  :host_resource_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#host_resource_group_arn ⇒ String

The Amazon Resource Name (ARN) of the host resource group in which to launch build and test instances. This only applies if tenancy is host.

Returns:

  • (String)


8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8206

class Placement < Struct.new(
  :availability_zone,
  :tenancy,
  :host_id,
  :host_resource_group_arn)
  SENSITIVE = []
  include Aws::Structure
end

#tenancy ⇒ String

The tenancy of the instance. An instance with a tenancy of dedicated runs on single-tenant hardware. An instance with a tenancy of host runs on a Dedicated Host.

If tenancy is set to host, then you can optionally specify one target for placement – either host ID or host resource group ARN. If automatic placement is enabled for your host, and you don't specify any placement target, Amazon EC2 will try to find an available host for your build and test instances.

Returns:

  • (String)


8206
8207
8208
8209
8210
8211
8212
8213
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8206

class Placement < Struct.new(
  :availability_zone,
  :tenancy,
  :host_id,
  :host_resource_group_arn)
  SENSITIVE = []
  include Aws::Structure
end