Class: Aws::Imagebuilder::Types::PutImagePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::PutImagePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_arn ⇒ String
The Amazon Resource Name (ARN) of the image that this policy should be applied to.
-
#policy ⇒ String
The resource policy to apply to the image, as a JSON policy document.
Instance Attribute Details
#image_arn ⇒ String
The Amazon Resource Name (ARN) of the image that this policy should be applied to.
8324 8325 8326 8327 8328 8329 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8324 class PutImagePolicyRequest < Struct.new( :image_arn, :policy) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The resource policy to apply to the image, as a JSON policy
document. Image Builder validates the policy with Amazon Web
Services RAM before applying it, and rejects invalid policies with
InvalidParameterValueException.
8324 8325 8326 8327 8328 8329 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8324 class PutImagePolicyRequest < Struct.new( :image_arn, :policy) SENSITIVE = [] include Aws::Structure end |