Class: Aws::Imagebuilder::Types::RegionFailure

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains details about a distribution or image configuration failure for a single Region.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#error_message ⇒ String

The error message for the failure in the Region.



8417
8418
8419
8420
8421
8422
8423
8424
8425
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8417

class RegionFailure < Struct.new(
  :region,
  :status,
  :image_configuration_step,
  :error_message,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#image_configuration_step ⇒ String

The image configuration step where the failure occurred. Image Builder sets this property when the failure happened during post-distribution configuration, such as launch template updates or virtual machine (VM) export. This property doesn't appear for failures that occurred while Image Builder copied the image to the Region.



8417
8418
8419
8420
8421
8422
8423
8424
8425
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8417

class RegionFailure < Struct.new(
  :region,
  :status,
  :image_configuration_step,
  :error_message,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#region ⇒ String

The Region where the failure occurred.



8417
8418
8419
8420
8421
8422
8423
8424
8425
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8417

class RegionFailure < Struct.new(
  :region,
  :status,
  :image_configuration_step,
  :error_message,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The failure status for the Region. Indicates whether the process failed, was canceled, or timed out.



8417
8418
8419
8420
8421
8422
8423
8424
8425
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8417

class RegionFailure < Struct.new(
  :region,
  :status,
  :image_configuration_step,
  :error_message,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#target_account_id ⇒ String

The account ID of the account that the image was distributed to in the Region.



8417
8418
8419
8420
8421
8422
8423
8424
8425
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8417

class RegionFailure < Struct.new(
  :region,
  :status,
  :image_configuration_step,
  :error_message,
  :target_account_id)
  SENSITIVE = []
  include Aws::Structure
end