Class: Aws::Imagebuilder::Types::RemediationRecommendation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Details about the recommended course of action to remediate the finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#text ⇒ String

The recommended course of action to remediate the finding.

Returns:

  • (String)


8494
8495
8496
8497
8498
8499
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8494

class RemediationRecommendation < Struct.new(
  :text,
  :url)
  SENSITIVE = []
  include Aws::Structure
end

#url ⇒ String

A link to more information about the recommended remediation for this vulnerability.

Returns:

  • (String)


8494
8495
8496
8497
8498
8499
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8494

class RemediationRecommendation < Struct.new(
  :text,
  :url)
  SENSITIVE = []
  include Aws::Structure
end