Class: Aws::Imagebuilder::Types::ResourceStateUpdateExclusionRules

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Additional rules to specify resources that should be exempt from ad-hoc lifecycle actions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#amis ⇒ Types::LifecyclePolicyDetailExclusionRulesAmis

Defines criteria for AMIs that Image Builder should exclude from the resource state update.



8583
8584
8585
8586
8587
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8583

class ResourceStateUpdateExclusionRules < Struct.new(
  :amis)
  SENSITIVE = []
  include Aws::Structure
end