Class: Aws::Imagebuilder::Types::ResourceStateUpdateIncludeResources
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ResourceStateUpdateIncludeResources
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Specifies which underlying resources the resource state update applies to, in addition to the Image Builder image resource itself: distributed AMIs and their snapshots for AMI images, or distributed container images for container images.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#amis ⇒ Boolean
Specifies whether the lifecycle action should apply to distributed AMIs.
-
#containers ⇒ Boolean
Specifies whether the lifecycle action should apply to distributed containers.
-
#snapshots ⇒ Boolean
Specifies whether the lifecycle action should apply to snapshots associated with distributed AMIs.
Instance Attribute Details
#amis ⇒ Boolean
Specifies whether the lifecycle action should apply to distributed AMIs.
8611 8612 8613 8614 8615 8616 8617 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8611 class ResourceStateUpdateIncludeResources < Struct.new( :amis, :snapshots, :containers) SENSITIVE = [] include Aws::Structure end |
#containers ⇒ Boolean
Specifies whether the lifecycle action should apply to distributed containers.
8611 8612 8613 8614 8615 8616 8617 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8611 class ResourceStateUpdateIncludeResources < Struct.new( :amis, :snapshots, :containers) SENSITIVE = [] include Aws::Structure end |
#snapshots ⇒ Boolean
Specifies whether the lifecycle action should apply to snapshots associated with distributed AMIs.
8611 8612 8613 8614 8615 8616 8617 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8611 class ResourceStateUpdateIncludeResources < Struct.new( :amis, :snapshots, :containers) SENSITIVE = [] include Aws::Structure end |