Class: Aws::Imagebuilder::Types::S3ExportConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Properties that configure exporting the output image to a disk image file in an Amazon S3 bucket, in a format that's compatible with your VMs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#disk_image_format ⇒ String

Export the updated image to one of the following supported disk image formats:

  • Virtual Hard Disk (VHD) – Compatible with Citrix Xen and Microsoft Hyper-V virtualization products.

  • Stream-optimized ESX Virtual Machine Disk (VMDK) – Compatible with VMware ESX and VMware vSphere versions 4, 5, and 6.

  • Raw – Raw format.

Returns:

  • (String)


8699
8700
8701
8702
8703
8704
8705
8706
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8699

class S3ExportConfiguration < Struct.new(
  :role_name,
  :disk_image_format,
  :s3_bucket,
  :s3_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#role_name ⇒ String

The name of the role that grants VM Import/Export permission to export images to your S3 bucket.

Returns:

  • (String)


8699
8700
8701
8702
8703
8704
8705
8706
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8699

class S3ExportConfiguration < Struct.new(
  :role_name,
  :disk_image_format,
  :s3_bucket,
  :s3_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucket ⇒ String

The S3 bucket in which to store the output disk images for your VM.

Returns:

  • (String)


8699
8700
8701
8702
8703
8704
8705
8706
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8699

class S3ExportConfiguration < Struct.new(
  :role_name,
  :disk_image_format,
  :s3_bucket,
  :s3_prefix)
  SENSITIVE = []
  include Aws::Structure
end

#s3_prefix ⇒ String

The Amazon S3 path for the bucket where the output disk images for your VM are stored.

Returns:

  • (String)


8699
8700
8701
8702
8703
8704
8705
8706
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8699

class S3ExportConfiguration < Struct.new(
  :role_name,
  :disk_image_format,
  :s3_bucket,
  :s3_prefix)
  SENSITIVE = []
  include Aws::Structure
end