Class: Aws::Imagebuilder::Types::Schedule

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

A schedule configures when and how often a pipeline will automatically create a new image.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_disable_policy ⇒ Types::AutoDisablePolicy

The policy that configures when Image Builder should automatically disable a pipeline that is failing.



8794
8795
8796
8797
8798
8799
8800
8801
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8794

class Schedule < Struct.new(
  :schedule_expression,
  :timezone,
  :pipeline_execution_start_condition,
  :auto_disable_policy)
  SENSITIVE = []
  include Aws::Structure
end

#pipeline_execution_start_condition ⇒ String

The start condition configures when the pipeline should trigger a new image build, as follows. If no value is set Image Builder defaults to EXPRESSION_MATCH_AND_DEPENDENCY_UPDATES_AVAILABLE.

  • EXPRESSION_MATCH_AND_DEPENDENCY_UPDATES_AVAILABLE (default) – When you use semantic version filters on the base image or components in your image recipe, EC2 Image Builder builds a new image only when there are new versions of the base image or components in your recipe that match the filter.

    For semantic version syntax, see CreateComponent.

  • EXPRESSION_MATCH_ONLY – This condition builds a new image every time the CRON expression matches the current time.

If the recipe references its base image through an Amazon Web Services Systems Manager Parameter Store parameter, a change in the parameter's value also counts as an available dependency update.

Returns:

  • (String)


8794
8795
8796
8797
8798
8799
8800
8801
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8794

class Schedule < Struct.new(
  :schedule_expression,
  :timezone,
  :pipeline_execution_start_condition,
  :auto_disable_policy)
  SENSITIVE = []
  include Aws::Structure
end

#schedule_expression ⇒ String

The expression determines how often EC2 Image Builder evaluates your pipelineExecutionStartCondition. You can specify a cron expression, or a rate expression such as rate(1 day).

For information on how to format a cron expression in Image Builder, see Use cron expressions in EC2 Image Builder.

Returns:

  • (String)


8794
8795
8796
8797
8798
8799
8800
8801
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8794

class Schedule < Struct.new(
  :schedule_expression,
  :timezone,
  :pipeline_execution_start_condition,
  :auto_disable_policy)
  SENSITIVE = []
  include Aws::Structure
end

#timezone ⇒ String

The timezone that applies to the scheduling expression. Specify a value in IANA timezone format, for example Etc/UTC or America/Los_Angeles. If not specified, this defaults to UTC.

Returns:

  • (String)


8794
8795
8796
8797
8798
8799
8800
8801
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8794

class Schedule < Struct.new(
  :schedule_expression,
  :timezone,
  :pipeline_execution_start_condition,
  :auto_disable_policy)
  SENSITIVE = []
  include Aws::Structure
end