Class: Aws::Imagebuilder::Types::SendWorkflowStepActionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action ⇒ String

The action to perform on the paused workflow step. RESUME completes the waiting step, and the workflow continues. STOP fails the step, and the step's onFailure setting determines whether the workflow continues or aborts. The workflow step must be in a waiting state to accept an action. The request fails if the step has already timed out or been actioned.

Returns:

  • (String)


8848
8849
8850
8851
8852
8853
8854
8855
8856
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8848

class SendWorkflowStepActionRequest < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :action,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


8848
8849
8850
8851
8852
8853
8854
8855
8856
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8848

class SendWorkflowStepActionRequest < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :action,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image build version associated with the workflow step execution. This value must match the image that owns the waiting step. If the ARN does not correspond to the image running the workflow, then the request fails with a validation error.

Returns:

  • (String)


8848
8849
8850
8851
8852
8853
8854
8855
8856
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8848

class SendWorkflowStepActionRequest < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :action,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#reason ⇒ String

The reason for the action. This value is stored with the step execution record and is accessible in subsequent workflow steps via step output references.

Returns:

  • (String)


8848
8849
8850
8851
8852
8853
8854
8855
8856
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8848

class SendWorkflowStepActionRequest < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :action,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#step_execution_id ⇒ String

Uniquely identifies the waiting workflow step that you send the action to. To get this identifier, call ListWaitingWorkflowSteps.

Returns:

  • (String)


8848
8849
8850
8851
8852
8853
8854
8855
8856
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8848

class SendWorkflowStepActionRequest < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :action,
  :reason,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end