Class: Aws::Imagebuilder::Types::SendWorkflowStepActionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

The client token that uniquely identifies the request.

Returns:

  • (String)


8874
8875
8876
8877
8878
8879
8880
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8874

class SendWorkflowStepActionResponse < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the image build version that received the action request.

Returns:

  • (String)


8874
8875
8876
8877
8878
8879
8880
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8874

class SendWorkflowStepActionResponse < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#step_execution_id ⇒ String

The unique identifier for the workflow step that received the action, as specified in the request.

Returns:

  • (String)


8874
8875
8876
8877
8878
8879
8880
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8874

class SendWorkflowStepActionResponse < Struct.new(
  :step_execution_id,
  :image_build_version_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end