Class: Aws::Imagebuilder::Types::StartImagePipelineExecutionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


9017
9018
9019
9020
9021
9022
9023
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9017

class StartImagePipelineExecutionRequest < Struct.new(
  :image_pipeline_arn,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_pipeline_arn ⇒ String

The Amazon Resource Name (ARN) of the image pipeline that you want to manually invoke.

Returns:

  • (String)


9017
9018
9019
9020
9021
9022
9023
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9017

class StartImagePipelineExecutionRequest < Struct.new(
  :image_pipeline_arn,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags for Image Builder to apply to the image resource that's created when pipeline execution starts.

Returns:

  • (Hash<String,String>)


9017
9018
9019
9020
9021
9022
9023
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9017

class StartImagePipelineExecutionRequest < Struct.new(
  :image_pipeline_arn,
  :client_token,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end