Class: Aws::Imagebuilder::Types::StartResourceStateUpdateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#exclusion_rules ⇒ Types::ResourceStateUpdateExclusionRules

Rules that Image Builder evaluates against each of the image's AMIs. Matching AMIs and their snapshots are skipped. Exclusion rules only take effect when the request includes AMIs. If the target state is DELETED and any resource was skipped, the Image Builder image resource itself is also retained. For the DEPRECATED and DISABLED target states, Image Builder updates the image resource's state regardless of exclusions.



9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The name or Amazon Resource Name (ARN) of the IAM role that's used to update image state. You must provide this property together with includeResources. Neither is valid without the other.

Returns:

  • (String)


9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#include_resources ⇒ Types::ResourceStateUpdateIncludeResources

Specifies which underlying resources to update, in addition to the Image Builder image resource itself. Snapshots and containers are only valid for the DELETED state. To set an image to DELETED, you must include its underlying resources. To delete only the Image Builder image record, use the DeleteImage operation instead.



9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arn ⇒ String

The Amazon Resource Name (ARN) of the image build version to update. The image must be in one of these terminal states: AVAILABLE, DEPRECATED, DISABLED, FAILED, or CANCELLED. Images with FAILED or CANCELLED status can transition only to DELETED.

Returns:

  • (String)


9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::ResourceState

Specifies the lifecycle action to take for this request. For AMI-based images, valid values are AVAILABLE, DEPRECATED, DISABLED, and DELETED. For container-based images, only DELETED is supported.



9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#update_at ⇒ Time

The timestamp that indicates when resources are updated by a lifecycle action. This property is valid only when the target status is DEPRECATED, and the value must be a future time. If you don't specify a value, Image Builder begins the state update right away. For a scheduled deprecation, included AMIs get their EC2 deprecation time set immediately, and Image Builder schedules the image resource to transition to DEPRECATED at that time.

Returns:

  • (Time)


9113
9114
9115
9116
9117
9118
9119
9120
9121
9122
9123
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end