Class: Aws::Imagebuilder::Types::StartResourceStateUpdateResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lifecycle_execution_id ⇒ String

Identifies the lifecycle execution that performs the resource state update. Image Builder only returns this field when it started a lifecycle execution for the update. Use it with GetLifecycleExecution to track progress.

Returns:

  • (String)


9139
9140
9141
9142
9143
9144
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9139

class StartResourceStateUpdateResponse < Struct.new(
  :lifecycle_execution_id,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arn ⇒ String

The requested Amazon Resource Name (ARN) of the Image Builder resource for the asynchronous update.

Returns:

  • (String)


9139
9140
9141
9142
9143
9144
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9139

class StartResourceStateUpdateResponse < Struct.new(
  :lifecycle_execution_id,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end