Class: Aws::Imagebuilder::Types::SystemsManagerAgent

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains settings for the Systems Manager agent on your build instance. This setting applies to Linux and macOS build instances only. Requests that set it for a recipe with a Windows base image are rejected.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#uninstall_after_build ⇒ Boolean

Specifies whether the Systems Manager agent is removed from your final build image before Image Builder creates the new AMI. If true, the agent is removed. If false, the agent is kept, so that it's included in the AMI. If you don't set this property, Image Builder removes the agent only if Image Builder installed the agent during the build. An agent that was pre-installed on the base image is kept.

Returns:

  • (Boolean)


9163
9164
9165
9166
9167
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9163

class SystemsManagerAgent < Struct.new(
  :uninstall_after_build)
  SENSITIVE = []
  include Aws::Structure
end