Class: Aws::Imagebuilder::Types::TargetContainerRepository

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The container repository where the output container image is stored.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#repository_name ⇒ String

The name of the container repository where the output container image is stored. Provide the repository name only (a namespace path such as team-a/my-repo is allowed, but not the registry hostname).

Returns:

  • (String)


9204
9205
9206
9207
9208
9209
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9204

class TargetContainerRepository < Struct.new(
  :service,
  :repository_name)
  SENSITIVE = []
  include Aws::Structure
end

#service ⇒ String

Specifies the service in which this image was registered.

Returns:

  • (String)


9204
9205
9206
9207
9208
9209
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9204

class TargetContainerRepository < Struct.new(
  :service,
  :repository_name)
  SENSITIVE = []
  include Aws::Structure
end