Class: Aws::Imagebuilder::Types::UpdateImagePipelineRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_token ⇒ String

A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#container_recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the container recipe that is used to configure images created by this container pipeline. You must specify either this property or imageRecipeArn, but not both.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the image pipeline.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the distribution configuration that Image Builder uses to configure and distribute images created by this image pipeline.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_image_metadata_enabled ⇒ Boolean

Specifies whether to collect additional information about the image being created, including the operating system (OS) version and package list. Defaults to true.

Returns:

  • (Boolean)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_role ⇒ String

The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions. If you omit this property, the pipeline reverts to the Image Builder service-linked role.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_pipeline_arn ⇒ String

The Amazon Resource Name (ARN) of the image pipeline that you want to update.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_recipe_arn ⇒ String

The Amazon Resource Name (ARN) of the image recipe that configures images created by this image pipeline. You must specify either this property or containerRecipeArn, but not both.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_scanning_configuration ⇒ Types::ImageScanningConfiguration

Contains settings for vulnerability scans that Amazon Inspector runs against the test instance during image creation.



9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_tags ⇒ Hash<String,String>

The tags that Image Builder applies to the Image Builder image resource that this pipeline's scheduled executions create. These tags don't apply to the output AMI. To tag output AMIs, use amiTags in the pipeline's distribution configuration.

Returns:

  • (Hash<String,String>)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_tests_configuration ⇒ Types::ImageTestsConfiguration

Specifies the test settings that Image Builder applies to images that this pipeline creates. If you don't provide test settings, Image Builder stores a default configuration with image tests enabled.



9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_configuration_arn ⇒ String

The Amazon Resource Name (ARN) of the infrastructure configuration that Image Builder uses to build images created by this image pipeline.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configuration ⇒ Types::PipelineLoggingConfiguration

Specifies the logging configuration for the image pipeline. Use this to define custom CloudWatch Logs log groups for your pipeline execution logs and image build logs. The service manages log groups with names starting with /aws/imagebuilder/ using the service-linked role. For custom log group names outside of this prefix, you must also provide an executionRole.



9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#schedule ⇒ Types::Schedule

The schedule of the image pipeline. Because the update replaces the entire configuration, omitting this property removes any existing schedule. The pipeline then runs only when you call StartImagePipelineExecution.

Returns:



9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the image pipeline. Defaults to ENABLED when omitted. To keep a pipeline disabled, include this property set to DISABLED in your update request.

Returns:

  • (String)


9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#workflows ⇒ Array<Types::WorkflowConfiguration>

The array of workflow configuration objects for builds that this pipeline starts. You must also specify executionRole when you provide workflows.

Returns:



9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9421

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end