Class: Aws::Imagebuilder::Types::UpdateInfrastructureConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::UpdateInfrastructureConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#description ⇒ String
The description of the infrastructure configuration.
-
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that you want to update.
-
#instance_metadata_options ⇒ Types::InstanceMetadataOptions
The instance metadata options that you can set for the HTTP requests that pipeline builds use to launch EC2 build and test instances.
-
#instance_profile_name ⇒ String
The instance profile to associate with the instance used to customize your Amazon EC2 AMI.
-
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration.
-
#key_pair ⇒ String
The key pair of the infrastructure configuration.
-
#logging ⇒ Types::Logging
The logging configuration of the infrastructure configuration.
-
#placement ⇒ Types::Placement
The instance placement settings that define where the instances that are launched from your image will run.
-
#resource_tags ⇒ Hash<String,String>
The tags attached to the resource created by Image Builder.
-
#security_group_ids ⇒ Array<String>
The security group IDs to associate with the instance used to customize your Amazon EC2 AMI.
-
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) for the SNS topic to which we send image build event notifications.
-
#subnet_id ⇒ String
The subnet ID to place the instance used to customize your Amazon EC2 AMI in.
-
#terminate_instance_on_failure ⇒ Boolean
The terminate instance on failure setting of the infrastructure configuration.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the infrastructure configuration.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that you want to update.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_options ⇒ Types::InstanceMetadataOptions
The instance metadata options that you can set for the HTTP requests that pipeline builds use to launch EC2 build and test instances. For more information about instance metadata options, see one of the following links:
-
Configure the instance metadata options in the Amazon EC2 User Guide for Linux instances.
-
Configure the instance metadata options in the Amazon EC2 Windows Guide for Windows instances.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_profile_name ⇒ String
The instance profile to associate with the instance used to customize your Amazon EC2 AMI.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration. You can specify one or more instance types to use for this build. The service will pick one of these instance types based on availability.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#key_pair ⇒ String
The key pair of the infrastructure configuration. You can use this to log on to and debug the instance used to create your image.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::Logging
The logging configuration of the infrastructure configuration.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#placement ⇒ Types::Placement
The instance placement settings that define where the instances that are launched from your image will run.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Hash<String,String>
The tags attached to the resource created by Image Builder.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security group IDs to associate with the instance used to customize your Amazon EC2 AMI.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) for the SNS topic to which we send image build event notifications.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The subnet ID to place the instance used to customize your Amazon EC2 AMI in.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |
#terminate_instance_on_failure ⇒ Boolean
The terminate instance on failure setting of the infrastructure configuration. Set to false if you want Image Builder to retain the instance used to configure your AMI if the build or test phase of your workflow fails.
8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8661 class UpdateInfrastructureConfigurationRequest < Struct.new( :infrastructure_configuration_arn, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :resource_tags, :instance_metadata_options, :placement, :client_token) SENSITIVE = [] include Aws::Structure end |