Class: Aws::Imagebuilder::Types::VulnerablePackage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Information about a vulnerable package that Amazon Inspector identifies in a finding.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arch ⇒ String

The architecture of the vulnerable package.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#epoch ⇒ Integer

The epoch of the vulnerable package.

Returns:

  • (Integer)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#file_path ⇒ String

The file path of the vulnerable package.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#fixed_in_version ⇒ String

The version of the package that contains the vulnerability fix.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the vulnerable package.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#package_manager ⇒ String

The package manager of the vulnerable package.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#release ⇒ String

The release of the vulnerable package.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#remediation ⇒ String

The code to run in your environment to update packages with a fix available.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#source_layer_hash ⇒ String

The source layer hash of the vulnerable package.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the vulnerable package.

Returns:

  • (String)


9775
9776
9777
9778
9779
9780
9781
9782
9783
9784
9785
9786
9787
9788
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9775

class VulnerablePackage < Struct.new(
  :name,
  :version,
  :source_layer_hash,
  :epoch,
  :release,
  :arch,
  :package_manager,
  :file_path,
  :fixed_in_version,
  :remediation)
  SENSITIVE = []
  include Aws::Structure
end