Class: Aws::Imagebuilder::Types::WindowsConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Windows-specific configuration settings for an ISO import, including the edition to install from a multi-edition Windows ISO file.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_indexInteger

The 1-based index that specifies which Windows edition to install from a multi-edition Windows ISO file. A Windows ISO can contain a .wim file with multiple image indexes, each representing a different edition.

Returns:

  • (Integer)


8974
8975
8976
8977
8978
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8974

class WindowsConfiguration < Struct.new(
  :image_index)
  SENSITIVE = []
  include Aws::Structure
end