Class: Aws::Imagebuilder::Types::Workflow

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines a process that Image Builder runs during the build, test, or distribution stage of the image creation process.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the workflow resource.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#change_description ⇒ String

Describes what change has been made in this version of the workflow, or what makes this version different from other versions of the workflow.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#data ⇒ String

Contains the YAML document content for the workflow.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The timestamp when Image Builder created the workflow resource.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the workflow.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_id ⇒ String

The KMS key identifier used to encrypt the workflow resource. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the workflow resource.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the workflow resource.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parameters ⇒ Array<Types::WorkflowParameterDetail>

An array of input parameters that the image workflow uses to control actions or configure settings.

Returns:



9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::WorkflowState

Describes the current status of the workflow and the reason for that status.



9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags that apply to the workflow resource.

Returns:

  • (Hash<String,String>)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The image creation stage that the workflow applies to.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The workflow resource version. Workflow resources are immutable. To make a change, you can clone a workflow or create a new version.

Returns:

  • (String)


9877
9878
9879
9880
9881
9882
9883
9884
9885
9886
9887
9888
9889
9890
9891
9892
9893
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9877

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end