Class: Aws::Imagebuilder::Types::WorkflowExecutionMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Metadata that includes details and status from this runtime instance of the workflow.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time ⇒ String

The timestamp when this runtime instance of the workflow finished.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

The runtime output message from the workflow, if applicable.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#parallel_group ⇒ String

The name of the test group that included the test workflow resource at runtime.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#retried ⇒ Boolean

Indicates whether a retry of the image build superseded this runtime instance of the workflow. When you retry a failed image build, Image Builder sets this flag to true on the original workflow executions that the retry re-ran.

Returns:

  • (Boolean)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ String

The timestamp when the runtime instance of this workflow started.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current runtime status for this workflow.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#total_step_count ⇒ Integer

The total number of steps that the workflow document defines for this runtime instance of the workflow. Image Builder sets this count before any steps run. The sum of succeeded, skipped, and failed steps only reaches this total if every step finishes in one of those states.

Returns:

  • (Integer)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_failed ⇒ Integer

A runtime count for the number of steps in the workflow that failed.

Returns:

  • (Integer)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_skipped ⇒ Integer

A runtime count for the number of steps in the workflow that were skipped.

Returns:

  • (Integer)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_succeeded ⇒ Integer

A runtime count for the number of steps in the workflow that ran successfully.

Returns:

  • (Integer)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

Indicates what type of workflow that Image Builder ran for this runtime instance of the workflow.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_build_version_arn ⇒ String

The Amazon Resource Name (ARN) of the workflow resource build version that ran.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_execution_id ⇒ String

Unique identifier that Image Builder assigns to keep track of runtime resources each time it runs a workflow.

Returns:

  • (String)


10005
10006
10007
10008
10009
10010
10011
10012
10013
10014
10015
10016
10017
10018
10019
10020
10021
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10005

class WorkflowExecutionMetadata < Struct.new(
  :workflow_build_version_arn,
  :workflow_execution_id,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group,
  :retried)
  SENSITIVE = []
  include Aws::Structure
end