Class: Aws::Imagebuilder::Types::WorkflowParameterDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines a parameter that's used to provide configuration details for the workflow.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#default_value ⇒ Array<String>

The default value of this parameter if no input is provided.

Returns:

  • (Array<String>)


9482
9483
9484
9485
9486
9487
9488
9489
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9482

class WorkflowParameterDetail < Struct.new(
  :name,
  :type,
  :default_value,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Describes this parameter.

Returns:

  • (String)


9482
9483
9484
9485
9486
9487
9488
9489
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9482

class WorkflowParameterDetail < Struct.new(
  :name,
  :type,
  :default_value,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of this input parameter.

Returns:

  • (String)


9482
9483
9484
9485
9486
9487
9488
9489
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9482

class WorkflowParameterDetail < Struct.new(
  :name,
  :type,
  :default_value,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The type of input this parameter provides. The currently supported value is "string".

Returns:

  • (String)


9482
9483
9484
9485
9486
9487
9488
9489
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9482

class WorkflowParameterDetail < Struct.new(
  :name,
  :type,
  :default_value,
  :description)
  SENSITIVE = []
  include Aws::Structure
end