Class: Aws::Imagebuilder::Types::WorkflowStepMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Runtime details and status for the workflow step.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action ⇒ String

The step action name.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#attempt_number ⇒ Integer

The current attempt number for the workflow step. The first run is attempt one. The number increases by one for each retry.

Returns:

  • (Integer)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Description of the workflow step.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#end_time ⇒ String

The timestamp when the workflow step finished.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#inputs ⇒ String

Input parameters that Image Builder provides for the workflow step, as a JSON-encoded string.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#max_attempts ⇒ Integer

The maximum number of attempts allowed for the workflow step, based on the retry configuration in the workflow document. If the step doesn't configure retries, the maximum is one attempt.

Returns:

  • (Integer)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#message ⇒ String

Detailed output message that the workflow step provides at runtime.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the workflow step.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#outputs ⇒ String

The output values that the workflow step produced for this runtime instance of the workflow, as a JSON-encoded string. For example, a step that launches an instance outputs the instance ID. If the step failed, this field contains the error message.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#rollback_status ⇒ String

Reports on the rollback status of the step, if applicable.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ String

The timestamp when the workflow step started.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

Runtime status for the workflow step.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end

#step_execution_id ⇒ String

A unique identifier for the workflow step, assigned at runtime.

Returns:

  • (String)


10204
10205
10206
10207
10208
10209
10210
10211
10212
10213
10214
10215
10216
10217
10218
10219
10220
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10204

class  < Struct.new(
  :step_execution_id,
  :name,
  :description,
  :action,
  :status,
  :rollback_status,
  :message,
  :inputs,
  :outputs,
  :start_time,
  :end_time,
  :attempt_number,
  :max_attempts)
  SENSITIVE = []
  include Aws::Structure
end