Class: Aws::Imagebuilder::Types::WorkflowSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains metadata about the workflow resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the workflow resource.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#change_description ⇒ String

The change description for the current version of the workflow resource.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The original creation date of the workflow resource.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Describes the workflow.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the workflow.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the workflow resource.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#state ⇒ Types::WorkflowState

Describes the current state of the workflow resource.



10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Contains a list of tags that are defined for the workflow.

Returns:

  • (Hash<String,String>)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The image creation stage that this workflow applies to.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The version of the workflow.

Returns:

  • (String)


10267
10268
10269
10270
10271
10272
10273
10274
10275
10276
10277
10278
10279
10280
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10267

class WorkflowSummary < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :owner,
  :state,
  :date_created,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end