Class: Aws::Imagebuilder::Types::WorkflowVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Contains details about this version of the workflow.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the workflow resource.

Returns:

  • (String)


10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10315

class WorkflowVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :type,
  :owner,
  :date_created)
  SENSITIVE = []
  include Aws::Structure
end

#date_created ⇒ String

The timestamp when Image Builder created the workflow version.

Returns:

  • (String)


10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10315

class WorkflowVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :type,
  :owner,
  :date_created)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

Describes the workflow.

Returns:

  • (String)


10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10315

class WorkflowVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :type,
  :owner,
  :date_created)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the workflow.

Returns:

  • (String)


10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10315

class WorkflowVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :type,
  :owner,
  :date_created)
  SENSITIVE = []
  include Aws::Structure
end

#owner ⇒ String

The owner of the workflow resource.

Returns:

  • (String)


10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10315

class WorkflowVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :type,
  :owner,
  :date_created)
  SENSITIVE = []
  include Aws::Structure
end

#type ⇒ String

The image creation stage that this workflow applies to.

Returns:

  • (String)


10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10315

class WorkflowVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :type,
  :owner,
  :date_created)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ String

The semantic version of the workflow resource. The format includes three nodes: <major>.<minor>.<patch>.

Returns:

  • (String)


10315
10316
10317
10318
10319
10320
10321
10322
10323
10324
10325
# File 'lib/aws-sdk-imagebuilder/types.rb', line 10315

class WorkflowVersion < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :type,
  :owner,
  :date_created)
  SENSITIVE = []
  include Aws::Structure
end