Class: Aws::Imagebuilder::Types::Component
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::Component
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
A detailed view of a component.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the component.
-
#change_description ⇒ String
Describes what change has been made in this version of the component, or what makes this version different from other versions of the component.
-
#data ⇒ String
Component data contains the YAML document content for the component.
-
#date_created ⇒ String
The date that Image Builder created the component.
-
#description ⇒ String
The description of the component.
-
#encrypted ⇒ Boolean
Indicates whether the component data is encrypted at rest.
-
#kms_key_id ⇒ String
The KMS key identifier used to encrypt the component.
-
#name ⇒ String
The name of the component.
-
#obfuscate ⇒ Boolean
Indicates whether component source is hidden from view in the console, and from component detail results for API, CLI, or SDK operations.
-
#owner ⇒ String
The owner of the component.
-
#parameters ⇒ Array<Types::ComponentParameterDetail>
Contains parameter details for each of the parameters that the component document defined for the component.
-
#platform ⇒ String
The operating system platform of the component.
-
#product_codes ⇒ Array<Types::ProductCodeListItem>
Contains product codes that are used for billing purposes for Amazon Web Services Marketplace components.
-
#publisher ⇒ String
Contains the name of the publisher if this is a third-party component.
-
#state ⇒ Types::ComponentState
Describes the current status of the component.
-
#supported_os_versions ⇒ Array<String>
The operating system (OS) version supported by the component.
-
#tags ⇒ Hash<String,String>
The tags that apply to the component.
-
#type ⇒ String
The component type specifies whether Image Builder uses the component to build the image or only to test it.
-
#version ⇒ String
The version of the component.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#change_description ⇒ String
Describes what change has been made in this version of the component, or what makes this version different from other versions of the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#data ⇒ String
Component data contains the YAML document content for the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ String
The date that Image Builder created the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Indicates whether the component data is encrypted at rest. Image
Builder encrypts all component data at rest, so this value is always
true. This field is retained for backward compatibility.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The KMS key identifier used to encrypt the component. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#obfuscate ⇒ Boolean
Indicates whether component source is hidden from view in the console, and from component detail results for API, CLI, or SDK operations.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the component. The value is your account ID for
components that you own, the sharing account's ID for shared
components, or Amazon, ThirdParty, or AWSMarketplace.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::ComponentParameterDetail>
Contains parameter details for each of the parameters that the component document defined for the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system platform of the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#product_codes ⇒ Array<Types::ProductCodeListItem>
Contains product codes that are used for billing purposes for Amazon Web Services Marketplace components.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#publisher ⇒ String
Contains the name of the publisher if this is a third-party component. Otherwise, this property is empty.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#state ⇒ Types::ComponentState
Describes the current status of the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#supported_os_versions ⇒ Array<String>
The operating system (OS) version supported by the component. If the OS information is available, Image Builder performs a prefix match against the base image OS version during image recipe creation.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that apply to the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The component type specifies whether Image Builder uses the component to build the image or only to test it.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the component.
445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 445 class Component < Struct.new( :arn, :name, :version, :description, :change_description, :type, :platform, :supported_os_versions, :state, :parameters, :owner, :data, :kms_key_id, :encrypted, :date_created, :tags, :publisher, :obfuscate, :product_codes) SENSITIVE = [] include Aws::Structure end |