Class: Aws::Imagebuilder::Types::ContainerRecipe
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ContainerRecipe
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Defines how Image Builder builds and tests a container image: the base image, components to apply, the Dockerfile template, the build and test instance configuration, and the target repository for the output image.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe.
-
#components ⇒ Array<Types::ComponentConfiguration>
Build and test components that are included in the container recipe.
-
#container_type ⇒ String
Specifies the type of container, such as Docker.
-
#date_created ⇒ String
The date when this container recipe was created.
-
#description ⇒ String
The description of the container recipe.
-
#dockerfile_template_data ⇒ String
The Dockerfile template that Image Builder uses to build the container image.
-
#encrypted ⇒ Boolean
Specifies whether the recipe's Dockerfile template data is encrypted at rest.
-
#instance_configuration ⇒ Types::InstanceConfiguration
A group of options that can be used to configure an instance for building and testing container images.
-
#kms_key_id ⇒ String
The KMS key that Image Builder uses to encrypt the recipe's Dockerfile template data at rest.
-
#name ⇒ String
The name of the container recipe.
-
#owner ⇒ String
The owner of the container recipe.
-
#parent_image ⇒ String
The base image for customizations specified in the container recipe.
-
#platform ⇒ String
The system platform for the container.
-
#tags ⇒ Hash<String,String>
Tags that are attached to the container recipe.
-
#target_repository ⇒ Types::TargetContainerRepository
The destination repository for the container image.
-
#version ⇒ String
The semantic version of the container recipe.
-
#working_directory ⇒ String
The working directory for use during build and test workflows.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe.
-
Versionless ARNs and Name ARNs do not include specific values in any of the nodes. The nodes are either left off entirely, or they are specified as wildcards, for example: x.x.x.
-
Version ARNs have only the first three nodes: <major>.<minor>.<patch>
-
Build version ARNs have all four nodes, and point to a specific build for a specific version of an object.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#components ⇒ Array<Types::ComponentConfiguration>
Build and test components that are included in the container recipe. A recipe can contain a maximum of 20 build and test components in any combination, by default. This maximum is an adjustable quota. For more information, see EC2 Image Builder endpoints and quotas in the Amazon Web Services General Reference.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#container_type ⇒ String
Specifies the type of container, such as Docker.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ String
The date when this container recipe was created.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the container recipe.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#dockerfile_template_data ⇒ String
The Dockerfile template that Image Builder uses to build the container image. The template can include contextual variables that Image Builder replaces with build information at build time. For the contextual variables that the template can include, see Create a new version of a container recipe in the EC2 Image Builder User Guide.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Specifies whether the recipe's Dockerfile template data is
encrypted at rest. Image Builder encrypts all Dockerfile template
data at rest, so this value is always true. This field is retained
for backward compatibility, and doesn't describe encryption of the
output container image.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#instance_configuration ⇒ Types::InstanceConfiguration
A group of options that can be used to configure an instance for building and testing container images.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The KMS key that Image Builder uses to encrypt the recipe's Dockerfile template data at rest. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide. If you don't specify a key, Image Builder encrypts the template data with a KMS key that Image Builder owns. This key isn't used to encrypt the output container image.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the container recipe.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the container recipe.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#parent_image ⇒ String
The base image for customizations specified in the container recipe.
This can contain an Image Builder image resource ARN or a container
image URI, for example amazonlinux:latest.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The system platform for the container. Container recipes support only the Linux and Windows platforms.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags that are attached to the container recipe.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#target_repository ⇒ Types::TargetContainerRepository
The destination repository for the container image.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The semantic version of the container recipe.
Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.
Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.
Filtering: You can use wildcards (x) to specify the most recent versions or nodes when selecting the base image or components for your recipe. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |
#working_directory ⇒ String
The working directory for use during build and test workflows.
996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 996 class ContainerRecipe < Struct.new( :arn, :container_type, :name, :description, :platform, :owner, :version, :components, :instance_configuration, :dockerfile_template_data, :kms_key_id, :encrypted, :parent_image, :date_created, :tags, :working_directory, :target_repository) SENSITIVE = [] include Aws::Structure end |