Class: Aws::Imagebuilder::Types::CreateContainerRecipeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CreateContainerRecipeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token that uniquely identifies the request.
-
#container_recipe_arn ⇒ String
Returns the Amazon Resource Name (ARN) of the container recipe that the request created.
-
#latest_version_references ⇒ Types::LatestVersionReferences
A set of wildcard version ARNs that always reference the latest version of the resource.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#client_token ⇒ String
The client token that uniquely identifies the request.
1417 1418 1419 1420 1421 1422 1423 1424 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1417 class CreateContainerRecipeResponse < Struct.new( :request_id, :client_token, :container_recipe_arn, :latest_version_references) SENSITIVE = [] include Aws::Structure end |
#container_recipe_arn ⇒ String
Returns the Amazon Resource Name (ARN) of the container recipe that the request created.
1417 1418 1419 1420 1421 1422 1423 1424 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1417 class CreateContainerRecipeResponse < Struct.new( :request_id, :client_token, :container_recipe_arn, :latest_version_references) SENSITIVE = [] include Aws::Structure end |
#latest_version_references ⇒ Types::LatestVersionReferences
A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.
1417 1418 1419 1420 1421 1422 1423 1424 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1417 class CreateContainerRecipeResponse < Struct.new( :request_id, :client_token, :container_recipe_arn, :latest_version_references) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
1417 1418 1419 1420 1421 1422 1423 1424 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1417 class CreateContainerRecipeResponse < Struct.new( :request_id, :client_token, :container_recipe_arn, :latest_version_references) SENSITIVE = [] include Aws::Structure end |