Class: Aws::Imagebuilder::Types::CreateImagePipelineRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CreateImagePipelineRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#container_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe that is used to configure images created by this container pipeline.
-
#description ⇒ String
The description of the image pipeline.
-
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration that will be used to configure and distribute images created by this image pipeline.
-
#enhanced_image_metadata_enabled ⇒ Boolean
Collects additional information about the image being created, including the operating system (OS) version and package list.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.
-
#image_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the image recipe that will be used to configure images created by this image pipeline.
-
#image_scanning_configuration ⇒ Types::ImageScanningConfiguration
Contains settings for vulnerability scans.
-
#image_tags ⇒ Hash<String,String>
The tags to be applied to the images produced by this pipeline.
-
#image_tests_configuration ⇒ Types::ImageTestsConfiguration
The image test configuration of the image pipeline.
-
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that will be used to build images created by this image pipeline.
-
#logging_configuration ⇒ Types::PipelineLoggingConfiguration
Specifies the logging configuration for the image pipeline.
-
#name ⇒ String
The name of the image pipeline.
-
#schedule ⇒ Types::Schedule
The schedule of the image pipeline.
-
#status ⇒ String
The status of the image pipeline.
-
#tags ⇒ Hash<String,String>
The tags of the image pipeline.
-
#workflows ⇒ Array<Types::WorkflowConfiguration>
Contains an array of workflow configuration objects.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#container_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe that is used to configure images created by this container pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration that will be used to configure and distribute images created by this image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#enhanced_image_metadata_enabled ⇒ Boolean
Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the image recipe that will be used to configure images created by this image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_scanning_configuration ⇒ Types::ImageScanningConfiguration
Contains settings for vulnerability scans.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_tags ⇒ Hash<String,String>
The tags to be applied to the images produced by this pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_tests_configuration ⇒ Types::ImageTestsConfiguration
The image test configuration of the image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that will be used to build images created by this image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::PipelineLoggingConfiguration
Specifies the logging configuration for the image pipeline. Use this
to define custom CloudWatch Logs log groups for your pipeline
execution logs and image build logs. The service manages log groups
with names starting with /aws/imagebuilder/ using the
service-linked role. For custom log group names outside of this
prefix, you must also provide an executionRole.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#schedule ⇒ Types::Schedule
The schedule of the image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the image pipeline.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#workflows ⇒ Array<Types::WorkflowConfiguration>
Contains an array of workflow configuration objects.
1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 1450 1451 1452 1453 1454 1455 1456 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1436 class CreateImagePipelineRequest < Struct.new( :name, :description, :image_recipe_arn, :container_recipe_arn, :infrastructure_configuration_arn, :distribution_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :schedule, :status, :tags, :image_tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |