Class: Aws::Imagebuilder::Types::CreateImageRecipeRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CreateImageRecipeRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_instance_configuration ⇒ Types::AdditionalInstanceConfiguration
The additional settings and launch scripts for your build instances.
-
#ami_tags ⇒ Hash<String,String>
Tags that are applied to the AMI that Image Builder creates during the Build phase prior to image distribution.
-
#ami_watermarks ⇒ Array<String>
The AMI watermark names to attach to the output AMI from this recipe.
-
#block_device_mappings ⇒ Array<Types::InstanceBlockDeviceMapping>
The block device mappings that Image Builder applies to the build instance and the output AMI.
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time.
-
#components ⇒ Array<Types::ComponentConfiguration>
The components included in the image recipe.
-
#description ⇒ String
The description of the image recipe.
-
#dry_run ⇒ Boolean
Validates the required permissions and request parameters without performing the operation.
-
#name ⇒ String
The name of the image recipe.
-
#parent_image ⇒ String
The base image for customizations specified in the image recipe.
-
#semantic_version ⇒ String
The semantic version of the image recipe.
-
#tags ⇒ Hash<String,String>
The tags of the image recipe.
-
#working_directory ⇒ String
The working directory used during build and test workflows.
Instance Attribute Details
#additional_instance_configuration ⇒ Types::AdditionalInstanceConfiguration
The additional settings and launch scripts for your build instances.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ami_tags ⇒ Hash<String,String>
Tags that are applied to the AMI that Image Builder creates during the Build phase prior to image distribution.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#ami_watermarks ⇒ Array<String>
The AMI watermark names to attach to the output AMI from this recipe. AMI watermarks are lineage markers. They automatically propagate to derivative AMIs when the source AMI is copied or distributed across Regions or accounts.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#block_device_mappings ⇒ Array<Types::InstanceBlockDeviceMapping>
The block device mappings that Image Builder applies to the build instance and the output AMI. For example, you can override the size of the base image's root volume or attach additional EBS volumes.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#components ⇒ Array<Types::ComponentConfiguration>
The components included in the image recipe. Components are
optional. A recipe with no components bakes the base image without
additional customization. You can specify each component only one
time in a recipe. Components with a status of DEPRECATED or
DISABLED can't be added to new recipes.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the image recipe.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Validates the required permissions and request parameters without
performing the operation. If validation succeeds, the operation
returns a DryRunOperationException error response.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the image recipe. The recipe name, combined with the semantic version, must be unique to your account in each Amazon Web Services Region. Image Builder generates the image recipe ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#parent_image ⇒ String
The base image for customizations specified in the image recipe. You can specify the parent image using one of the following options:
-
AMI ID
-
Image Builder image Amazon Resource Name (ARN)
-
Amazon Web Services Systems Manager (SSM) Parameter Store Parameter, prefixed by
ssm:, followed by the parameter name or ARN. -
Amazon Web Services Marketplace product ID
If you enter an AMI ID or an SSM parameter that contains the AMI ID, you must have access to the AMI. The AMI must also be in the Region where you're creating the recipe.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#semantic_version ⇒ String
The semantic version of the image recipe. This version follows the semantic version syntax.
Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.
Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the image recipe.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |
#working_directory ⇒ String
The working directory used during build and test workflows. If you
don't specify a working directory, Image Builder uses /tmp for
Linux and macOS build instances, and C:/ for Windows build
instances.
1791 1792 1793 1794 1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1791 class CreateImageRecipeRequest < Struct.new( :name, :description, :semantic_version, :components, :parent_image, :block_device_mappings, :tags, :working_directory, :additional_instance_configuration, :ami_tags, :ami_watermarks, :client_token, :dry_run) SENSITIVE = [] include Aws::Structure end |