Class: Aws::Imagebuilder::Types::CreateImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CreateImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#container_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe that defines how images are configured and tested.
-
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration that defines and configures the outputs of your pipeline.
-
#enhanced_image_metadata_enabled ⇒ Boolean
Collects additional information about the image being created, including the operating system (OS) version and package list.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.
-
#image_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the image recipe that defines how images are configured, tested, and assessed.
-
#image_scanning_configuration ⇒ Types::ImageScanningConfiguration
Contains settings for vulnerability scans.
-
#image_tests_configuration ⇒ Types::ImageTestsConfiguration
The image tests configuration of the image.
-
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that defines the environment in which your image will be built and tested.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
Define logging configuration for the image build process.
-
#tags ⇒ Hash<String,String>
The tags of the image.
-
#workflows ⇒ Array<Types::WorkflowConfiguration>
Contains an array of workflow configuration objects.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#container_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe that defines how images are configured and tested.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration that defines and configures the outputs of your pipeline.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#enhanced_image_metadata_enabled ⇒ Boolean
Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the image recipe that defines how images are configured, tested, and assessed.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_scanning_configuration ⇒ Types::ImageScanningConfiguration
Contains settings for vulnerability scans.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_tests_configuration ⇒ Types::ImageTestsConfiguration
The image tests configuration of the image.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that defines the environment in which your image will be built and tested.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
Define logging configuration for the image build process.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the image.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#workflows ⇒ Array<Types::WorkflowConfiguration>
Contains an array of workflow configuration objects.
1696 1697 1698 1699 1700 1701 1702 1703 1704 1705 1706 1707 1708 1709 1710 1711 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1696 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |