Class: Aws::Imagebuilder::Types::CreateImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CreateImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time.
-
#container_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe that defines how images are configured and tested.
-
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration that defines and configures the outputs of the image build.
-
#enhanced_image_metadata_enabled ⇒ Boolean
Specifies whether to collect additional information about the image being created, including the operating system (OS) version and package list.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.
-
#image_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the image recipe that defines how images are configured, tested, and assessed.
-
#image_scanning_configuration ⇒ Types::ImageScanningConfiguration
Settings for vulnerability scans that Amazon Inspector runs during image creation.
-
#image_tests_configuration ⇒ Types::ImageTestsConfiguration
Settings that determine whether Image Builder runs tests on the image after building it.
-
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that defines the environment in which your image will be built and tested.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The CloudWatch Logs log group where Image Builder sends the image build logs.
-
#tags ⇒ Hash<String,String>
The tags of the image.
-
#workflows ⇒ Array<Types::WorkflowConfiguration>
The array of workflow configuration objects for the build.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#container_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the container recipe that defines
how images are configured and tested. You must specify either this
property or imageRecipeArn, but not both.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration that defines and configures the outputs of the image build. If you don't specify a distribution configuration, Image Builder creates the output image only in the account and Amazon Web Services Region where the build runs.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#enhanced_image_metadata_enabled ⇒ Boolean
Specifies whether to collect additional information about the image
being created, including the operating system (OS) version and
package list. Defaults to true.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create
that grants Image Builder access to perform workflow actions. This
property is required if you specify workflows. If you don't
provide a role, Image Builder uses the Image Builder service-linked
role in your account, and creates it if it doesn't exist.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_recipe_arn ⇒ String
The Amazon Resource Name (ARN) of the image recipe that defines how
images are configured, tested, and assessed. You must specify either
this property or containerRecipeArn, but not both.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_scanning_configuration ⇒ Types::ImageScanningConfiguration
Settings for vulnerability scans that Amazon Inspector runs during
image creation. For AMI output, Amazon Inspector scans the test
instance. For container output, Amazon Inspector scans the container
image that Image Builder pushes to the Amazon ECR repository
specified in ecrConfiguration.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_tests_configuration ⇒ Types::ImageTestsConfiguration
Settings that determine whether Image Builder runs tests on the image after building it. Image tests are enabled by default.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration that defines the environment in which your image will be built and tested.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The CloudWatch Logs log group where Image Builder sends the image
build logs. If you specify a log group name outside of the
/aws/imagebuilder/ namespace, you must also provide an
executionRole that has permission to write to that log group.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the image.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#workflows ⇒ Array<Types::WorkflowConfiguration>
The array of workflow configuration objects for the build. If you
specify workflows, they replace the default workflows that Image
Builder otherwise runs for the build, and you must also provide an
executionRole.
1928 1929 1930 1931 1932 1933 1934 1935 1936 1937 1938 1939 1940 1941 1942 1943 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 1928 class CreateImageRequest < Struct.new( :image_recipe_arn, :container_recipe_arn, :distribution_configuration_arn, :infrastructure_configuration_arn, :image_tests_configuration, :enhanced_image_metadata_enabled, :tags, :client_token, :image_scanning_configuration, :workflows, :execution_role, :logging_configuration) SENSITIVE = [] include Aws::Structure end |