Class: Aws::Imagebuilder::Types::CreateWorkflowRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CreateWorkflowRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_description ⇒ String
Describes what change has been made in this version of the workflow, or what makes this version different from other versions of the workflow.
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#data ⇒ String
Contains the UTF-8 encoded YAML document content for the workflow.
-
#description ⇒ String
Describes the workflow.
-
#dry_run ⇒ Boolean
Validates the required permissions for the operation and the request parameters, without actually making the request, and provides an error response.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key used to encrypt this workflow resource.
-
#name ⇒ String
The name of the workflow to create.
-
#semantic_version ⇒ String
The semantic version of this workflow resource.
-
#tags ⇒ Hash<String,String>
Tags that apply to the workflow resource.
-
#type ⇒ String
The phase in the image build process for which the workflow resource is responsible.
-
#uri ⇒ String
The
uriof a YAML component document file.
Instance Attribute Details
#change_description ⇒ String
Describes what change has been made in this version of the workflow, or what makes this version different from other versions of the workflow.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#data ⇒ String
Contains the UTF-8 encoded YAML document content for the workflow.
Alternatively, you can specify the uri of a YAML document file
stored in Amazon S3. However, you cannot specify both properties.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Describes the workflow.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#dry_run ⇒ Boolean
Validates the required permissions for the operation and the request
parameters, without actually making the request, and provides an
error response. Upon a successful request, the error response is
DryRunOperationException.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key used to encrypt this workflow resource. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workflow to create.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#semantic_version ⇒ String
The semantic version of this workflow resource. The semantic version syntax adheres to the following rules.
Assignment: For the first three nodes you can assign any positive integer value, including zero, with an upper limit of 2^30-1, or 1073741823 for each node. Image Builder automatically assigns the build number to the fourth node.
Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags that apply to the workflow resource.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The phase in the image build process for which the workflow resource is responsible.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The uri of a YAML component document file. This must be an S3 URL
(s3://bucket/key), and the requester must have permission to
access the S3 bucket it points to. If you use Amazon S3, you can
specify component content up to your service quota.
Alternatively, you can specify the YAML document inline, using the
component data property. You cannot specify both properties.
2036 2037 2038 2039 2040 2041 2042 2043 2044 2045 2046 2047 2048 2049 2050 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2036 class CreateWorkflowRequest < Struct.new( :name, :semantic_version, :description, :change_description, :data, :uri, :kms_key_id, :tags, :client_token, :type, :dry_run) SENSITIVE = [] include Aws::Structure end |