Class: Aws::Imagebuilder::Types::CreateWorkflowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::CreateWorkflowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
The client token that uniquely identifies the request.
-
#latest_version_references ⇒ Types::LatestVersionReferences
A set of wildcard version ARNs that always reference the latest version of the resource.
-
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource that the request created.
Instance Attribute Details
#client_token ⇒ String
The client token that uniquely identifies the request.
2402 2403 2404 2405 2406 2407 2408 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2402 class CreateWorkflowResponse < Struct.new( :client_token, :workflow_build_version_arn, :latest_version_references) SENSITIVE = [] include Aws::Structure end |
#latest_version_references ⇒ Types::LatestVersionReferences
A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.
2402 2403 2404 2405 2406 2407 2408 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2402 class CreateWorkflowResponse < Struct.new( :client_token, :workflow_build_version_arn, :latest_version_references) SENSITIVE = [] include Aws::Structure end |
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource that the request created.
2402 2403 2404 2405 2406 2407 2408 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2402 class CreateWorkflowResponse < Struct.new( :client_token, :workflow_build_version_arn, :latest_version_references) SENSITIVE = [] include Aws::Structure end |