Class: Aws::Imagebuilder::Types::DistributeImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2501

class DistributeImageRequest < Struct.new(
  :source_image,
  :distribution_configuration_arn,
  :execution_role,
  :tags,
  :client_token,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_configuration_arnString

The Amazon Resource Name (ARN) of the distribution configuration. The configuration defines target Regions, accounts, and AMI settings. The distribution configuration must be in the same Region as this operation.

Returns:

  • (String)


2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2501

class DistributeImageRequest < Struct.new(
  :source_image,
  :distribution_configuration_arn,
  :execution_role,
  :tags,
  :client_token,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#execution_roleString

The name or Amazon Resource Name (ARN) of the IAM role that Image Builder assumes to distribute the image.

Returns:

  • (String)


2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2501

class DistributeImageRequest < Struct.new(
  :source_image,
  :distribution_configuration_arn,
  :execution_role,
  :tags,
  :client_token,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::ImageLoggingConfiguration

The logging configuration for the distribution.



2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2501

class DistributeImageRequest < Struct.new(
  :source_image,
  :distribution_configuration_arn,
  :execution_role,
  :tags,
  :client_token,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_imageString

The source image to distribute. Specify an AMI identifier, SSM parameter path, or Image Builder image Amazon Resource Name (ARN). When you specify an Image Builder image Amazon Resource Name (ARN), the image must be in the AVAILABLE state.

Returns:

  • (String)


2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2501

class DistributeImageRequest < Struct.new(
  :source_image,
  :distribution_configuration_arn,
  :execution_role,
  :tags,
  :client_token,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags to apply to the distributed image.

Returns:

  • (Hash<String,String>)


2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2501

class DistributeImageRequest < Struct.new(
  :source_image,
  :distribution_configuration_arn,
  :execution_role,
  :tags,
  :client_token,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end