Class: Aws::Imagebuilder::Types::DistributeImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::DistributeImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration to use.
-
#execution_role ⇒ String
The IAM role to use for the distribution.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The logging configuration for the distribution.
-
#source_image ⇒ String
The source image Amazon Resource Name (ARN) to distribute.
-
#tags ⇒ Hash<String,String>
The tags to apply to the distributed image.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2477 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration to use.
2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2477 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The IAM role to use for the distribution.
2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2477 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The logging configuration for the distribution.
2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2477 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#source_image ⇒ String
The source image Amazon Resource Name (ARN) to distribute.
2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2477 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to the distributed image.
2477 2478 2479 2480 2481 2482 2483 2484 2485 2486 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2477 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |