Class: Aws::Imagebuilder::Types::DistributeImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::DistributeImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time.
-
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that Image Builder assumes to distribute the image.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The logging configuration for the distribution.
-
#source_image ⇒ String
The source image to distribute.
-
#tags ⇒ Hash<String,String>
The tags to apply to the new Image Builder image resource that this operation creates.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2824 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#distribution_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the distribution configuration. The configuration defines target Regions, accounts, and AMI settings. The distribution configuration must be in the same Region as this operation.
2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2824 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that Image Builder assumes to distribute the image.
2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2824 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The logging configuration for the distribution.
2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2824 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#source_image ⇒ String
The source image to distribute. You can specify the source in any of the following formats:
-
An AMI ID.
-
An Amazon Web Services Systems Manager Parameter Store reference, prefixed by
ssm:, followed by the parameter name or ARN. -
An Image Builder image Amazon Resource Name (ARN). An image version ARN resolves to the latest available build version.
Whichever format you use, the source must resolve to an AMI in the current Amazon Web Services Region.
2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2824 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to apply to the new Image Builder image resource that this
operation creates. To tag the output AMIs, use amiTags in the
distribution configuration.
2824 2825 2826 2827 2828 2829 2830 2831 2832 2833 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2824 class DistributeImageRequest < Struct.new( :source_image, :distribution_configuration_arn, :execution_role, :tags, :client_token, :logging_configuration) SENSITIVE = [] include Aws::Structure end |