Class: Aws::Imagebuilder::Types::DryRunOperationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The dry run operation of the resource was successful, and no resources or mutations were actually performed due to the dry run flag in the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2690
2691
2692
2693
2694
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2690

class DryRunOperationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end