Class: Aws::Imagebuilder::Types::DryRunOperationException

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

The dry run operation of the resource was successful, and no resources or mutations were actually performed due to the dry run flag in the request.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Returns:

  • (String)


2666
2667
2668
2669
2670
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2666

class DryRunOperationException < Struct.new(
  :message)
  SENSITIVE = []
  include Aws::Structure
end