Class: Aws::Imagebuilder::Types::EbsInstanceBlockDeviceSpecification
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::EbsInstanceBlockDeviceSpecification
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Amazon EBS-specific block device mapping specifications.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delete_on_termination ⇒ Boolean
Use to configure delete on termination of the associated device.
-
#encrypted ⇒ Boolean
Use to configure device encryption.
-
#iops ⇒ Integer
Use to configure device IOPS.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key to use when encrypting the device.
-
#snapshot_id ⇒ String
The snapshot that defines the device contents.
-
#throughput ⇒ Integer
For GP3 volumes only – The throughput in MiB/s that the volume supports.
-
#volume_size ⇒ Integer
Use to override the device's volume size.
-
#volume_type ⇒ String
Use to override the device's volume type.
Instance Attribute Details
#delete_on_termination ⇒ Boolean
Use to configure delete on termination of the associated device.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#encrypted ⇒ Boolean
Use to configure device encryption.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
Use to configure device IOPS.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key to use when encrypting the device. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#snapshot_id ⇒ String
The snapshot that defines the device contents.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#throughput ⇒ Integer
For GP3 volumes only – The throughput in MiB/s that the volume supports.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#volume_size ⇒ Integer
Use to override the device's volume size.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |
#volume_type ⇒ String
Use to override the device's volume type.
2740 2741 2742 2743 2744 2745 2746 2747 2748 2749 2750 2751 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 2740 class EbsInstanceBlockDeviceSpecification < Struct.new( :encrypted, :delete_on_termination, :iops, :kms_key_id, :snapshot_id, :volume_size, :volume_type, :throughput) SENSITIVE = [] include Aws::Structure end |