Class: Aws::Imagebuilder::Types::EcrConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::EcrConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Settings that Image Builder uses to configure the ECR repository and the output container images that Amazon Inspector scans.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#container_tags ⇒ Array<String>
Tags for Image Builder to apply to the output container image that Amazon Inspector scans.
-
#repository_name ⇒ String
The name of the container repository where Image Builder pushes the container image for the vulnerability scan.
Instance Attribute Details
#container_tags ⇒ Array<String>
Tags for Image Builder to apply to the output container image that Amazon Inspector scans. Tags can help you identify and manage your scanned images.
3132 3133 3134 3135 3136 3137 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3132 class EcrConfiguration < Struct.new( :repository_name, :container_tags) SENSITIVE = [] include Aws::Structure end |
#repository_name ⇒ String
The name of the container repository where Image Builder pushes the
container image for the vulnerability scan. Provide the repository
name only (a namespace path is allowed, but not the registry
hostname); the repository must already exist in your account. If you
don't specify a repository name, Image Builder creates the default
repository image-builder-image-scanning-repository in your
account.
3132 3133 3134 3135 3136 3137 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3132 class EcrConfiguration < Struct.new( :repository_name, :container_tags) SENSITIVE = [] include Aws::Structure end |