Class: Aws::Imagebuilder::Types::GetImageRecipeResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::GetImageRecipeResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_recipe ⇒ Types::ImageRecipe
The image recipe object.
-
#latest_version_references ⇒ Types::LatestVersionReferences
A set of wildcard version ARNs that always reference the latest version of the resource.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#image_recipe ⇒ Types::ImageRecipe
The image recipe object.
3560 3561 3562 3563 3564 3565 3566 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3560 class GetImageRecipeResponse < Struct.new( :request_id, :image_recipe, :latest_version_references) SENSITIVE = [] include Aws::Structure end |
#latest_version_references ⇒ Types::LatestVersionReferences
A set of wildcard version ARNs that always reference the latest version of the resource. ARNs are included for the latest version overall, and for the latest versions within the same major, minor, and patch levels.
3560 3561 3562 3563 3564 3565 3566 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3560 class GetImageRecipeResponse < Struct.new( :request_id, :image_recipe, :latest_version_references) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
3560 3561 3562 3563 3564 3565 3566 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3560 class GetImageRecipeResponse < Struct.new( :request_id, :image_recipe, :latest_version_references) SENSITIVE = [] include Aws::Structure end |