Class: Aws::Imagebuilder::Types::GetMarketplaceResourceResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::GetMarketplaceResourceResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data ⇒ String
Returns obfuscated data that contains the YAML content of the component.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the Amazon Web Services Marketplace resource that was requested.
-
#url ⇒ String
A time-limited presigned URL for downloading the component artifact from Amazon S3.
Instance Attribute Details
#data ⇒ String
Returns obfuscated data that contains the YAML content of the component.
3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3739 class GetMarketplaceResourceResponse < Struct.new( :resource_arn, :url, :data) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) for the Amazon Web Services Marketplace resource that was requested.
3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3739 class GetMarketplaceResourceResponse < Struct.new( :resource_arn, :url, :data) SENSITIVE = [] include Aws::Structure end |
#url ⇒ String
A time-limited presigned URL for downloading the component artifact from Amazon S3.
3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3739 class GetMarketplaceResourceResponse < Struct.new( :resource_arn, :url, :data) SENSITIVE = [] include Aws::Structure end |