Class: Aws::Imagebuilder::Types::GetWorkflowExecutionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeString

The timestamp when the specified runtime instance of the workflow finished.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arnString

The Amazon Resource Name (ARN) of the image resource build version that the specified runtime instance of the workflow created.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The output message from the specified runtime instance of the workflow, if applicable.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#parallel_groupString

Test workflows are defined within named runtime groups. The parallel group is a named group that contains one or more test workflows.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The request ID that uniquely identifies this request.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeString

The timestamp when the specified runtime instance of the workflow started.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current runtime status for the specified runtime instance of the workflow.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_step_countInteger

The total number of steps in the specified runtime instance of the workflow that ran. This number should equal the sum of the step counts for steps that succeeded, were skipped, and failed.

Returns:

  • (Integer)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_failedInteger

A runtime count for the number of steps that failed in the specified runtime instance of the workflow.

Returns:

  • (Integer)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_skippedInteger

A runtime count for the number of steps that were skipped in the specified runtime instance of the workflow.

Returns:

  • (Integer)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#total_steps_succeededInteger

A runtime count for the number of steps that ran successfully in the specified runtime instance of the workflow.

Returns:

  • (Integer)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of workflow that Image Builder ran for the specified runtime instance of the workflow.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_build_version_arnString

The Amazon Resource Name (ARN) of the build version for the Image Builder workflow resource that defines the specified runtime instance of the workflow.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end

#workflow_execution_idString

The unique identifier that Image Builder assigned to keep track of runtime details when it ran the workflow.

Returns:

  • (String)


3448
3449
3450
3451
3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
3462
3463
3464
3465
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448

class GetWorkflowExecutionResponse < Struct.new(
  :request_id,
  :workflow_build_version_arn,
  :workflow_execution_id,
  :image_build_version_arn,
  :type,
  :status,
  :message,
  :total_step_count,
  :total_steps_succeeded,
  :total_steps_failed,
  :total_steps_skipped,
  :start_time,
  :end_time,
  :parallel_group)
  SENSITIVE = []
  include Aws::Structure
end