Class: Aws::Imagebuilder::Types::GetWorkflowExecutionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::GetWorkflowExecutionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ String
The timestamp when the specified runtime instance of the workflow finished.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image resource build version that the specified runtime instance of the workflow created.
-
#message ⇒ String
The output message from the specified runtime instance of the workflow, if applicable.
-
#parallel_group ⇒ String
Test workflows are defined within named runtime groups.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
-
#start_time ⇒ String
The timestamp when the specified runtime instance of the workflow started.
-
#status ⇒ String
The current runtime status for the specified runtime instance of the workflow.
-
#total_step_count ⇒ Integer
The total number of steps in the specified runtime instance of the workflow that ran.
-
#total_steps_failed ⇒ Integer
A runtime count for the number of steps that failed in the specified runtime instance of the workflow.
-
#total_steps_skipped ⇒ Integer
A runtime count for the number of steps that were skipped in the specified runtime instance of the workflow.
-
#total_steps_succeeded ⇒ Integer
A runtime count for the number of steps that ran successfully in the specified runtime instance of the workflow.
-
#type ⇒ String
The type of workflow that Image Builder ran for the specified runtime instance of the workflow.
-
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the build version for the Image Builder workflow resource that defines the specified runtime instance of the workflow.
-
#workflow_execution_id ⇒ String
The unique identifier that Image Builder assigned to keep track of runtime details when it ran the workflow.
Instance Attribute Details
#end_time ⇒ String
The timestamp when the specified runtime instance of the workflow finished.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image resource build version that the specified runtime instance of the workflow created.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The output message from the specified runtime instance of the workflow, if applicable.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#parallel_group ⇒ String
Test workflows are defined within named runtime groups. The parallel group is a named group that contains one or more test workflows.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The timestamp when the specified runtime instance of the workflow started.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current runtime status for the specified runtime instance of the workflow.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#total_step_count ⇒ Integer
The total number of steps in the specified runtime instance of the workflow that ran. This number should equal the sum of the step counts for steps that succeeded, were skipped, and failed.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#total_steps_failed ⇒ Integer
A runtime count for the number of steps that failed in the specified runtime instance of the workflow.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#total_steps_skipped ⇒ Integer
A runtime count for the number of steps that were skipped in the specified runtime instance of the workflow.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#total_steps_succeeded ⇒ Integer
A runtime count for the number of steps that ran successfully in the specified runtime instance of the workflow.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of workflow that Image Builder ran for the specified runtime instance of the workflow.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the build version for the Image Builder workflow resource that defines the specified runtime instance of the workflow.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |
#workflow_execution_id ⇒ String
The unique identifier that Image Builder assigned to keep track of runtime details when it ran the workflow.
3448 3449 3450 3451 3452 3453 3454 3455 3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 3448 class GetWorkflowExecutionResponse < Struct.new( :request_id, :workflow_build_version_arn, :workflow_execution_id, :image_build_version_arn, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group) SENSITIVE = [] include Aws::Structure end |