Class: Aws::Imagebuilder::Types::ImagePipeline

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Details of an image pipeline.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#consecutive_failuresInteger

Image Builder tracks the number of consecutive failures for scheduled pipeline executions and takes one of the following actions each time it runs on a schedule:

  • If the pipeline execution is successful, the number of consecutive failures resets to zero.

  • If the pipeline execution fails, Image Builder increments the number of consecutive failures. If the failure count exceeds the limit defined in the ‘AutoDisablePolicy`, Image Builder disables the pipeline.

The consecutive failure count is also reset to zero under the following conditions:

  • The pipeline runs manually and succeeds.

  • The pipeline configuration is updated.

If the pipeline runs manually and fails, the count remains the same. The next scheduled run continues to increment where it left off before.

Returns:

  • (Integer)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#container_recipe_arnString

The Amazon Resource Name (ARN) of the container recipe that is used for this pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_createdString

The date on which this image pipeline was created.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_last_runString

This is no longer supported, and does not return a value.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_next_runString

The next date when the pipeline is scheduled to run.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#date_updatedString

The date on which this image pipeline was last updated.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_configuration_arnString

The Amazon Resource Name (ARN) of the distribution configuration associated with this image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_image_metadata_enabledBoolean

Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default.

Returns:

  • (Boolean)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#execution_roleString

The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_recipe_arnString

The Amazon Resource Name (ARN) of the image recipe associated with this image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_scanning_configurationTypes::ImageScanningConfiguration

Contains settings for vulnerability scans.



4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_tagsHash<String,String>

The tags to be applied to the images produced by this pipeline.

Returns:

  • (Hash<String,String>)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#image_tests_configurationTypes::ImageTestsConfiguration

The image tests configuration of the image pipeline.



4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_configuration_arnString

The Amazon Resource Name (ARN) of the infrastructure configuration associated with this image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#last_run_statusString

The status of the last image that this pipeline built, such as ‘BUILDING`, `TESTING`, `FAILED`, or `AVAILABLE`.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::PipelineLoggingConfiguration

Defines logging configuration for the output image.



4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The platform of the image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::Schedule

The schedule of the image pipeline.

Returns:



4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the image pipeline.

Returns:

  • (String)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags of this image pipeline.

Returns:

  • (Hash<String,String>)


4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end

#workflowsArray<Types::WorkflowConfiguration>

Contains the workflows that run for the image pipeline.

Returns:



4012
4013
4014
4015
4016
4017
4018
4019
4020
4021
4022
4023
4024
4025
4026
4027
4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
4038
4039
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4012

class ImagePipeline < Struct.new(
  :arn,
  :name,
  :description,
  :platform,
  :enhanced_image_metadata_enabled,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :schedule,
  :status,
  :date_created,
  :date_updated,
  :date_last_run,
  :last_run_status,
  :date_next_run,
  :tags,
  :image_scanning_configuration,
  :image_tags,
  :execution_role,
  :workflows,
  :logging_configuration,
  :consecutive_failures)
  SENSITIVE = []
  include Aws::Structure
end