Class: Aws::Imagebuilder::Types::ImageRecipe

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

An image recipe.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_instance_configurationTypes::AdditionalInstanceConfiguration

Before you create a new AMI, Image Builder launches temporary Amazon EC2 instances to build and test your image configuration. Instance configuration adds a layer of control over those instances. You can define settings and add scripts to run when an instance is launched from your AMI.



4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#ami_tagsHash<String,String>

Tags that are applied to the AMI that Image Builder creates during the Build phase prior to image distribution.

Returns:

  • (Hash<String,String>)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#ami_watermarksArray<String>

The AMI watermark names attached to the output AMI from this recipe. AMI watermarks are lineage markers that automatically propagate to derivative AMIs when the source AMI is copied or distributed.

Returns:

  • (Array<String>)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#arnString

The Amazon Resource Name (ARN) of the image recipe.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#block_device_mappingsArray<Types::InstanceBlockDeviceMapping>

The block device mappings to apply when creating images from this recipe.



4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#componentsArray<Types::ComponentConfiguration>

The components that are included in the image recipe. Recipes require a minimum of one build component, and can have a maximum of 20 build and test components in any combination.

Returns:



4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#date_createdString

The date on which this image recipe was created.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the image recipe.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the image recipe.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The owner of the image recipe.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#parent_imageString

The base image for customizations specified in the image recipe. You can specify the parent image using one of the following options:

  • AMI ID

  • Image Builder image Amazon Resource Name (ARN)

  • Amazon Web Services Systems Manager (SSM) Parameter Store Parameter, prefixed by ssm:, followed by the parameter name or ARN.

  • Amazon Web Services Marketplace product ID

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The platform of the image recipe.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags of the image recipe.

Returns:

  • (Hash<String,String>)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Specifies which type of image is created by the recipe - an AMI or a container image.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the image recipe.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end

#working_directoryString

The working directory to be used during build and test workflows.

Returns:

  • (String)


4177
4178
4179
4180
4181
4182
4183
4184
4185
4186
4187
4188
4189
4190
4191
4192
4193
4194
4195
4196
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4177

class ImageRecipe < Struct.new(
  :arn,
  :type,
  :name,
  :description,
  :platform,
  :owner,
  :version,
  :components,
  :parent_image,
  :block_device_mappings,
  :date_created,
  :tags,
  :working_directory,
  :additional_instance_configuration,
  :ami_tags,
  :ami_watermarks)
  SENSITIVE = []
  include Aws::Structure
end