Class: Aws::Imagebuilder::Types::ImageScanState
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImageScanState
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Shows the vulnerability scan status for a specific image, and the reason for that status.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#reason ⇒ String
The reason for the scan status for the image.
-
#status ⇒ String
The current state of vulnerability scans for the image.
Instance Attribute Details
#reason ⇒ String
The reason for the scan status for the image.
4934 4935 4936 4937 4938 4939 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4934 class ImageScanState < Struct.new( :status, :reason) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current state of vulnerability scans for the image. The scan
starts as PENDING and moves through SCANNING and COLLECTING to
COMPLETED. Image Builder sets the status to ABANDONED if the
image reaches a terminal state before the scan finding collection
completes. A scan can also end as FAILED or TIMED_OUT.
4934 4935 4936 4937 4938 4939 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4934 class ImageScanState < Struct.new( :status, :reason) SENSITIVE = [] include Aws::Structure end |