Class: Aws::Imagebuilder::Types::ImageSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

An image summary.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#build_typeString

Indicates the type of build that created this image. The build can be initiated in the following ways:

  • USER_INITIATED – A manual pipeline build request.

  • SCHEDULED – A pipeline build initiated by a cron expression in the Image Builder pipeline, or from EventBridge.

  • IMPORT – A VM import created the image to use as the base image for the recipe.

  • IMPORT_ISO – An ISO disk import created the image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#date_createdString

The date on which Image Builder created this image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#deprecation_timeTime

The time when deprecation occurs for an image resource. This can be a past or future date.

Returns:

  • (Time)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#image_sourceString

The origin of the base image that Image Builder used to build this image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycle_execution_idString

Identifies the last runtime instance of the lifecycle policy to take action on the image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::ImageLoggingConfiguration

The logging configuration that's defined for the image.



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#os_versionString

The operating system version of the instances that launch from this image. For example, Amazon Linux 2, Ubuntu 18, or Microsoft Windows Server 2019.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#output_resourcesTypes::OutputResources

The output resources that Image Builder produced when it created this image.



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The owner of the image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#platformString

The image operating system platform, such as Linux or Windows.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stateTypes::ImageState

The state of the image.

Returns:



4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that apply to this image.

Returns:

  • (Hash<String,String>)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Specifies whether this image produces an AMI or a container image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The version of the image.

Returns:

  • (String)


4530
4531
4532
4533
4534
4535
4536
4537
4538
4539
4540
4541
4542
4543
4544
4545
4546
4547
4548
4549
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4530

class ImageSummary < Struct.new(
  :arn,
  :name,
  :type,
  :version,
  :platform,
  :os_version,
  :state,
  :owner,
  :date_created,
  :output_resources,
  :tags,
  :build_type,
  :image_source,
  :deprecation_time,
  :lifecycle_execution_id,
  :logging_configuration)
  SENSITIVE = []
  include Aws::Structure
end