Class: Aws::Imagebuilder::Types::ImageSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImageSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
An image summary.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the image.
-
#build_type ⇒ String
Indicates the type of build that created this image.
-
#date_created ⇒ String
The date on which Image Builder created this image.
-
#deprecation_time ⇒ Time
The time when deprecation occurs for an image resource.
-
#image_source ⇒ String
The origin of the base image that Image Builder used to build this image.
-
#lifecycle_execution_id ⇒ String
Identifies the last runtime instance of the lifecycle policy to take action on the image.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The logging configuration that's defined for the image.
-
#name ⇒ String
The name of the image.
-
#os_version ⇒ String
The operating system version of the instances that launch from this image.
-
#output_resources ⇒ Types::OutputResources
The output resources that Image Builder produced when it created this image.
-
#owner ⇒ String
The owner of the image.
-
#platform ⇒ String
The image operating system platform, such as Linux or Windows.
-
#state ⇒ Types::ImageState
The state of the image.
-
#tags ⇒ Hash<String,String>
The tags that apply to this image.
-
#type ⇒ String
Specifies whether this image produces an AMI or a container image.
-
#version ⇒ String
The version of the image.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#build_type ⇒ String
Indicates the type of build that created this image. The build can be initiated in the following ways:
-
USER_INITIATED – A manual pipeline build request.
-
SCHEDULED – A pipeline build initiated by a cron expression in the Image Builder pipeline, or from EventBridge.
-
IMPORT – A VM import created the image to use as the base image for the recipe.
-
IMPORT_ISO – An ISO disk import created the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ String
The date on which Image Builder created this image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#deprecation_time ⇒ Time
The time when deprecation occurs for an image resource. This can be a past or future date.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#image_source ⇒ String
The origin of the base image that Image Builder used to build this image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#lifecycle_execution_id ⇒ String
Identifies the last runtime instance of the lifecycle policy to take action on the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The logging configuration that's defined for the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#os_version ⇒ String
The operating system version of the instances that launch from this image. For example, Amazon Linux 2, Ubuntu 18, or Microsoft Windows Server 2019.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#output_resources ⇒ Types::OutputResources
The output resources that Image Builder produced when it created this image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
The owner of the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The image operating system platform, such as Linux or Windows.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#state ⇒ Types::ImageState
The state of the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags that apply to this image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies whether this image produces an AMI or a container image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the image.
5081 5082 5083 5084 5085 5086 5087 5088 5089 5090 5091 5092 5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5081 class ImageSummary < Struct.new( :arn, :name, :type, :version, :platform, :os_version, :state, :owner, :date_created, :output_resources, :tags, :build_type, :image_source, :deprecation_time, :lifecycle_execution_id, :logging_configuration) SENSITIVE = [] include Aws::Structure end |