Class: Aws::Imagebuilder::Types::ImportComponentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImportComponentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#change_description ⇒ String
The change description of the component.
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#data ⇒ String
The data of the component.
-
#description ⇒ String
The description of the component.
-
#format ⇒ String
The format of the resource that you want to import as a component.
-
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key used to encrypt this component.
-
#name ⇒ String
The name of the component.
-
#platform ⇒ String
The platform of the component.
-
#semantic_version ⇒ String
The semantic version of the component.
-
#tags ⇒ Hash<String,String>
The tags of the component.
-
#type ⇒ String
The type of the component denotes whether the component is used to build the image, or only to test it.
-
#uri ⇒ String
The uri of the component.
Instance Attribute Details
#change_description ⇒ String
The change description of the component. This description indicates the change that has been made in this version, or what makes this version different from other versions of the component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#data ⇒ String
The data of the component. Used to specify the data inline. Either
data or uri can be used to specify the data within the
component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the component. Describes the contents of the component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#format ⇒ String
The format of the resource that you want to import as a component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the KMS key used to encrypt this component. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The platform of the component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#semantic_version ⇒ String
The semantic version of the component. This version follows the semantic version syntax.
Filtering: With semantic versioning, you have the flexibility to use wildcards (x) to specify the most recent versions or nodes when selecting the base image or components for your recipe. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of the component denotes whether the component is used to build the image, or only to test it.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The uri of the component. Must be an Amazon S3 URL and the requester
must have permission to access the Amazon S3 bucket. If you use
Amazon S3, you can specify component content up to your service
quota. Either data or uri can be used to specify the data within
the component.
4751 4752 4753 4754 4755 4756 4757 4758 4759 4760 4761 4762 4763 4764 4765 4766 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4751 class ImportComponentRequest < Struct.new( :name, :semantic_version, :description, :change_description, :type, :format, :platform, :data, :uri, :kms_key_id, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |