Class: Aws::Imagebuilder::Types::ImportDiskImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImportDiskImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#description ⇒ String
The description for your disk image import.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions to import an image from a Microsoft ISO file.
-
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration resource that's used for launching the EC2 instance on which the ISO image is built.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
Define logging configuration for the image build process.
-
#name ⇒ String
The name of the image resource that's created from the import.
-
#os_version ⇒ String
The operating system version for the imported image.
-
#platform ⇒ String
The operating system platform for the imported image.
-
#register_image_options ⇒ Types::RegisterImageOptions
Configures Secure Boot and UEFI settings for the imported image.
-
#semantic_version ⇒ String
The semantic version to attach to the image that's created during the import process.
-
#tags ⇒ Hash<String,String>
Tags that are attached to image resources created from the import.
-
#uri ⇒ String
The
uriof the ISO disk file that's stored in Amazon S3. -
#windows_configuration ⇒ Types::WindowsConfiguration
Specifies Windows settings for ISO imports.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for your disk image import.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions to import an image from a Microsoft ISO file.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration resource that's used for launching the EC2 instance on which the ISO image is built.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
Define logging configuration for the image build process.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the image resource that's created from the import.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#os_version ⇒ String
The operating system version for the imported image. Allowed values
include the following: Microsoft Windows 11.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system platform for the imported image. Allowed values
include the following: Windows.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#register_image_options ⇒ Types::RegisterImageOptions
Configures Secure Boot and UEFI settings for the imported image.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#semantic_version ⇒ String
The semantic version to attach to the image that's created during the import process. This version follows the semantic version syntax.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags that are attached to image resources created from the import.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The uri of the ISO disk file that's stored in Amazon S3.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#windows_configuration ⇒ Types::WindowsConfiguration
Specifies Windows settings for ISO imports.
4892 4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 4892 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |