Class: Aws::Imagebuilder::Types::ImportDiskImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImportDiskImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time.
-
#description ⇒ String
The description for your disk image import.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions to import an image from a Microsoft ISO file.
-
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration resource that's used for launching the EC2 instance on which the ISO image is built.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The CloudWatch Logs log group where Image Builder sends the import logs.
-
#name ⇒ String
The name of the image resource that's created from the import.
-
#os_version ⇒ String
The operating system version for the imported image.
-
#platform ⇒ String
The operating system platform for the imported image.
-
#register_image_options ⇒ Types::RegisterImageOptions
Configures Secure Boot and UEFI settings for the imported image.
-
#semantic_version ⇒ String
The semantic version to attach to the image that's created during the import process.
-
#tags ⇒ Hash<String,String>
Tags that are attached to image resources created from the import.
-
#uri ⇒ String
The
uriof the ISO disk file that's stored in Amazon S3, ins3://bucket/keyformat. -
#windows_configuration ⇒ Types::WindowsConfiguration
Specifies Windows settings for ISO imports.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for your disk image import.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions to import an image from a Microsoft ISO file. If you don't provide a role, Image Builder uses the Image Builder service-linked role in your account, and creates it if it doesn't exist.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#infrastructure_configuration_arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration resource that's used for launching the EC2 instance on which the ISO image is built.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The CloudWatch Logs log group where Image Builder sends the import
logs. If you specify a log group name outside of the
/aws/imagebuilder/ namespace, you must also provide an
executionRole that has permission to write to that log group.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the image resource that's created from the import. Image Builder generates the image ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name. If an image with the same name and semantic version already exists in your account in the same Amazon Web Services Region, the import creates a new build version for it.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#os_version ⇒ String
The operating system version for the imported image. The only
supported value is Microsoft Windows 11.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system platform for the imported image. Allowed values
include the following: Windows.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#register_image_options ⇒ Types::RegisterImageOptions
Configures Secure Boot and UEFI settings for the imported image.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#semantic_version ⇒ String
The semantic version to attach to the image that's created during the import process. This version follows the semantic version syntax.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags that are attached to image resources created from the import.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#uri ⇒ String
The uri of the ISO disk file that's stored in Amazon S3, in
s3://bucket/key format. The key must end with the .iso, .ISO,
or .Iso extension, and the bucket must be owned by the account
that makes the request.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |
#windows_configuration ⇒ Types::WindowsConfiguration
Specifies Windows settings for ISO imports.
5473 5474 5475 5476 5477 5478 5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5473 class ImportDiskImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :execution_role, :infrastructure_configuration_arn, :uri, :logging_configuration, :tags, :register_image_options, :windows_configuration, :client_token) SENSITIVE = [] include Aws::Structure end |