Class: Aws::Imagebuilder::Types::ImportVmImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ImportVmImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time.
-
#description ⇒ String
The description for the base image that is created by the import process.
-
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The CloudWatch Logs log group where Image Builder sends the import logs.
-
#name ⇒ String
The name of the base image that is created by the import process.
-
#os_version ⇒ String
The operating system version for the imported VM.
-
#platform ⇒ String
The operating system platform for the imported VM.
-
#semantic_version ⇒ String
The semantic version to attach to the base image that was created during the import process.
-
#tags ⇒ Hash<String,String>
Tags that are attached to the import resources.
-
#vm_import_task_id ⇒ String
The
importTaskId(API) orImportTaskId(CLI) from the Amazon EC2 VM import process.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the base image that is created by the import process.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#logging_configuration ⇒ Types::ImageLoggingConfiguration
The CloudWatch Logs log group where Image Builder sends the import
logs. For ImportVmImage, the log group name must be within the
/aws/imagebuilder/ namespace.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the base image that is created by the import process. Image Builder generates the image ARN from a normalized form of the name, so names that differ only in case, spaces, or underscores count as the same name. If an image with the same name and semantic version already exists in your account in the same Amazon Web Services Region, the import creates a new build version for it.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#os_version ⇒ String
The operating system version for the imported VM.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#platform ⇒ String
The operating system platform for the imported VM.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#semantic_version ⇒ String
The semantic version to attach to the base image that was created during the import process. This version follows the semantic version syntax.
Assignment: For the first three nodes, you can assign any positive integer value, including zero. The upper limit is 2^30-1, or 1073741823, for each node. Image Builder automatically assigns the build number to the fourth node.
Patterns: You can use any numeric pattern that adheres to the assignment requirements for the nodes that you can assign. For example, you might choose a software version pattern, such as 1.0.0, or a date, such as 2021.01.01.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags that are attached to the import resources.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |
#vm_import_task_id ⇒ String
The importTaskId (API) or ImportTaskId (CLI) from the Amazon EC2
VM import process. The import task doesn't need to be complete when
you call ImportVmImage - Image Builder monitors the task and
finishes creating the image when the task completes.
5589 5590 5591 5592 5593 5594 5595 5596 5597 5598 5599 5600 5601 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5589 class ImportVmImageRequest < Struct.new( :name, :semantic_version, :description, :platform, :os_version, :vm_import_task_id, :logging_configuration, :tags, :client_token) SENSITIVE = [] include Aws::Structure end |