Class: Aws::Imagebuilder::Types::InfrastructureConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::InfrastructureConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Details of the infrastructure configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration.
-
#date_created ⇒ String
The date on which the infrastructure configuration was created.
-
#date_updated ⇒ String
The date on which the infrastructure configuration was last updated.
-
#description ⇒ String
The description of the infrastructure configuration.
-
#instance_metadata_options ⇒ Types::InstanceMetadataOptions
The instance metadata option settings for the infrastructure configuration.
-
#instance_profile_name ⇒ String
The instance profile of the infrastructure configuration.
-
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration.
-
#key_pair ⇒ String
The Amazon EC2 key pair of the infrastructure configuration.
-
#logging ⇒ Types::Logging
The logging configuration of the infrastructure configuration.
-
#name ⇒ String
The name of the infrastructure configuration.
-
#placement ⇒ Types::Placement
The instance placement settings that define where the instances that are launched from your image will run.
-
#resource_tags ⇒ Hash<String,String>
The tags attached to the resource created by Image Builder.
-
#security_group_ids ⇒ Array<String>
The security group IDs of the infrastructure configuration.
-
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) for the SNS topic to which we send image build event notifications.
-
#subnet_id ⇒ String
The subnet ID of the infrastructure configuration.
-
#tags ⇒ Hash<String,String>
The tags of the infrastructure configuration.
-
#terminate_instance_on_failure ⇒ Boolean
The terminate instance on failure configuration of the infrastructure configuration.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ String
The date on which the infrastructure configuration was created.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#date_updated ⇒ String
The date on which the infrastructure configuration was last updated.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#instance_metadata_options ⇒ Types::InstanceMetadataOptions
The instance metadata option settings for the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#instance_profile_name ⇒ String
The instance profile of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#key_pair ⇒ String
The Amazon EC2 key pair of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#logging ⇒ Types::Logging
The logging configuration of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#placement ⇒ Types::Placement
The instance placement settings that define where the instances that are launched from your image will run.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Hash<String,String>
The tags attached to the resource created by Image Builder.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The security group IDs of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#sns_topic_arn ⇒ String
The Amazon Resource Name (ARN) for the SNS topic to which we send image build event notifications.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#subnet_id ⇒ String
The subnet ID of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |
#terminate_instance_on_failure ⇒ Boolean
The terminate instance on failure configuration of the infrastructure configuration.
5118 5119 5120 5121 5122 5123 5124 5125 5126 5127 5128 5129 5130 5131 5132 5133 5134 5135 5136 5137 5138 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5118 class InfrastructureConfiguration < Struct.new( :arn, :name, :description, :instance_types, :instance_profile_name, :security_group_ids, :subnet_id, :logging, :key_pair, :terminate_instance_on_failure, :sns_topic_arn, :date_created, :date_updated, :resource_tags, :instance_metadata_options, :tags, :placement) SENSITIVE = [] include Aws::Structure end |