Class: Aws::Imagebuilder::Types::InfrastructureConfigurationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::InfrastructureConfigurationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
The infrastructure used when building Amazon EC2 AMIs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration.
-
#date_created ⇒ String
The date on which the infrastructure configuration was created.
-
#date_updated ⇒ String
The date on which the infrastructure configuration was last updated.
-
#description ⇒ String
The description of the infrastructure configuration.
-
#instance_profile_name ⇒ String
The instance profile of the infrastructure configuration.
-
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration.
-
#name ⇒ String
The name of the infrastructure configuration.
-
#placement ⇒ Types::Placement
The instance placement settings that define where the instances that are launched from your image will run.
-
#resource_tags ⇒ Hash<String,String>
The tags attached to the image created by Image Builder.
-
#tags ⇒ Hash<String,String>
The tags of the infrastructure configuration.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the infrastructure configuration.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ String
The date on which the infrastructure configuration was created.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#date_updated ⇒ String
The date on which the infrastructure configuration was last updated.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the infrastructure configuration.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#instance_profile_name ⇒ String
The instance profile of the infrastructure configuration.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#instance_types ⇒ Array<String>
The instance types of the infrastructure configuration.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the infrastructure configuration.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#placement ⇒ Types::Placement
The instance placement settings that define where the instances that are launched from your image will run.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#resource_tags ⇒ Hash<String,String>
The tags attached to the image created by Image Builder.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags of the infrastructure configuration.
5144 5145 5146 5147 5148 5149 5150 5151 5152 5153 5154 5155 5156 5157 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5144 class InfrastructureConfigurationSummary < Struct.new( :arn, :name, :description, :date_created, :date_updated, :resource_tags, :tags, :instance_types, :instance_profile_name, :placement) SENSITIVE = [] include Aws::Structure end |