Class: Aws::Imagebuilder::Types::LaunchPermissionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::LaunchPermissionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Describes the configuration for a launch permission. The launch
permission modification request is sent to the Amazon EC2
ModifyImageAttribute API on behalf of the user for each Region
they have selected to distribute the AMI. To make an AMI public, set
the launch permission authorized accounts to all. See the examples
for making an AMI public at Amazon EC2 ModifyImageAttribute.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#organization_arns ⇒ Array<String>
The ARN for an Amazon Web Services Organization that you want to share your AMI with.
-
#organizational_unit_arns ⇒ Array<String>
The ARN for an Organizations organizational unit (OU) that you want to share your AMI with.
-
#user_groups ⇒ Array<String>
The name of the group.
-
#user_ids ⇒ Array<String>
The Amazon Web Services account ID.
Instance Attribute Details
#organization_arns ⇒ Array<String>
The ARN for an Amazon Web Services Organization that you want to share your AMI with. For more information, see What is Organizations?.
5474 5475 5476 5477 5478 5479 5480 5481 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5474 class LaunchPermissionConfiguration < Struct.new( :user_ids, :user_groups, :organization_arns, :organizational_unit_arns) SENSITIVE = [] include Aws::Structure end |
#organizational_unit_arns ⇒ Array<String>
The ARN for an Organizations organizational unit (OU) that you want to share your AMI with. For more information about key concepts for Organizations, see Organizations terminology and concepts.
5474 5475 5476 5477 5478 5479 5480 5481 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5474 class LaunchPermissionConfiguration < Struct.new( :user_ids, :user_groups, :organization_arns, :organizational_unit_arns) SENSITIVE = [] include Aws::Structure end |
#user_groups ⇒ Array<String>
The name of the group.
5474 5475 5476 5477 5478 5479 5480 5481 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5474 class LaunchPermissionConfiguration < Struct.new( :user_ids, :user_groups, :organization_arns, :organizational_unit_arns) SENSITIVE = [] include Aws::Structure end |
#user_ids ⇒ Array<String>
The Amazon Web Services account ID.
5474 5475 5476 5477 5478 5479 5480 5481 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 5474 class LaunchPermissionConfiguration < Struct.new( :user_ids, :user_groups, :organization_arns, :organizational_unit_arns) SENSITIVE = [] include Aws::Structure end |