Class: Aws::Imagebuilder::Types::LifecyclePolicyDetailExclusionRulesAmis
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::LifecyclePolicyDetailExclusionRulesAmis
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Defines criteria for AMIs that are excluded from lifecycle actions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#is_public ⇒ Boolean
Configures whether public AMIs are excluded from the lifecycle action.
-
#last_launched ⇒ Types::LifecyclePolicyDetailExclusionRulesAmisLastLaunched
Configures Image Builder to exclude AMIs that were launched within the specified time period from lifecycle actions.
-
#regions ⇒ Array<String>
Configures Amazon Web Services Regions that are excluded from the lifecycle action.
-
#shared_accounts ⇒ Array<String>
The lifecycle action doesn't apply to AMIs that are shared with any of the specified Amazon Web Services accounts.
-
#tag_map ⇒ Hash<String,String>
Lifecycle actions don't apply to AMIs that have any of these tags.
Instance Attribute Details
#is_public ⇒ Boolean
Configures whether public AMIs are excluded from the lifecycle action.
6545 6546 6547 6548 6549 6550 6551 6552 6553 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6545 class LifecyclePolicyDetailExclusionRulesAmis < Struct.new( :is_public, :regions, :shared_accounts, :last_launched, :tag_map) SENSITIVE = [] include Aws::Structure end |
#last_launched ⇒ Types::LifecyclePolicyDetailExclusionRulesAmisLastLaunched
Configures Image Builder to exclude AMIs that were launched within the specified time period from lifecycle actions. AMIs with no recorded last-launched time aren't excluded by this rule.
6545 6546 6547 6548 6549 6550 6551 6552 6553 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6545 class LifecyclePolicyDetailExclusionRulesAmis < Struct.new( :is_public, :regions, :shared_accounts, :last_launched, :tag_map) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
Configures Amazon Web Services Regions that are excluded from the lifecycle action.
6545 6546 6547 6548 6549 6550 6551 6552 6553 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6545 class LifecyclePolicyDetailExclusionRulesAmis < Struct.new( :is_public, :regions, :shared_accounts, :last_launched, :tag_map) SENSITIVE = [] include Aws::Structure end |
#shared_accounts ⇒ Array<String>
The lifecycle action doesn't apply to AMIs that are shared with any of the specified Amazon Web Services accounts.
6545 6546 6547 6548 6549 6550 6551 6552 6553 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6545 class LifecyclePolicyDetailExclusionRulesAmis < Struct.new( :is_public, :regions, :shared_accounts, :last_launched, :tag_map) SENSITIVE = [] include Aws::Structure end |
#tag_map ⇒ Hash<String,String>
Lifecycle actions don't apply to AMIs that have any of these tags. Both the key and the value must match.
6545 6546 6547 6548 6549 6550 6551 6552 6553 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6545 class LifecyclePolicyDetailExclusionRulesAmis < Struct.new( :is_public, :regions, :shared_accounts, :last_launched, :tag_map) SENSITIVE = [] include Aws::Structure end |