Class: Aws::Imagebuilder::Types::LifecyclePolicySummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::LifecyclePolicySummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Contains a summary of lifecycle policy resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the lifecycle policy.
-
#date_created ⇒ Time
The timestamp when Image Builder created the lifecycle policy resource.
-
#date_last_run ⇒ Time
The timestamp for the last time Image Builder ran the lifecycle policy.
-
#date_updated ⇒ Time
The timestamp when Image Builder updated the lifecycle policy resource.
-
#description ⇒ String
Optional description for the lifecycle policy.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that Image Builder uses to run the lifecycle policy.
-
#name ⇒ String
The name of the lifecycle policy.
-
#resource_type ⇒ String
The type of resources the lifecycle policy targets.
-
#status ⇒ String
The lifecycle policy resource status.
-
#tags ⇒ Hash<String,String>
To help manage your lifecycle policy resources, you can assign your own metadata to each resource in the form of tags.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the lifecycle policy.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#date_created ⇒ Time
The timestamp when Image Builder created the lifecycle policy resource.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#date_last_run ⇒ Time
The timestamp for the last time Image Builder ran the lifecycle policy.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#date_updated ⇒ Time
The timestamp when Image Builder updated the lifecycle policy resource.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Optional description for the lifecycle policy.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that Image Builder uses to run the lifecycle policy.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the lifecycle policy.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of resources the lifecycle policy targets.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The lifecycle policy resource status.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
To help manage your lifecycle policy resources, you can assign your own metadata to each resource in the form of tags. Each tag consists of a key and an optional value, both of which you define.
6714 6715 6716 6717 6718 6719 6720 6721 6722 6723 6724 6725 6726 6727 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6714 class LifecyclePolicySummary < Struct.new( :arn, :name, :description, :status, :execution_role, :resource_type, :date_created, :date_updated, :date_last_run, :tags) SENSITIVE = [] include Aws::Structure end |