Class: Aws::Imagebuilder::Types::ListComponentBuildVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListComponentBuildVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_summary_list ⇒ Array<Types::ComponentSummary>
The list of component summaries.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#component_summary_list ⇒ Array<Types::ComponentSummary>
The list of component summaries. Each summary represents one build version of the specified component version, or of the components that your account owns if you didn't specify an ARN. Deprecated build versions aren't included.
6775 6776 6777 6778 6779 6780 6781 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6775 class ListComponentBuildVersionsResponse < Struct.new( :request_id, :component_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
6775 6776 6777 6778 6779 6780 6781 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6775 class ListComponentBuildVersionsResponse < Struct.new( :request_id, :component_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
6775 6776 6777 6778 6779 6780 6781 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6775 class ListComponentBuildVersionsResponse < Struct.new( :request_id, :component_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |