Class: Aws::Imagebuilder::Types::ListComponentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#by_nameBoolean

Returns the list of components for the specified name.

Returns:

  • (Boolean)


6144
6145
6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6144

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

Use the following filters to streamline results:

  • description

  • name

  • platform

  • supportedOsVersion

  • type

  • version

Returns:



6144
6145
6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6144

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Specify the maximum number of items to return in a request.

Returns:

  • (Integer)


6144
6145
6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6144

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token to specify where to start paginating. This is the nextToken from a previously truncated response.

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6144

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

Filters results based on the type of owner for the component. By default, this request returns a list of components that your account owns. To see results for other types of owners, you can specify components that Amazon manages, third party components, or components that other accounts have shared with you.

Returns:

  • (String)


6144
6145
6146
6147
6148
6149
6150
6151
6152
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6144

class ListComponentsRequest < Struct.new(
  :owner,
  :filters,
  :by_name,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end