Class: Aws::Imagebuilder::Types::ListComponentsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListComponentsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#component_version_list ⇒ Array<Types::ComponentVersion>
The list of component semantic versions.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#component_version_list ⇒ Array<Types::ComponentVersion>
The list of component semantic versions.
6863 6864 6865 6866 6867 6868 6869 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6863 class ListComponentsResponse < Struct.new( :request_id, :component_version_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
6863 6864 6865 6866 6867 6868 6869 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6863 class ListComponentsResponse < Struct.new( :request_id, :component_version_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
6863 6864 6865 6866 6867 6868 6869 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6863 class ListComponentsResponse < Struct.new( :request_id, :component_version_list, :next_token) SENSITIVE = [] include Aws::Structure end |