Class: Aws::Imagebuilder::Types::ListContainerRecipesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListContainerRecipesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results:.
-
#max_results ⇒ Integer
The maximum number of items to return in a single request.
-
#next_token ⇒ String
A token to specify where to start paginating.
-
#owner ⇒ String
Returns container recipes belonging to the specified owner, that have been shared with you.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results:
-
containerType -
name -
parentImage -
platform
6901 6902 6903 6904 6905 6906 6907 6908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6901 class ListContainerRecipesRequest < Struct.new( :owner, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in a single request.
6901 6902 6903 6904 6905 6906 6907 6908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6901 class ListContainerRecipesRequest < Struct.new( :owner, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. Use the nextToken
value from a previously truncated response.
6901 6902 6903 6904 6905 6906 6907 6908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6901 class ListContainerRecipesRequest < Struct.new( :owner, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#owner ⇒ String
Returns container recipes belonging to the specified owner, that
have been shared with you. You can omit this field to return
container recipes belonging to your account. For container recipes,
the valid owner values are Self, Shared, and Amazon.
6901 6902 6903 6904 6905 6906 6907 6908 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6901 class ListContainerRecipesRequest < Struct.new( :owner, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |