Class: Aws::Imagebuilder::Types::ListDistributionConfigurationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListDistributionConfigurationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#distribution_configuration_summary_list ⇒ Array<Types::DistributionConfigurationSummary>
The list of distributions.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#distribution_configuration_summary_list ⇒ Array<Types::DistributionConfigurationSummary>
The list of distributions.
6288 6289 6290 6291 6292 6293 6294 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6288 class ListDistributionConfigurationsResponse < Struct.new( :request_id, :distribution_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
6288 6289 6290 6291 6292 6293 6294 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6288 class ListDistributionConfigurationsResponse < Struct.new( :request_id, :distribution_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
6288 6289 6290 6291 6292 6293 6294 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6288 class ListDistributionConfigurationsResponse < Struct.new( :request_id, :distribution_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |