Class: Aws::Imagebuilder::Types::ListImageBuildVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListImageBuildVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results:.
-
#image_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image version whose build versions you want to retrieve.
-
#max_results ⇒ Integer
The maximum number of items to return in a single request.
-
#next_token ⇒ String
A token to specify where to start paginating.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
Use the following filters to streamline results:
-
name -
osVersion -
platform -
type -
version
7016 7017 7018 7019 7020 7021 7022 7023 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7016 class ListImageBuildVersionsRequest < Struct.new( :image_version_arn, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#image_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image version whose build
versions you want to retrieve. The ARN must specify an exact version
(<major>.<minor>.<patch>) - wildcards aren't allowed. This
parameter is optional. If you don't specify it, Image Builder
returns build versions for all of the images in your account.
7016 7017 7018 7019 7020 7021 7022 7023 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7016 class ListImageBuildVersionsRequest < Struct.new( :image_version_arn, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in a single request.
7016 7017 7018 7019 7020 7021 7022 7023 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7016 class ListImageBuildVersionsRequest < Struct.new( :image_version_arn, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. Use the nextToken
value from a previously truncated response.
7016 7017 7018 7019 7020 7021 7022 7023 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7016 class ListImageBuildVersionsRequest < Struct.new( :image_version_arn, :filters, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |