Class: Aws::Imagebuilder::Types::ListImageBuildVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#image_summary_listArray<Types::ImageSummary>

The list of image build versions.

Returns:



6352
6353
6354
6355
6356
6357
6358
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6352

class ListImageBuildVersionsResponse < Struct.new(
  :request_id,
  :image_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.

Returns:

  • (String)


6352
6353
6354
6355
6356
6357
6358
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6352

class ListImageBuildVersionsResponse < Struct.new(
  :request_id,
  :image_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#request_idString

The request ID that uniquely identifies this request.

Returns:

  • (String)


6352
6353
6354
6355
6356
6357
6358
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6352

class ListImageBuildVersionsResponse < Struct.new(
  :request_id,
  :image_summary_list,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end