Class: Aws::Imagebuilder::Types::ListImageScanFindingAggregationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListImageScanFindingAggregationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::Filter
A filter name and value pair that is used to return a more specific list of results from a list operation.
-
#next_token ⇒ String
A token to specify where to start paginating.
Instance Attribute Details
#filter ⇒ Types::Filter
A filter name and value pair that is used to return a more specific list of results from a list operation. Filters can be used to match a set of resources by specific criteria, such as tags, attributes, or IDs.
6606 6607 6608 6609 6610 6611 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6606 class ListImageScanFindingAggregationsRequest < Struct.new( :filter, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. This is the nextToken from a previously truncated response.
6606 6607 6608 6609 6610 6611 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6606 class ListImageScanFindingAggregationsRequest < Struct.new( :filter, :next_token) SENSITIVE = [] include Aws::Structure end |