Class: Aws::Imagebuilder::Types::ListImageScanFindingAggregationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListImageScanFindingAggregationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Types::Filter
A filter name and value pair that determines the type of aggregation that Image Builder returns.
-
#next_token ⇒ String
A token to specify where to start paginating.
Instance Attribute Details
#filter ⇒ Types::Filter
A filter name and value pair that determines the type of aggregation that Image Builder returns. Use one of the following filter names:
-
imageBuildVersionArn -
imagePipelineArn -
vulnerabilityId
If you don't specify a filter, Image Builder returns an aggregation for your account.
7304 7305 7306 7307 7308 7309 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7304 class ListImageScanFindingAggregationsRequest < Struct.new( :filter, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. Use the nextToken
value from a previously truncated response.
7304 7305 7306 7307 7308 7309 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7304 class ListImageScanFindingAggregationsRequest < Struct.new( :filter, :next_token) SENSITIVE = [] include Aws::Structure end |