Class: Aws::Imagebuilder::Types::ListImagesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListImagesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_version_list ⇒ Array<Types::ImageVersion>
The list of image semantic versions.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#image_version_list ⇒ Array<Types::ImageVersion>
The list of image semantic versions.
Filtering: You can use wildcards (x) to specify the most recent versions or nodes when selecting the base image or components for your recipe. When you use a wildcard in any node, all nodes to the right of the first wildcard must also be wildcards.
7506 7507 7508 7509 7510 7511 7512 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7506 class ListImagesResponse < Struct.new( :request_id, :image_version_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
7506 7507 7508 7509 7510 7511 7512 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7506 class ListImagesResponse < Struct.new( :request_id, :image_version_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
7506 7507 7508 7509 7510 7511 7512 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7506 class ListImagesResponse < Struct.new( :request_id, :image_version_list, :next_token) SENSITIVE = [] include Aws::Structure end |