Class: Aws::Imagebuilder::Types::ListInfrastructureConfigurationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListInfrastructureConfigurationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#infrastructure_configuration_summary_list ⇒ Array<Types::InfrastructureConfigurationSummary>
The list of infrastructure configurations.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#infrastructure_configuration_summary_list ⇒ Array<Types::InfrastructureConfigurationSummary>
The list of infrastructure configurations.
6851 6852 6853 6854 6855 6856 6857 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6851 class ListInfrastructureConfigurationsResponse < Struct.new( :request_id, :infrastructure_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
6851 6852 6853 6854 6855 6856 6857 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6851 class ListInfrastructureConfigurationsResponse < Struct.new( :request_id, :infrastructure_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
6851 6852 6853 6854 6855 6856 6857 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 6851 class ListInfrastructureConfigurationsResponse < Struct.new( :request_id, :infrastructure_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |