Class: Aws::Imagebuilder::Types::ListInfrastructureConfigurationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListInfrastructureConfigurationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#infrastructure_configuration_summary_list ⇒ Array<Types::InfrastructureConfigurationSummary>
The list of infrastructure configurations.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#request_id ⇒ String
The request ID that uniquely identifies this request.
Instance Attribute Details
#infrastructure_configuration_summary_list ⇒ Array<Types::InfrastructureConfigurationSummary>
The list of infrastructure configurations.
7554 7555 7556 7557 7558 7559 7560 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7554 class ListInfrastructureConfigurationsResponse < Struct.new( :request_id, :infrastructure_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
7554 7555 7556 7557 7558 7559 7560 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7554 class ListInfrastructureConfigurationsResponse < Struct.new( :request_id, :infrastructure_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#request_id ⇒ String
The request ID that uniquely identifies this request.
7554 7555 7556 7557 7558 7559 7560 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7554 class ListInfrastructureConfigurationsResponse < Struct.new( :request_id, :infrastructure_configuration_summary_list, :next_token) SENSITIVE = [] include Aws::Structure end |