Class: Aws::Imagebuilder::Types::ListLifecycleExecutionResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListLifecycleExecutionResourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lifecycle_execution_id ⇒ String
The unique identifier for a runtime instance of the lifecycle policy.
-
#max_results ⇒ Integer
The maximum number of items to return in a single request.
-
#next_token ⇒ String
A token to specify where to start paginating.
-
#parent_resource_id ⇒ String
The Amazon Resource Name (ARN) of an image build version to get the output resources for, such as AMIs or container images in Amazon ECR.
Instance Attribute Details
#lifecycle_execution_id ⇒ String
The unique identifier for a runtime instance of the lifecycle policy.
7589 7590 7591 7592 7593 7594 7595 7596 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7589 class ListLifecycleExecutionResourcesRequest < Struct.new( :lifecycle_execution_id, :parent_resource_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to return in a single request.
7589 7590 7591 7592 7593 7594 7595 7596 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7589 class ListLifecycleExecutionResourcesRequest < Struct.new( :lifecycle_execution_id, :parent_resource_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. Use the nextToken
value from a previously truncated response.
7589 7590 7591 7592 7593 7594 7595 7596 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7589 class ListLifecycleExecutionResourcesRequest < Struct.new( :lifecycle_execution_id, :parent_resource_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#parent_resource_id ⇒ String
The Amazon Resource Name (ARN) of an image build version to get the
output resources for, such as AMIs or container images in Amazon
ECR. You can get this value from the resourceId in the top-level
response. If you leave this property empty, the response lists the
Image Builder resources that the lifecycle execution identified for
lifecycle actions. If the image build version that you specify in
parentResourceId wasn't part of this lifecycle execution, the
response contains an empty list.
7589 7590 7591 7592 7593 7594 7595 7596 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7589 class ListLifecycleExecutionResourcesRequest < Struct.new( :lifecycle_execution_id, :parent_resource_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |