Class: Aws::Imagebuilder::Types::ListLifecycleExecutionResourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListLifecycleExecutionResourcesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lifecycle_execution_id ⇒ String
The unique identifier for the runtime instance of the lifecycle policy.
-
#lifecycle_execution_state ⇒ Types::LifecycleExecutionState
The current state of the lifecycle runtime instance.
-
#next_token ⇒ String
The next token used for paginated responses.
-
#resources ⇒ Array<Types::LifecycleExecutionResource>
A list of resources that were identified for lifecycle actions.
Instance Attribute Details
#lifecycle_execution_id ⇒ String
The unique identifier for the runtime instance of the lifecycle policy.
7620 7621 7622 7623 7624 7625 7626 7627 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7620 class ListLifecycleExecutionResourcesResponse < Struct.new( :lifecycle_execution_id, :lifecycle_execution_state, :resources, :next_token) SENSITIVE = [] include Aws::Structure end |
#lifecycle_execution_state ⇒ Types::LifecycleExecutionState
The current state of the lifecycle runtime instance.
7620 7621 7622 7623 7624 7625 7626 7627 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7620 class ListLifecycleExecutionResourcesResponse < Struct.new( :lifecycle_execution_id, :lifecycle_execution_state, :resources, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next token used for paginated responses. When this field isn't empty, there are additional elements that the service hasn't included in this request. Use this token with the next request to retrieve additional objects.
7620 7621 7622 7623 7624 7625 7626 7627 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7620 class ListLifecycleExecutionResourcesResponse < Struct.new( :lifecycle_execution_id, :lifecycle_execution_state, :resources, :next_token) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<Types::LifecycleExecutionResource>
A list of resources that were identified for lifecycle actions.
7620 7621 7622 7623 7624 7625 7626 7627 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7620 class ListLifecycleExecutionResourcesResponse < Struct.new( :lifecycle_execution_id, :lifecycle_execution_state, :resources, :next_token) SENSITIVE = [] include Aws::Structure end |