Class: Aws::Imagebuilder::Types::ListLifecycleExecutionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::ListLifecycleExecutionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return in a single request.
-
#next_token ⇒ String
A token to specify where to start paginating.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource for which to list lifecycle executions.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return in a single request.
7648 7649 7650 7651 7652 7653 7654 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7648 class ListLifecycleExecutionsRequest < Struct.new( :max_results, :next_token, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token to specify where to start paginating. Use the nextToken
value from a previously truncated response.
7648 7649 7650 7651 7652 7653 7654 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7648 class ListLifecycleExecutionsRequest < Struct.new( :max_results, :next_token, :resource_arn) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource for which to list lifecycle executions. Specify a lifecycle policy ARN to list its executions, or an image build version ARN to list the executions that StartResourceStateUpdate started for that image. Other ARN types aren't valid for this request.
7648 7649 7650 7651 7652 7653 7654 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7648 class ListLifecycleExecutionsRequest < Struct.new( :max_results, :next_token, :resource_arn) SENSITIVE = [] include Aws::Structure end |