Class: Aws::Imagebuilder::Types::PackageVulnerabilityDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::PackageVulnerabilityDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Information about package vulnerability findings.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cvss ⇒ Array<Types::CvssScore>
CVSS scores for one or more vulnerabilities that Amazon Inspector identified for a package.
-
#reference_urls ⇒ Array<String>
Links to web pages that contain details about the vulnerabilities that Amazon Inspector identified for the package.
-
#related_vulnerabilities ⇒ Array<String>
Vulnerabilities that are often related to the findings for the package.
-
#source ⇒ String
The source of the vulnerability information.
-
#source_url ⇒ String
A link to the source of the vulnerability information.
-
#vendor_created_at ⇒ Time
The date and time when this vulnerability was first added to the vendor's database.
-
#vendor_severity ⇒ String
The severity that the vendor assigned to this vulnerability type.
-
#vendor_updated_at ⇒ Time
The date and time when the vendor last updated this vulnerability in their database.
-
#vulnerability_id ⇒ String
A unique identifier for this vulnerability.
-
#vulnerable_packages ⇒ Array<Types::VulnerablePackage>
The packages that this vulnerability impacts.
Instance Attribute Details
#cvss ⇒ Array<Types::CvssScore>
CVSS scores for one or more vulnerabilities that Amazon Inspector identified for a package.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#reference_urls ⇒ Array<String>
Links to web pages that contain details about the vulnerabilities that Amazon Inspector identified for the package.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#related_vulnerabilities ⇒ Array<String>
Vulnerabilities that are often related to the findings for the package.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the vulnerability information.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#source_url ⇒ String
A link to the source of the vulnerability information.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#vendor_created_at ⇒ Time
The date and time when this vulnerability was first added to the vendor's database.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#vendor_severity ⇒ String
The severity that the vendor assigned to this vulnerability type.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#vendor_updated_at ⇒ Time
The date and time when the vendor last updated this vulnerability in their database.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#vulnerability_id ⇒ String
A unique identifier for this vulnerability.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |
#vulnerable_packages ⇒ Array<Types::VulnerablePackage>
The packages that this vulnerability impacts.
7437 7438 7439 7440 7441 7442 7443 7444 7445 7446 7447 7448 7449 7450 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7437 class PackageVulnerabilityDetails < Struct.new( :vulnerability_id, :vulnerable_packages, :source, :cvss, :related_vulnerabilities, :source_url, :vendor_severity, :vendor_created_at, :vendor_updated_at, :reference_urls) SENSITIVE = [] include Aws::Structure end |