Class: Aws::Imagebuilder::Types::PipelineLoggingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::PipelineLoggingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
The logging configuration that's defined for pipeline execution.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_log_group_name ⇒ String
Specifies the CloudWatch Logs log group name for image build logs.
-
#pipeline_log_group_name ⇒ String
Specifies the CloudWatch Logs log group name for pipeline execution logs.
Instance Attribute Details
#image_log_group_name ⇒ String
Specifies the CloudWatch Logs log group name for image build logs.
The log group name can contain alphanumeric characters, hyphens,
underscores, forward slashes, and periods, up to 512 characters. Log
group names not starting with /aws/imagebuilder/ require an
executionRole with CloudWatch Logs write permissions. If not
specified, defaults to /aws/imagebuilder/image-name.
7475 7476 7477 7478 7479 7480 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7475 class PipelineLoggingConfiguration < Struct.new( :image_log_group_name, :pipeline_log_group_name) SENSITIVE = [] include Aws::Structure end |
#pipeline_log_group_name ⇒ String
Specifies the CloudWatch Logs log group name for pipeline execution
logs. The log group name can contain alphanumeric characters,
hyphens, underscores, forward slashes, and periods, up to 512
characters. Log group names not starting with /aws/imagebuilder/
require an executionRole with CloudWatch Logs write permissions.
If not specified, defaults to
/aws/imagebuilder/pipeline/pipeline-name.
7475 7476 7477 7478 7479 7480 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7475 class PipelineLoggingConfiguration < Struct.new( :image_log_group_name, :pipeline_log_group_name) SENSITIVE = [] include Aws::Structure end |