Class: Aws::Imagebuilder::Types::RetryImageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


7820
7821
7822
7823
7824
7825
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7820

class RetryImageRequest < Struct.new(
  :image_build_version_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#image_build_version_arnString

The source image Amazon Resource Name (ARN) to retry.

Returns:

  • (String)


7820
7821
7822
7823
7824
7825
# File 'lib/aws-sdk-imagebuilder/types.rb', line 7820

class RetryImageRequest < Struct.new(
  :image_build_version_arn,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end