Class: Aws::Imagebuilder::Types::RetryImageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::RetryImageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version that you want to retry.
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier you provide to ensure that the operation runs no more than one time. If you retry a request with the same client token, Image Builder returns the original response without running the operation again. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
8642 8643 8644 8645 8646 8647 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8642 class RetryImageRequest < Struct.new( :image_build_version_arn, :client_token) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version that you
want to retry. The image must be in the FAILED or CANCELLED
state.
8642 8643 8644 8645 8646 8647 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8642 class RetryImageRequest < Struct.new( :image_build_version_arn, :client_token) SENSITIVE = [] include Aws::Structure end |