Class: Aws::Imagebuilder::Types::SendWorkflowStepActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::SendWorkflowStepActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action to perform on the paused workflow step.
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version associated with the workflow step execution.
-
#reason ⇒ String
The reason for the action.
-
#step_execution_id ⇒ String
Uniquely identifies the workflow step that sent the step action.
Instance Attribute Details
#action ⇒ String
The action to perform on the paused workflow step. The workflow step must be in a waiting state to accept an action. The request fails if the step has already timed out or been actioned.
8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8093 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8093 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version associated with the workflow step execution. This value must match the image that owns the waiting step. If the ARN does not correspond to the image running the workflow, then the request fails with a validation error.
8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8093 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason for the action. This value is stored with the step execution record and is accessible in subsequent workflow steps via step output references.
8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8093 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#step_execution_id ⇒ String
Uniquely identifies the workflow step that sent the step action.
8093 8094 8095 8096 8097 8098 8099 8100 8101 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8093 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |