Class: Aws::Imagebuilder::Types::SendWorkflowStepActionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::SendWorkflowStepActionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The action for the image creation process to take while a workflow
WaitForActionstep waits for an asynchronous action to complete. -
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version to send action for.
-
#reason ⇒ String
The reason why this action is sent.
-
#step_execution_id ⇒ String
Uniquely identifies the workflow step that sent the step action.
Instance Attribute Details
#action ⇒ String
The action for the image creation process to take while a workflow
WaitForAction step waits for an asynchronous action to complete.
8001 8002 8003 8004 8005 8006 8007 8008 8009 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8001 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
8001 8002 8003 8004 8005 8006 8007 8008 8009 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8001 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version to send action for.
8001 8002 8003 8004 8005 8006 8007 8008 8009 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8001 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason why this action is sent.
8001 8002 8003 8004 8005 8006 8007 8008 8009 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8001 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |
#step_execution_id ⇒ String
Uniquely identifies the workflow step that sent the step action.
8001 8002 8003 8004 8005 8006 8007 8008 8009 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8001 class SendWorkflowStepActionRequest < Struct.new( :step_execution_id, :image_build_version_arn, :action, :reason, :client_token) SENSITIVE = [] include Aws::Structure end |