Class: Aws::Imagebuilder::Types::SsmParameterConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::SsmParameterConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Configuration for a single Parameter in the Amazon Web Services Systems Manager (SSM) Parameter Store in a given Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ami_account_id ⇒ String
Specify the account that will own the Parameter in a given Region.
-
#data_type ⇒ String
The data type specifies what type of value the Parameter contains.
-
#parameter_name ⇒ String
This is the name of the Parameter in the target Region or account.
Instance Attribute Details
#ami_account_id ⇒ String
Specify the account that will own the Parameter in a given Region. During distribution, this account must be specified in distribution settings as a target account for the Region.
8226 8227 8228 8229 8230 8231 8232 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8226 class SsmParameterConfiguration < Struct.new( :ami_account_id, :parameter_name, :data_type) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
The data type specifies what type of value the Parameter contains.
We recommend that you use data type aws:ec2:image.
8226 8227 8228 8229 8230 8231 8232 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8226 class SsmParameterConfiguration < Struct.new( :ami_account_id, :parameter_name, :data_type) SENSITIVE = [] include Aws::Structure end |
#parameter_name ⇒ String
This is the name of the Parameter in the target Region or account. The image distribution creates the Parameter if it doesn't already exist. Otherwise, it updates the parameter.
8226 8227 8228 8229 8230 8231 8232 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8226 class SsmParameterConfiguration < Struct.new( :ami_account_id, :parameter_name, :data_type) SENSITIVE = [] include Aws::Structure end |