Class: Aws::Imagebuilder::Types::StartResourceStateUpdateRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#exclusion_rulesTypes::ResourceStateUpdateExclusionRules

Skip action on the image resource and associated resources if specified exclusion rules are met.



8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#execution_roleString

The name or Amazon Resource Name (ARN) of the IAM role that’s used to update image state.

Returns:

  • (String)


8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#include_resourcesTypes::ResourceStateUpdateIncludeResources

Specifies which image resources to include in the state update. When specified, the lifecycle action applies to underlying resources. These resources include AMIs, snapshots, and containers in addition to the Image Builder image resource. Requires executionRole to also be specified. To delete an image and its underlying resources, you must specify includeResources. To delete only the Image Builder image record without affecting underlying resources, use the DeleteImage API instead.



8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the image build version to update. The image must be in one of these terminal states: AVAILABLE, DEPRECATED, DISABLED, FAILED, or CANCELLED. Images with FAILED or CANCELLED status can transition only to DELETED.

Returns:

  • (String)


8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#stateTypes::ResourceState

Specifies the lifecycle action to take for this request. For AMI-based images, valid values are AVAILABLE, DEPRECATED, DISABLED, and DELETED. For container-based images, only DELETED is supported.



8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#update_atTime

Specifies the timestamp when the state transition takes effect. Use this parameter only when the target status is DEPRECATED. The value must be a future time.

Returns:

  • (Time)


8346
8347
8348
8349
8350
8351
8352
8353
8354
8355
8356
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346

class StartResourceStateUpdateRequest < Struct.new(
  :resource_arn,
  :state,
  :execution_role,
  :include_resources,
  :exclusion_rules,
  :update_at,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end