Class: Aws::Imagebuilder::Types::StartResourceStateUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::StartResourceStateUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#exclusion_rules ⇒ Types::ResourceStateUpdateExclusionRules
Skip action on the image resource and associated resources if specified exclusion rules are met.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that’s used to update image state.
-
#include_resources ⇒ Types::ResourceStateUpdateIncludeResources
Specifies which image resources to include in the state update.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version to update.
-
#state ⇒ Types::ResourceState
Specifies the lifecycle action to take for this request.
-
#update_at ⇒ Time
Specifies the timestamp when the state transition takes effect.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#exclusion_rules ⇒ Types::ResourceStateUpdateExclusionRules
Skip action on the image resource and associated resources if specified exclusion rules are met.
8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that’s used to update image state.
8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#include_resources ⇒ Types::ResourceStateUpdateIncludeResources
Specifies which image resources to include in the state update. When
specified, the lifecycle action applies to underlying resources.
These resources include AMIs, snapshots, and containers in addition
to the Image Builder image resource. Requires executionRole to
also be specified. To delete an image and its underlying resources,
you must specify includeResources. To delete only the Image
Builder image record without affecting underlying resources, use the
DeleteImage API instead.
8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version to update.
The image must be in one of these terminal states: AVAILABLE,
DEPRECATED, DISABLED, FAILED, or CANCELLED. Images with
FAILED or CANCELLED status can transition only to DELETED.
8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#state ⇒ Types::ResourceState
Specifies the lifecycle action to take for this request. For
AMI-based images, valid values are AVAILABLE, DEPRECATED,
DISABLED, and DELETED. For container-based images, only
DELETED is supported.
8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#update_at ⇒ Time
Specifies the timestamp when the state transition takes effect. Use
this parameter only when the target status is DEPRECATED. The
value must be a future time.
8346 8347 8348 8349 8350 8351 8352 8353 8354 8355 8356 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8346 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |