Class: Aws::Imagebuilder::Types::StartResourceStateUpdateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::StartResourceStateUpdateRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#exclusion_rules ⇒ Types::ResourceStateUpdateExclusionRules
Skip action on the image resource and associated resources if specified exclusion rules are met.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that’s used to update image state.
-
#include_resources ⇒ Types::ResourceStateUpdateIncludeResources
A list of image resources to update state for.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the Image Builder resource that is updated.
-
#state ⇒ Types::ResourceState
Indicates the lifecycle action to take for this request.
-
#update_at ⇒ Time
The timestamp that indicates when resources are updated by a lifecycle action.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8241 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#exclusion_rules ⇒ Types::ResourceStateUpdateExclusionRules
Skip action on the image resource and associated resources if specified exclusion rules are met.
8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8241 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that’s used to update image state.
8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8241 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#include_resources ⇒ Types::ResourceStateUpdateIncludeResources
A list of image resources to update state for.
8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8241 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the Image Builder resource that is updated. The state update might also impact associated resources.
8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8241 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#state ⇒ Types::ResourceState
Indicates the lifecycle action to take for this request.
8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8241 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |
#update_at ⇒ Time
The timestamp that indicates when resources are updated by a lifecycle action.
8241 8242 8243 8244 8245 8246 8247 8248 8249 8250 8251 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8241 class StartResourceStateUpdateRequest < Struct.new( :resource_arn, :state, :execution_role, :include_resources, :exclusion_rules, :update_at, :client_token) SENSITIVE = [] include Aws::Structure end |