Class: Aws::Imagebuilder::Types::UpdateImagePipelineRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see [Ensuring idempotency] in the *Amazon EC2 API Reference*.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#container_recipe_arnString

The Amazon Resource Name (ARN) of the container pipeline to update.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the image pipeline.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#distribution_configuration_arnString

The Amazon Resource Name (ARN) of the distribution configuration that Image Builder uses to configure and distribute images that this image pipeline has updated.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#enhanced_image_metadata_enabledBoolean

Collects additional information about the image being created, including the operating system (OS) version and package list. This information is used to enhance the overall experience of using EC2 Image Builder. Enabled by default.

Returns:

  • (Boolean)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#execution_roleString

The name or Amazon Resource Name (ARN) for the IAM role you create that grants Image Builder access to perform workflow actions.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_pipeline_arnString

The Amazon Resource Name (ARN) of the image pipeline that you want to update.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_recipe_arnString

The Amazon Resource Name (ARN) of the image recipe that will be used to configure images updated by this image pipeline.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_scanning_configurationTypes::ImageScanningConfiguration

Contains settings for vulnerability scans.



8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_tagsHash<String,String>

The tags to be applied to the images produced by this pipeline.

Returns:

  • (Hash<String,String>)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#image_tests_configurationTypes::ImageTestsConfiguration

The image test configuration of the image pipeline.



8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#infrastructure_configuration_arnString

The Amazon Resource Name (ARN) of the infrastructure configuration that Image Builder uses to build images that this image pipeline has updated.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#logging_configurationTypes::PipelineLoggingConfiguration

Update logging configuration for the output image that’s created when the pipeline runs.



8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#scheduleTypes::Schedule

The schedule of the image pipeline.

Returns:



8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the image pipeline.

Returns:

  • (String)


8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end

#workflowsArray<Types::WorkflowConfiguration>

Contains the workflows to run for the pipeline.

Returns:



8565
8566
8567
8568
8569
8570
8571
8572
8573
8574
8575
8576
8577
8578
8579
8580
8581
8582
8583
8584
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8565

class UpdateImagePipelineRequest < Struct.new(
  :image_pipeline_arn,
  :description,
  :image_recipe_arn,
  :container_recipe_arn,
  :infrastructure_configuration_arn,
  :distribution_configuration_arn,
  :image_tests_configuration,
  :enhanced_image_metadata_enabled,
  :schedule,
  :status,
  :client_token,
  :image_scanning_configuration,
  :workflows,
  :logging_configuration,
  :execution_role,
  :image_tags)
  SENSITIVE = []
  include Aws::Structure
end