Class: Aws::Imagebuilder::Types::UpdateLifecyclePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::UpdateLifecyclePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request.
-
#description ⇒ String
Optional description for the lifecycle policy.
-
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that Image Builder uses to update the lifecycle policy.
-
#lifecycle_policy_arn ⇒ String
The Amazon Resource Name (ARN) of the lifecycle policy resource.
-
#policy_details ⇒ Array<Types::LifecyclePolicyDetail>
The configuration details for a lifecycle policy resource.
-
#resource_selection ⇒ Types::LifecyclePolicyResourceSelection
Selection criteria for resources that the lifecycle policy applies to.
-
#resource_type ⇒ String
The type of image resource that the lifecycle policy applies to.
-
#status ⇒ String
Indicates whether the lifecycle policy resource is enabled.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference.
A suitable default value is auto-generated. You should normally not need to pass this option.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Optional description for the lifecycle policy.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |
#execution_role ⇒ String
The name or Amazon Resource Name (ARN) of the IAM role that Image Builder uses to update the lifecycle policy.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |
#lifecycle_policy_arn ⇒ String
The Amazon Resource Name (ARN) of the lifecycle policy resource.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |
#policy_details ⇒ Array<Types::LifecyclePolicyDetail>
The configuration details for a lifecycle policy resource.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_selection ⇒ Types::LifecyclePolicyResourceSelection
Selection criteria for resources that the lifecycle policy applies to.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of image resource that the lifecycle policy applies to.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Indicates whether the lifecycle policy resource is enabled.
8748 8749 8750 8751 8752 8753 8754 8755 8756 8757 8758 8759 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8748 class UpdateLifecyclePolicyRequest < Struct.new( :lifecycle_policy_arn, :description, :status, :execution_role, :resource_type, :policy_details, :resource_selection, :client_token) SENSITIVE = [] include Aws::Structure end |