Class: Aws::Imagebuilder::Types::WindowsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::WindowsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Windows-specific configuration settings for an ISO import, including the edition to install from a multi-edition Windows ISO file.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#image_index ⇒ Integer
The 1-based index that specifies which Windows edition to install from a multi-edition Windows ISO file.
Instance Attribute Details
#image_index ⇒ Integer
The 1-based index that specifies which Windows edition to install from a multi-edition Windows ISO file. A Windows ISO can contain a ‘.wim` file with multiple image indexes, each representing a different edition.
8917 8918 8919 8920 8921 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 8917 class WindowsConfiguration < Struct.new( :image_index) SENSITIVE = [] include Aws::Structure end |