Class: Aws::Imagebuilder::Types::Workflow

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-imagebuilder/types.rb

Overview

Defines a process that Image Builder uses to build and test images during the image creation process.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the workflow resource.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#change_descriptionString

Describes what change has been made in this version of the workflow, or what makes this version different from other versions of the workflow.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#dataString

Contains the YAML document content for the workflow.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#date_createdString

The timestamp when Image Builder created the workflow resource.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the workflow.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The KMS key identifier used to encrypt the workflow resource. This can be either the Key ARN or the Alias ARN. For more information, see Key identifiers (KeyId) in the Key Management Service Developer Guide.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the workflow resource.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#ownerString

The owner of the workflow resource.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#parametersArray<Types::WorkflowParameterDetail>

An array of input parameters that that the image workflow uses to control actions or configure settings.

Returns:



9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#stateTypes::WorkflowState

Describes the current status of the workflow and the reason for that status.



9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The tags that apply to the workflow resource

Returns:

  • (Hash<String,String>)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Specifies the image creation stage that the workflow applies to. Image Builder currently supports build and test workflows.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end

#versionString

The workflow resource version. Workflow resources are immutable. To make a change, you can clone a workflow or create a new version.

Returns:

  • (String)


9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9050

class Workflow < Struct.new(
  :arn,
  :name,
  :version,
  :description,
  :change_description,
  :type,
  :state,
  :owner,
  :data,
  :kms_key_id,
  :date_created,
  :tags,
  :parameters)
  SENSITIVE = []
  include Aws::Structure
end