Class: Aws::Imagebuilder::Types::WorkflowConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::WorkflowConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Contains control settings and configurable inputs for a workflow resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#on_failure ⇒ String
The action to take if the workflow fails.
-
#parallel_group ⇒ String
Test workflows are defined within named runtime groups called parallel groups.
-
#parameters ⇒ Array<Types::WorkflowParameter>
Contains parameter values for each of the parameters that the workflow document defined for the workflow resource.
-
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource.
Instance Attribute Details
#on_failure ⇒ String
The action to take if the workflow fails. With CONTINUE, a failed
workflow is logged and image creation proceeds to the next workflow.
If you don't set a value, the image build fails when the workflow
fails. You can only set this property for test workflows.
9926 9927 9928 9929 9930 9931 9932 9933 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9926 class WorkflowConfiguration < Struct.new( :workflow_arn, :parameters, :parallel_group, :on_failure) SENSITIVE = [] include Aws::Structure end |
#parallel_group ⇒ String
Test workflows are defined within named runtime groups called parallel groups. The parallel group is the named group that contains this test workflow. Test workflows within a parallel group can run at the same time. Image Builder starts up to five test workflows in the group at the same time, and starts additional workflows as others complete, until all workflows in the group have completed. This field only applies for test workflows.
9926 9927 9928 9929 9930 9931 9932 9933 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9926 class WorkflowConfiguration < Struct.new( :workflow_arn, :parameters, :parallel_group, :on_failure) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::WorkflowParameter>
Contains parameter values for each of the parameters that the workflow document defined for the workflow resource.
9926 9927 9928 9929 9930 9931 9932 9933 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9926 class WorkflowConfiguration < Struct.new( :workflow_arn, :parameters, :parallel_group, :on_failure) SENSITIVE = [] include Aws::Structure end |
#workflow_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource.
9926 9927 9928 9929 9930 9931 9932 9933 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9926 class WorkflowConfiguration < Struct.new( :workflow_arn, :parameters, :parallel_group, :on_failure) SENSITIVE = [] include Aws::Structure end |