Class: Aws::Imagebuilder::Types::WorkflowExecutionMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::WorkflowExecutionMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Metadata that includes details and status from this runtime instance of the workflow.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ String
The timestamp when this runtime instance of the workflow finished.
-
#message ⇒ String
The runtime output message from the workflow, if applicable.
-
#parallel_group ⇒ String
The name of the test group that included the test workflow resource at runtime.
-
#retried ⇒ Boolean
Indicates retry status for this runtime instance of the workflow.
-
#start_time ⇒ String
The timestamp when the runtime instance of this workflow started.
-
#status ⇒ String
The current runtime status for this workflow.
-
#total_step_count ⇒ Integer
The total number of steps in the workflow.
-
#total_steps_failed ⇒ Integer
A runtime count for the number of steps in the workflow that failed.
-
#total_steps_skipped ⇒ Integer
A runtime count for the number of steps in the workflow that were skipped.
-
#total_steps_succeeded ⇒ Integer
A runtime count for the number of steps in the workflow that ran successfully.
-
#type ⇒ String
Indicates what type of workflow that Image Builder ran for this runtime instance of the workflow.
-
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource build version that ran.
-
#workflow_execution_id ⇒ String
Unique identifier that Image Builder assigns to keep track of runtime resources each time it runs a workflow.
Instance Attribute Details
#end_time ⇒ String
The timestamp when this runtime instance of the workflow finished.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The runtime output message from the workflow, if applicable.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#parallel_group ⇒ String
The name of the test group that included the test workflow resource at runtime.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#retried ⇒ Boolean
Indicates retry status for this runtime instance of the workflow.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The timestamp when the runtime instance of this workflow started.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current runtime status for this workflow.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#total_step_count ⇒ Integer
The total number of steps in the workflow. This should equal the sum of the step counts for steps that succeeded, were skipped, and failed.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#total_steps_failed ⇒ Integer
A runtime count for the number of steps in the workflow that failed.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#total_steps_skipped ⇒ Integer
A runtime count for the number of steps in the workflow that were skipped.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#total_steps_succeeded ⇒ Integer
A runtime count for the number of steps in the workflow that ran successfully.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Indicates what type of workflow that Image Builder ran for this runtime instance of the workflow.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource build version that ran.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |
#workflow_execution_id ⇒ String
Unique identifier that Image Builder assigns to keep track of runtime resources each time it runs a workflow.
9113 9114 9115 9116 9117 9118 9119 9120 9121 9122 9123 9124 9125 9126 9127 9128 9129 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9113 class WorkflowExecutionMetadata < Struct.new( :workflow_build_version_arn, :workflow_execution_id, :type, :status, :message, :total_step_count, :total_steps_succeeded, :total_steps_failed, :total_steps_skipped, :start_time, :end_time, :parallel_group, :retried) SENSITIVE = [] include Aws::Structure end |