Class: Aws::Imagebuilder::Types::WorkflowStepExecution
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::WorkflowStepExecution
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Contains runtime details for an instance of a workflow that ran for the associated image build version.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The name of the step action.
-
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version that ran the workflow.
-
#name ⇒ String
The name of the workflow step.
-
#start_time ⇒ String
The timestamp when the workflow step started.
-
#step_execution_id ⇒ String
Uniquely identifies the workflow step that ran for the associated image build version.
-
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource that ran.
-
#workflow_execution_id ⇒ String
Uniquely identifies the runtime instance of the workflow that contains the workflow step that ran for the associated image build version.
Instance Attribute Details
#action ⇒ String
The name of the step action.
9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9237 class WorkflowStepExecution < Struct.new( :step_execution_id, :image_build_version_arn, :workflow_execution_id, :workflow_build_version_arn, :name, :action, :start_time) SENSITIVE = [] include Aws::Structure end |
#image_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the image build version that ran the workflow.
9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9237 class WorkflowStepExecution < Struct.new( :step_execution_id, :image_build_version_arn, :workflow_execution_id, :workflow_build_version_arn, :name, :action, :start_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workflow step.
9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9237 class WorkflowStepExecution < Struct.new( :step_execution_id, :image_build_version_arn, :workflow_execution_id, :workflow_build_version_arn, :name, :action, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The timestamp when the workflow step started.
9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9237 class WorkflowStepExecution < Struct.new( :step_execution_id, :image_build_version_arn, :workflow_execution_id, :workflow_build_version_arn, :name, :action, :start_time) SENSITIVE = [] include Aws::Structure end |
#step_execution_id ⇒ String
Uniquely identifies the workflow step that ran for the associated image build version.
9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9237 class WorkflowStepExecution < Struct.new( :step_execution_id, :image_build_version_arn, :workflow_execution_id, :workflow_build_version_arn, :name, :action, :start_time) SENSITIVE = [] include Aws::Structure end |
#workflow_build_version_arn ⇒ String
The Amazon Resource Name (ARN) of the workflow resource that ran.
9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9237 class WorkflowStepExecution < Struct.new( :step_execution_id, :image_build_version_arn, :workflow_execution_id, :workflow_build_version_arn, :name, :action, :start_time) SENSITIVE = [] include Aws::Structure end |
#workflow_execution_id ⇒ String
Uniquely identifies the runtime instance of the workflow that contains the workflow step that ran for the associated image build version.
9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 9247 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9237 class WorkflowStepExecution < Struct.new( :step_execution_id, :image_build_version_arn, :workflow_execution_id, :workflow_build_version_arn, :name, :action, :start_time) SENSITIVE = [] include Aws::Structure end |