Class: Aws::Imagebuilder::Types::WorkflowStepMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::WorkflowStepMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Runtime details and status for the workflow step.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The step action name.
-
#description ⇒ String
Description of the workflow step.
-
#end_time ⇒ String
The timestamp when the workflow step finished.
-
#inputs ⇒ String
Input parameters that Image Builder provides for the workflow step.
-
#message ⇒ String
Detailed output message that the workflow step provides at runtime.
-
#name ⇒ String
The name of the workflow step.
-
#outputs ⇒ String
The file names that the workflow step created as output for this runtime instance of the workflow.
-
#rollback_status ⇒ String
Reports on the rollback status of the step, if applicable.
-
#start_time ⇒ String
The timestamp when the workflow step started.
-
#status ⇒ String
Runtime status for the workflow step.
-
#step_execution_id ⇒ String
A unique identifier for the workflow step, assigned at runtime.
Instance Attribute Details
#action ⇒ String
The step action name.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the workflow step.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ String
The timestamp when the workflow step finished.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ String
Input parameters that Image Builder provides for the workflow step.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
Detailed output message that the workflow step provides at runtime.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workflow step.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ String
The file names that the workflow step created as output for this runtime instance of the workflow.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#rollback_status ⇒ String
Reports on the rollback status of the step, if applicable.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The timestamp when the workflow step started.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Runtime status for the workflow step.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#step_execution_id ⇒ String
A unique identifier for the workflow step, assigned at runtime.
9298 9299 9300 9301 9302 9303 9304 9305 9306 9307 9308 9309 9310 9311 9312 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9298 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |