Class: Aws::Imagebuilder::Types::WorkflowStepMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::Imagebuilder::Types::WorkflowStepMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-imagebuilder/types.rb
Overview
Runtime details and status for the workflow step.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action ⇒ String
The step action name.
-
#description ⇒ String
Description of the workflow step.
-
#end_time ⇒ String
The timestamp when the workflow step finished.
-
#inputs ⇒ String
Input parameters that Image Builder provides for the workflow step.
-
#message ⇒ String
Detailed output message that the workflow step provides at runtime.
-
#name ⇒ String
The name of the workflow step.
-
#outputs ⇒ String
The file names that the workflow step created as output for this runtime instance of the workflow.
-
#rollback_status ⇒ String
Reports on the rollback status of the step, if applicable.
-
#start_time ⇒ String
The timestamp when the workflow step started.
-
#status ⇒ String
Runtime status for the workflow step.
-
#step_execution_id ⇒ String
A unique identifier for the workflow step, assigned at runtime.
Instance Attribute Details
#action ⇒ String
The step action name.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Description of the workflow step.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ String
The timestamp when the workflow step finished.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ String
Input parameters that Image Builder provides for the workflow step.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
Detailed output message that the workflow step provides at runtime.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the workflow step.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ String
The file names that the workflow step created as output for this runtime instance of the workflow.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#rollback_status ⇒ String
Reports on the rollback status of the step, if applicable.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The timestamp when the workflow step started.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Runtime status for the workflow step.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |
#step_execution_id ⇒ String
A unique identifier for the workflow step, assigned at runtime.
9232 9233 9234 9235 9236 9237 9238 9239 9240 9241 9242 9243 9244 9245 9246 |
# File 'lib/aws-sdk-imagebuilder/types.rb', line 9232 class WorkflowStepMetadata < Struct.new( :step_execution_id, :name, :description, :action, :status, :rollback_status, :message, :inputs, :outputs, :start_time, :end_time) SENSITIVE = [] include Aws::Structure end |